#!/usr/bin/perl
#################################################################Modules
use strict;
use warnings;
use threads;
use threads::shared;
use Net::DNS;
use Net::Whois::IANA;
use Net::Abuse::Utils qw( :all );
use Tk::ProgressBar;
use Tk::Dialog;
use Tk::ROText;
use Tk::Menu;
use Tk;
########################################################Optional Modules
if ($^O eq 'MSWin32') {
  eval    { require Win32::Console; Win32::Console::Free() };
  if ($@) { warn "Win32::Console is not installed\n"; }
}
############################################################Declarations
our $VERSION = 4.01;
my  $VERBOSE = 0;
my  $DEBUG   = 0;
my (%threads, %shash);
####################################################################Main
#start logging
if (-e 'error.log') {
  rename ('error.log', 'error.old.log')
    || warn "Can't rename error.log\n[$!]\n";
}
open (STDERR, '>', 'error.log')
  || die "Can't create error.log\n[$!]\n";
writeLog(1, 'IPLU is starting (' . localtime(time) . ')');

#start threads
writeLog(1, "Initializing shared memory\n");
foreach my $l qw (NS MX AX WI AB progress fin returnCSV optionCSV) {
  share ($shash{1}{$l});
  $shash{1}{$l} = 0;
}
writeLog(1, "Launching thread\n");
$threads{1} = threads->new(\&worker, 1);
if (defined $threads{1}) {
  writeLog(1, "Thread 1 is active\n");
}
else {
  die "Unable to launch thread\n";
}

#start gui
gui();
Tk::MainLoop();

#exit
foreach my $TID (sort keys %threads) {
  my $c = 0;
  writeLog(1, 'Destroying Thread ' . $TID . "\n");
  $shash{$TID}{fin} = 1;
  while ($c <= 3) {
    sleep (1);
    if ($threads{$TID}->is_joinable()) {
      $threads{$TID}->join();
      last;
    }
    $c++;
  }
}
writeLog(1, 'IPLU is exiting  (' . localtime(time) . ')');
close STDERR || writeLog(2, "Can't close STDERR\n[$!]");
exit;
#############################################################Subroutines
sub gui #---------------------------------------------------------------
{
  #Main Window
  my  ($sys_bg, $sys_fg,);
  our ($mw, $sys_x, $sys_y,);
  $mw = MainWindow->new(
    -title    => 'IP Lookup',
    -relief   => 'sunken',
    -bd       => 1,
  );
  $mw->gridRowconfigure   (1, -weight  => 1,);
  $mw->gridColumnconfigure(1, -weight  => 1,);
  $sys_bg = $mw->cget(-background);
  $sys_fg = $mw->cget(-foreground);
  $sys_x  = $mw->screenwidth;
  $sys_y  = $mw->screenheight;
  
  #Splashscreen
  {
    my ($splash, $canvas, $image, $geometry,);
    $mw->withdraw;
    {
      my $imagedata = load_image(1);
      $image = $mw->Photo(-format => 'gif', -data => $imagedata);
    }
    {
      my $x   = ($sys_x / 2) - 250;
      my $y   = ($sys_y / 2) - 144;
      $geometry = '500x288+' . $x . '+' .$y;
      $splash = $mw->Toplevel(-takefocus => 1,);
      $splash->overrideredirect(1);
      $splash->geometry($geometry);
      $splash->resizable(0, 0);
    }
    $canvas = $splash->Canvas()->pack(
      -fill   => 'both',
      -expand => 1,
    );
    $canvas->createImage(0,0,
      -image  => $image,
      -anchor => 'nw',
    );
    $mw->after(8000, sub {
      {
        my $w = $mw->width;
        my $h = $mw->height;
        my $x = int(($sys_x / 2) - ($w / 2));
        my $y = int(($sys_y / 2) - ($h / 2));
        $mw->geometry($w . 'x' . $h . '+' . $x . '+' . $y);
      }
      $splash->destroy;
      $mw->deiconify;
      $mw->raise;
    });
  }
  
  #Frames
  my ($f1, $f2, $f3, $f4, $f5,);
  $f1 = $mw->Frame(-relief => 'raised', -bd => 1,)->grid(
    -in     => $mw,    -column => 1,
    -sticky => 'news', -row    => 1,
  );
  $f1->gridRowconfigure   (1, -minsize => 8,);
  $f1->gridRowconfigure   (2, -weight  => 1,);
  $f1->gridRowconfigure   (3, -minsize => 8,);
  $f1->gridColumnconfigure(1, -minsize => 8,);
  $f1->gridColumnconfigure(2, -weight  => 1,);
  $f1->gridColumnconfigure(3, -minsize => 8,);
  
  $f2 = $f1->Frame()->grid(
    -in     => $f1,    -column => 2,
    -sticky => 'news', -row    => 2,
  );
  $f2->gridRowconfigure   (2, -minsize => 8,);
  $f2->gridRowconfigure   (8, -minsize => 8, -weight => 1,);
  $f2->gridColumnconfigure(2, -minsize => 8, -weight => 1,);
  $f2->gridColumnconfigure(4, -minsize => 8,);
  
  $f3 = $f1->Frame(-relief => 'sunken', -bd => 1,)->grid(
    -in     => $f2,    -column => 1, -columnspan => 3,
    -sticky => 'news', -row    => 1, -rowspan    => 1,
  );
  $f3->gridRowconfigure   (1, -weight => 1,);
  $f3->gridColumnconfigure(2, -weight => 1,);
  
  $f4 = $f1->Frame(-relief => 'solid', -bd => .5,)->grid(
    -in     => $f2,    -column => 1, -columnspan => 3,
    -sticky => 'news', -row    => 3, -rowspan    => 6,
  );
  $f4->gridRowconfigure   (1, -weight => 1,);
  $f4->gridColumnconfigure(1, -weight => 1,);
  
  #Labels
  my ($l1, $l2,);
  $l1 = $f3->Label(
    -text   => 'Host:  ',
    -relief => 'raised',
    -fg     => '#202090',
    -bd     => 1,
  )->grid(
    -in     => $f3,    -column => 1,
    -sticky => 'news', -row    => 1,
  );
  
  #Entries
  my ($e1,);
  $e1 = $f3->Entry(
    -textvariable => \our $host,
    -width        => 80,
    -bd           => .5,
    -relief       => 'solid',
    -bg           => 'white',
    -fg           => 'black',
  )->grid(
    -in     => $f3,    -column => 2,
    -sticky => 'news', -row    => 1,
  );
  
  #Buttons
  my ($b1, $b2, $b3, $b4, $b5, $b6, $b7,);
  $b1 = $f3->Button(
    -activeforeground => '#fff000',
    -activebackground => $sys_bg,
    -background       => $sys_bg,
    -bitmap           => '@' . Tk->findINC('cbxarrow.xbm'),
    -command          => sub { history('SHOW'); }
  )->grid(
    -in     => $f3,    -column => 3,
    -sticky => 'news', -row    => 1,
  );
  {
    my $c;
    foreach my $l (
      'Lookup', 'View Log', 'Save Log', 'Clear Log', 'Help', 'Exit'
    ) {
      $c++;
      my $w = $f2->Button(
        -text             => $l,
        -foreground       => $sys_fg,
        -activebackground => $sys_bg,
        -background       => $sys_bg,
        -width            => 8,
        -activeforeground => '#000fff',
      )->grid(
        -in     => $f2,    -column => 5,
        -sticky => 'news', -row    => $c,
      );
      if ($c == 1) {
        $w->configure(-command => \&lookup);
        $c++;
      }
      else {
        $w->configure(-command => sub { launch($l); });
      }
    }
  }
  
  #Text widgets
  our ($t1, $fontSize,);
  $fontSize = 8;
  $t1 = $f4->Scrolled(
    'ROText',
    -scrollbars       => 'se',
    -font             => "Courier $fontSize",
    -bg               => '#ffffff',
    -fg               => '#202090',
    -insertbackground => '#ffffff',
    -relief           => 'flat',
    -wrap             => 'none',
    -bd               => 2,
    -height           => 20,
    -width            => 80,
  )->grid(
    -in     => $f4,    -column => 1,
    -sticky => 'news', -row    => 1,
  );
  $t1->menu(undef);
  
  #History window
  our ($tl1, $f5, $lb, $loadhistory,);
  $tl1 = $mw ->Toplevel(-relief => 'flat',);
  $tl1->overrideredirect(1);
  $tl1->resizable(0, 0);
  $tl1->transient($mw);
  $tl1->withdraw;
  
  $f5 = $tl1->Frame(
    -relief    => 'groove',
    -bd        => 2,
    -takefocus => 1,
  )->grid(
    -in     => $tl1,   -column => 1,
    -sticky => 'news', -row    => 1,
  );
  $tl1->gridRowconfigure    (1, -minsize => 8, -weight => 1,);
  $tl1->gridColumnconfigure (1, -minsize => 8, -weight => 1,);
  $f5->gridRowconfigure     (1, -minsize => 8, -weight => 1,);
  $f5->gridColumnconfigure  (1, -minsize => 8, -weight => 1,);
  
  $lb = $tl1->Scrolled(
    'Listbox',
    -width            => 80,
    -height           => 8,
    -scrollbars       => 'ose',
    -selectmode       => 'single',
    -bg               => '#000000',
    -fg               => '#ffffff',
    -selectforeground => '#000000',
    -selectbackground => '#fff000',
  )->grid(
    -in     => $f5,    -column => 1,
    -sticky => 'news', -row    => 1,
  );
  
  #Progress bar
  our ($tl2, $pb,);
  $tl2 = $mw->Toplevel(
    -relief    => 'raised',
    -takefocus => 1,
    -bd        => 2.5,
  );
  $tl2->gridRowconfigure    (2, -weight => 1,);
  $tl2->gridColumnconfigure (1, -weight => 1,);
  $tl2->overrideredirect(1);
  $tl2->resizable(0, 0);
  $tl2->transient($mw);
  $tl2->withdraw;
  {
    my ($w, $f,);
    $w = $tl2->Label(-text => 'Working...')->grid(
      -in     => $tl2, -column => 1,
      -sticky => 'sw', -row    => 2,
    );
    $f = $tl2->Frame(-relief => 'sunken', -bd => 2,)->grid(
      -in     => $tl2,  -column => 1,
      -sticky => 'new', -row    => 1,
    );
    $f->gridRowconfigure    (1, -minsize => 8, -weight => 1,);
    $f->gridColumnconfigure (1, -minsize => 8, -weight => 1,);
    $w = $f->ProgressBar(
      -relief   => 'raised',
      -bd       => 4,
      -from     => 0,
      -to       => 100,
      -blocks   => 50,
      -colors   => [0, '#00ff00'],
      -variable => \$pb
    )->grid(
      -in     => $f,     -column => 1,
      -sticky => 'news', -row    => 1,
    );
  }
  
  #Bindings
  $mw->protocol(WM_DELETE_WINDOW    => sub { launch('EXIT'); });
  $mw->bind('<F1>'                  => sub { launch('HELP'); });
  $e1->bind('<Return>'              => sub { lookup(); });
  $e1->bind('<KP_Enter>'            => sub { lookup(); });
  $lb->bind('<ButtonPress-1>'       => sub { history('SELECT'); });
  $mw->bind('<Control-Key-plus>'    => sub { font('+'); });
  $mw->bind('<Control-KP_Add>'      => sub { font('+'); });
  $mw->bind('<Control-Key-minus>'   => sub { font('-'); });
  $mw->bind('<Control-KP_Subtract>' => sub { font('-'); });
  $f5->bind('<FocusOut>'            => sub {
    $lb->selectionClear(0, "end");
    $tl1->withdraw;
  });
  
  #Defaults
  $e1->focus;
  $mw->update;
  
  #Callbacks
  sub lookup #----------------------------------------------------------
  {
    my (@RHostList,);
    
    #Gather target from entry widget
    if (!defined $host) {
      launch('HELP');
      return (0);
    }
    else {
      $t1->delete('1.0', 'end');
      @RHostList = split(' ', $host);
    }
    
    foreach my $target (@RHostList) {
      my ($ok, $ip, $name, $aliases, $addrtype, $length, @addrs,);
      my ($A_out, $NS_out, $MX_out, $AXfr_out, $WhoIs_out, $Abuse_out,);
      
      #Record lookup attempt in history
      history('SAVE', $target);
      
      #Check to see if an IP address or Hostname was supplied
      if ($target =~ m#\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}#) {
        my ($a, $b, $c, $d,);
        
        #Determine target
        ($a,$b,$c,$d) = split /\./, "$target";
        if ($a > 255 || $a < 1 || $b > 255 || $c > 255 || $d > 255) {
          writeLog(2, "IP: [$target] is not a valid IP address");
          $ok = 0;
        }
        else {
          my ($packed_ip) = pack 'C4',$a,$b,$c,$d;
          if (($name, $aliases, $addrtype, $length, @addrs,)
               =gethostbyaddr($packed_ip, 1)) {
            $ok = 1
          }
          else {
            writeLog(2, "IP: [$target] is not resolvable through DNS");
            $ok = 0;;
          }
        }
      }
      else {
        if (($name, $aliases, $addrtype, $length, @addrs,)
            =gethostbyname($target)) {
          $ok = 1;
        }
        else {
          writeLog(2, "Host: [$target] is not a valid DNS hostname");
          $ok = 0;
        }
      }
      if ($ok) {
        $target = $name;
        #Target is now the FQDN, determine the IP
        {
          my ($a,$b,$c,$d) = unpack('C4', $addrs[0]);
          $ip = join('.', $a,$b,$c,$d);
        }
        
        #Perform lookups
        {
          writeLog(1, "Lookups beginning: (" . localtime(time) . ')');
          $mw->Busy(-recurse => 1,);
          ($NS_out, $A_out) = NS_A_lookup($target);
          $MX_out           = MX_lookup($target);
          $AXfr_out         = AXfr_lookup($target);
          $Abuse_out        = Abuse_lookup($target);
          $WhoIs_out        = WhoIs_lookup($ip);
          $mw->Unbusy;
          writeLog(1, "Lookups completed: (" . localtime(time) . ')');
        }
        
        #Display Output
        {
          $aliases = (join ', ', (split ' ', $aliases))
            || "Alias information not available";
          {
            my $msg =
              "Target:\t\t" . $target . ' ('. $ip . ")\n\n" .
              "Name:\t\t"   . $name               . "\n\n"  .
              "Aliases:\t"  . $aliases            . "\n\n"  .
              "NS Info:\t"  . $NS_out             . "\n\n"  .
              "A  Info:\t"  . $A_out              . "\n\n"  .
              "MX Info:"    . $MX_out             . "\n"    .
              "AX Info:"    . $AXfr_out           . "\n"    .
              "Abuse Info:" . $Abuse_out          . "\n"    .
              "WhoIs Info:" . $WhoIs_out          . "\n"    .
              '='x80 . "\n\n";
            $t1->insert('end', $msg);
            $mw->update;
          }
        }
      }
      else {
        my $m = 'Unable to perform lookups for: ' . $target . "\n\n" .
                '='x80 . "\n\n";
        $t1->insert('end', $m);
        $mw->update;
      }
    }
    #Append to logfile.
    {
      my ($logtxt,);
      if (!(open (IPLULOG, '>>', 'iplu_log.txt'))) {
        writeLog(3, "Can't create or append to logfile\n[$!]");
      }
      else {
        $logtxt = $t1->get('1.0', 'end');
        print IPLULOG $logtxt;
        close IPLULOG
          || writeLog(2, "Can't close logfile\n[$!]");
      }
    }
    $mw->Unbusy;
    $t1->focus;
    $mw->update;
    return (1);
  }
  sub NS_A_lookup #-----------------------------------------------------
  {
    my $target = $_[0] || return (0);
    my (@NS, @A, $dns, $query, $nsOut, $aOut,);
    writeLog(1, 'NS lookup started:  (' . time . ')');
    
    $dns = Net::DNS::Resolver->new;
    $dns->tcp_timeout(5);
    
    #lookup NS and A records
    foreach my $lookupType ('NS', 'A') {
      $query = $dns->query($target, $lookupType);
      if ($query) {
        foreach my $rr ($query->answer) {
          if ($rr->type eq $lookupType) {
            if ($lookupType eq 'NS') { push (@NS, $rr->nsdname); }
            else                     { push (@A,  $rr->address); }
          }
        }
        $nsOut = join("\n\t\t", @NS);
        $aOut  = join("\n\t\t", @A);
      }
      else{
        $nsOut = "'NS' record not available";
        $aOut  = "'A' record not available";
      }
    }
    #return data
    writeLog(1, 'NS lookup finished: (' . time . ')');
    return ($nsOut, $aOut);
  }
  sub MX_lookup #-------------------------------------------------------
  {
    my $target = $_[0] || return (0);
    my (@mx, $dns, $MX_counter, $MX_out,);
    my (@mx_info, $rr, $rr_error, $rr_pref, $rr_exch,);
    writeLog(1, 'MX Lookup started:  (' . time . ')');
    
    $dns = Net::DNS::Resolver->new;
    $dns->tcp_timeout(5);
    
    #perform MX lookup
    @mx = mx($dns, $target);
    $MX_counter = 0;
    if (@mx) {
      foreach my $rr (@mx) {
        $rr_pref = $rr->preference;
        $rr_exch = $rr->exchange,;
        push @mx_info, ("\t", "\tPreference: ", $rr_pref,
                        "\tExchange: ", $rr_exch, "\n");
        if ($MX_counter == 0) {
          shift @mx_info;
        }
        $MX_counter = 1;
      }
    }
    else{
      $rr_error = "\tMX record not available\n";
    }
    
    #return data
    if ($rr_error) { $MX_out = $rr_error;           }
    else           { $MX_out = (join '', @mx_info); }
    writeLog(1, 'MX Lookup finished: (' . time . ')');
    return ($MX_out);
  }
  sub AXfr_lookup #-----------------------------------------------------
  {
    my $target = $_[0] || return (0);
    my ($result, $AXfr_out,);
    writeLog(1, 'AX Lookup started:  (' . time . ')');
    
    $result = invokeThread('AX', $target);
    if ($result) {
      $AXfr_out = "\t" . $result . "\n";
    }
    else {
      $AXfr_out = "\tZone transfer not available\n";
    }
    writeLog(1, 'AX Lookup finished: (' . time . ')');
    return ($AXfr_out);
  }
  sub WhoIs_lookup #----------------------------------------------------
  {
    my $ip = $_[0] || return (0);
    my ($result, $WI_out,);
    writeLog(1, 'WI Lookup started:  (' . time . ')');
    
    $result = invokeThread('WI', $ip);
    if ($result) {
      $WI_out = "\t" . $result . "\n";
    }
    else {
      $WI_out = "\tWhois information not available\n";
    }
    writeLog(1, 'WI Lookup finished: (' . time . ')');
    return ($WI_out);
  }
  sub Abuse_lookup #----------------------------------------------------
  {
    my $target = $_[0] || return (0);
    my ($result, $AB_out,);
    writeLog(1, 'AB Lookup started:  (' . time . ')');
    
    $result = invokeThread('AB', $target);
    if ($result) {
      $AB_out = "\t" . $result . "\n";
    }
    else {
      $AB_out = "\tContact information not available\n";
    }
    writeLog(1, 'AB Lookup finished: (' . time . ')');
    return ($AB_out);
  }
  sub invokeThread #----------------------------------------------------
  {
    my $opt    = uc ($_[0]) || return 0;
    my $target = $_[1]      || '127.0.0.1';
    my $output;
    
    $shash{1}{optionCSV} = $target;
    $shash{1}{$opt}      = 1;
    launch('PBAR');
    $mw->after(500);
    
    while ($shash{1}{$opt} == 1) {
      #wait for the thread, update gui
      if ($pb < 100) { $pb++;   }
      else           { $pb = 0; }
      $tl2->focus;
      $tl2->update;
      $mw->update;
      $mw->after(50);                                                   #<-test
    }
    
    #check return data
    if ($shash{1}{returnCSV}) {
      $output = $shash{1}{returnCSV};
      undef $shash{1}{returnCSV};
    }
    else {
      $output = 0;
    }
    while ($pb < 100) { $pb += 2; $mw->update; }
    $tl2->withdraw;
    return ($output);
  }
  sub launch #----------------------------------------------------------
  {
    my $opt1 = uc ($_[0]) || return (0);
    
    if ($opt1 eq 'PBAR') {                                 #Progress Bar
      my $geometry;
      {
        my $g = $mw->geometry;
        my $x = $mw->rootx;
        my $y = $mw->rooty;
        my $w = $mw->width;
        my $h = $mw->height;
        my $pb_x = int (($w / 2) - 150) + $x;
        my $pb_y = int (($h / 2) - 30)  + $y;
        $geometry = '300x60+' . $pb_x . '+' .$pb_y;
        $pb = 0;
      }
      $tl2->geometry($geometry);
      $tl2->deiconify();
      $tl2->raise();
      $tl2->focus;
    }
    elsif ($opt1 eq 'VIEW LOG') {                              #View Log
      $t1->delete('1.0', 'end');
      if (-e 'iplu_log.txt') {
        if (! (open (IPLULOG, '<', 'iplu_log.txt'))) {
          writeLog(3, "Can't open iplu_log.txt\n[$!]");
        }
        else {
          while (my $line = (<IPLULOG>)) {
            $t1->insert('end', $line);
            $mw->update;
          }
          close IPLULOG
            || writeLog(2, "Can't close iplu_log.txt\n[$!]");
        }
      }
      else {
        return (0);
      }
      $t1->focus;
      $mw->update;
    }
    elsif ($opt1 eq 'SAVE LOG') {                              #Save Log
      my $types = [
        ['Text Files',       ['.txt', '.text']],
        ['All Files',        '*',             ],
      ];
      my $sfile = $mw->getSaveFile(
        -title            => 'Save Log',
        -defaultextension => 'txt',
        -filetypes        => $types,
      );
      if (defined ($sfile)) {
        if (!(open (IPLU_LOG,  '<', 'iplu_log.txt'))) {
          writeLog(3, 'Cant read iplu_log.txt' . "\n[$!]");
        }
        else {
          if (!(open (IPLU_SAVE, '>', $sfile))) {
            writeLog(3, 'Cant create ' . $sfile . "\n[$!]");
          }
          else {
            while (my $line = (<IPLU_LOG>)) {
              print IPLU_SAVE $line;
            }
            close IPLU_SAVE
              || writeLog(2, 'Cant close' . $sfile . "\n[$!]");
          }
          close IPLU_LOG
            || writeLog(2, 'Cant close iplu_log.txt' . "\n[$!]");
        }
      }
      else {
        return (0);
      }
    }
    elsif ($opt1 eq 'CLEAR LOG') {                            #Clear Log
      my $confirm = $mw->Dialog(
        -text    => 'Are you sure you want to clear the log?',
        -title   => 'Confirm Clear Log',
        -buttons => [ 'Yes', 'No'],
        -bitmap  => 'question',
        -default_button => 'Yes',)->Show(
      );
      if ($confirm eq 'Yes') {
        if (-e 'iplu_log.txt') {
          unlink 'iplu_log.txt'
            || writeLog(3, "Cant delete iplu_log.txt\n[$!]");
        }
        open (IPLULOG, ">>iplu_log.txt")
          || writeLog(3, "Cant create or append to log\n[$!]");
        close IPLULOG
          || writeLog(2, "Cant close log\n[$!]");
      }
    }
    elsif ($opt1 eq 'HELP') {                                      #Help
      $t1->delete('1.0', 'end');
      $t1->insert('end', 'IPLU - Lists IP addresses, aliases, MX, '  .
                         "and AXfr info for the targets.\n\n"        .
                         "Version:\t4.01\nAuthor:\t\t"               .
                         "Jason McManus\nContact:\t".'QoS@cpan.org'  .
                         "\n\n");
      $t1->insert('end', "Usage:\t\t<target1> <target2> <etc..>\n\n" .
                         "Examples:\t"                               .
                         "17.254.0.91\n\t\t"                         .
                         "www.perlmonks.org\n\t\t"                   .
                         "www.cpan.org www.perl.org 10.5.2.1\n\n");
      $mw->update;
    }
    elsif ($opt1 eq 'EXIT') {                                      #Exit
      writeLog(5, "Exit requested");
    }
    else {
      writeLog(4, 'Invald option: [' . $opt1 . '] in launch');
      return (0);
    }
    return (1);
  }
  sub history #---------------------------------------------------------
  {
    my $cmd = uc ($_[0]) || return (0);
    my $in1 = $_[1]      || 0;
    
    if ($cmd eq 'SHOW') {
      my ($x, $y) = $mw->pointerxy;
      $f5->focus;
      $lb->see('end');
      $x -= 505;
      $y += 5;
      $tl1->geometry('+'."$x".'+'."$y");
      $tl1->deiconify();
      $tl1->raise();
      
      #read in the history file the first time history is requested
      if (! $loadhistory) {
        if (-e 'iplu.hst') {
          open(HIST_IN, '<', 'iplu.hst')
            || writeLog(3, "Unable to open iplu.hst\n[$!]")
            && return (0);
          my @hist = (<HIST_IN>);
          close HIST_IN
            || writeLog(2, "Unable to close iplu.hst\n[$!]");
          while ($#hist >= 9) {
            shift @hist;
          }
          open(HIST_OUT, '>', 'iplu.hst')
            || writeLog(3, "Unable to open iplu.hst\n[$!]")
            && return (0);
          foreach my $i (@hist) {
            chomp $i;
            print HIST_OUT $i . "\n";
            $lb->insert('end', $i);
          }
          close HIST_OUT
            || writeLog(2, "Unable to close iplu.hst\n[$!]");
        }
        else {
          open(HIST_OUT, '>', 'iplu.hst')
            || writeLog(2, "Unable to open iplu.hst\n[$!]")
            && return (0);
          close HIST_OUT
            || writeLog(2, "Unable to close iplu.hst\n[$!]");
        }
        $loadhistory = 1;
      }
    }
    elsif ($cmd eq 'SELECT') {
      $mw->update;
      $mw->after(400);
      my @sels = $lb->curselection();
      if (defined $sels[0]) {
        $host = $lb->get($sels[0]);
        $mw->focus;
        $mw->update;
      }
      else {
        return (0);
      }
    }
    elsif ($cmd eq 'SAVE') {
      $lb->insert('end', $in1);
      open (HIST_OUT, '>>', 'iplu.hst')
        || writeLog(3, "Unable to create iplu.hst\n[$!]")
        && return (0);
      print HIST_OUT $in1 . "\n";
      close HIST_OUT
        || writeLog(2, "Unable to close iplu.hst\n[$!]");
    }
    else {
      writeLog(4, 'Invalid cmd: [' . $cmd . "] in History\n[$!]");
      return (0);
    }
    return (1);
  }
  sub writeLog #--------------------------------------------------------
  {
    my $msgType = $_[0] || return (0);
    my $msgIn   = $_[1] || return (0);
    my ($msgOut, $time,);
    
    #Prepare time
    {
      #(sec, min, hour, mday, mon, year, wday, yday, isdst)
      my @a = localtime(time);
      $a[5] = $a[5] + 1900;
      $a[5] = sprintf("%02d", $a[5] % 100);
      if ($a[2] < 10) { $a[2] = 0 . $a[2]; }
      $time = "$a[4]/$a[3]/$a[5]  $a[2]:$a[1]:$a[1]";
    }
    
    #Prepare output
    chomp $msgIn;
    if ($msgType == 4) {
      #Debug mode ?
      if ($DEBUG != 1) { return (0); }
      $msgOut = 'DEBUG ' . $msgIn;
    }
    else {
      if    ($msgType == 1) { $msgOut = $time . '  INFO    ' . $msgIn; }
      elsif ($msgType == 2) { $msgOut = $time . '  WARN    ' . $msgIn; }
      elsif ($msgType == 3) { $msgOut = $time . '  ERROR   ' . $msgIn; }
      elsif ($msgType == 5) { $msgOut = $time . '  FATAL   ' . $msgIn; }
      else {
        $msgOut = 'Invalid msgType: [' . $msgType . "] in writeLog\n";
      }
    }
    
    #Verbose mode ?
    if ($VERBOSE == 1) {
      my ($c1, $c2, $c3,);
      $c1 = (caller(1))[3] || 'main';
      $c2 = (caller(2))[3] || 'main';
      $c3 = (caller(0))[2];
      warn "$time  VERBOSE $c1 line $c3 (called by $c2)\n";
    }
    
    #Output to log
    warn $msgOut . "\n";
    
    #Fatal?
    if ($msgType == 5) { $mw->destroy; }
    
    return (1);
  }
  sub load_image #------------------------------------------------------LOAD IMAGE
  {
    my $opt = $_[0] || return (0);
    my $imagedata;
    
    if ($opt == 1) {
      while (my $l = (<DATA>)) { $imagedata .= $l; }
    }
    return ($imagedata);
  }
  return (1);
}
#################################################################Workers
sub worker #------------------------------------------------------------
{
  #called from main
  #shash = NS MX AX WI progress die returnCSV optionCSV
  my $TID = $_[0] || 0;
  $| = 1;
  
  while(1) {
    if ($shash{$TID}{fin} == 1) {                                   #Fin
      last;
    }
    elsif ($shash{$TID}{NS} == 1) {                         #Name server
      $shash{$TID}{optionCSV} = 0;
      $shash{$TID}{NS}        = 0;
    }
    elsif ($shash{$TID}{MX} == 1) {                      #Mail exchanger
      $shash{$TID}{optionCSV} = 0;
      $shash{$TID}{MX}        = 0;
    }
    elsif ($shash{$TID}{AX} == 1) {                                #AXfr
      my ($dns, $target, @zone,);
      undef $shash{$TID}{returnCSV};
      
      #perform zone transfer
      $dns = Net::DNS::Resolver->new;
      $dns->tcp_timeout(10);
      $target = $shash{1}{optionCSV} || '127.0.0.1';
      @zone   = $dns->axfr($target);
      
      if (@zone) {
        #print zone transfer to tempfile
        my ($save_fh,);
        open (TEMPFILE_1, '>~iplutmp1.tmp')
          || writeLog(3, "Unable to create ~tplutmp1.tmp\n[$!]")
          && return (0);
        $save_fh = select(TEMPFILE_1);
        $| = 1;
        print "\n\n";
        foreach my $rr (@zone) {
          $rr->print;
        }
        select ($save_fh);
        $| = 0;
        close TEMPFILE_1
          || writeLog(2, "Can't close ~iplutmp1.tmp\n[$!]");
        
        #read tempfile and prepare the return data
        open (TEMPFILE_1, '~iplutmp1.tmp')
          || writeLog(3, "Can't open ~iplutmp1.tmp\n[$!]")
          && return (0);
        foreach my $line ((<TEMPFILE_1>)) {
          $shash{$TID}{returnCSV} .= $line;
        }
        close TEMPFILE_1
          || writeLog(2, "Can't close ~iplutmp1.tmp\n[$!]");
        unlink '~iplutmp1.tmp'
          || writeLog(2, "Can't delete ~iplutmp1.tmp\n[$!]");
      }
      $shash{$TID}{optionCSV} = 0;
      $shash{$TID}{AX}        = 0;
    }
    elsif ($shash{$TID}{WI} == 1) {                               #WhoIs
      my ($iana, $WhoIs_out,);
      my $ip = $shash{1}{optionCSV} || '127.0.0.1';
      undef $shash{$TID}{returnCSV};
      
      #perform whois lookup
      $iana = new Net::Whois::IANA;
      if ($iana->whois_query(-ip => $ip,)) {
        $WhoIs_out = "\n" . $iana->fullinfo();
      }
      else {
        $WhoIs_out = 0;
      }
      
      #return data
      $shash{$TID}{returnCSV} = $WhoIs_out;
      $shash{$TID}{optionCSV} = 0;
      $shash{$TID}{WI}        = 0;
    }
    elsif ($shash{$TID}{AB} == 1) {                               #Abuse
      my (@r, $dns,);
      my $save = my $domain = $shash{1}{optionCSV} || 'localhost';
      undef $shash{$TID}{returnCSV};
      
      $dns = new Net::DNS::Resolver;
      $dns->tcp_timeout(5);
      
      while(1) {
        # look up contacts from abuse.net
        my $query = $dns->search($domain . '.contacts.abuse.net', 'TXT');
        if ($query) {
          foreach my $rr ($query->answer) {
            if ($rr->type eq "TXT") { push (@r, $rr->txtdata); }
          }
          $shash{$TID}{returnCSV} = join (',', @r);
          last;
        }
        else {
          # Net::DNS rejects special characters, strip off
          # subdomains and see if a parent domain works
          writeLog(1, 'Removing subdomain from:' . $domain);
          if($domain =~ m{^[^.]+\.([^.]+\..+)}) {
            $domain = $1;
            writeLog(1, 'Trying abuse query for: ' . $domain);
          }
          else {
            writeLog(3, "Can't lookup contacts for: "  . $save);
            $shash{$TID}{returnCSV} = 0;
            last;
          }
        }
      }
      $shash{$TID}{optionCSV} = 0;
      $shash{$TID}{AB}        = 0;
    }
    else {
      sleep (1);
    }
  }
  writeLog(1, 'Thread ' . $TID . ' is closing');
  return (0);
}
###########################################################DOCUMENTATION
=head1 NAME

IPLU - IP Lookup

=head1 DESCRIPTION

A IP Networking tool

=head1 README

IPLU - Displays WhoIs, MX, NS, Axfr, and other information

=head1 PREREQUISITES

Tk
Net::DNS
Net::Whois::IANA

=head1 COREQUISITES

=head1 Copyright

IPLU - Discovers Multi-Homed addresses and other information.
Copyright (C) 2003 - 2008 Jason David McManus

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

=head1 History

v1_00 (Dec. 2003)

      Initial release

v4_00 (Oct. 2008)

      Complete re-write
      Now performs all lookups all the time
      Includes a timeout for AXfr queries
      Implemented threads

v4_01 (Nov. 2008)

      Improved logging
      Improved GUI code
      Included progress bar
      Now using Net::DNS to find A records
      Now performs Abuse.net contact lookups

=head1 ToDo

Adding new functions and more features

=pod OSNAMES

=pod SCRIPT CATEGORIES

Networking

=cut

__DATA__
R0lGODlh+AFoAfcAAAYDBMGDSodDC/rDikhEVoqFnkUiCMyqZHBmTMTExGhjWygkNlBDM4aDe/zm
y2llf1QkBqSkpAQCJMSkhIRJLCAUCZ10VcSSSLBkIKulxuTl5OKlfp5mPvO0gIxyWmg0CNrIqr2T
ePbz68rF6VRUVDEzIXNTNNy1nLB0QTcUBlg0H7aHYDQ0NYhZMiUkJEVFRbSztCkFBI5UItTTy7KV
fN20kWdlbltVcMqUYXZ1ffSzdIRcRdeVYQYEFvzWqDo1UZeUn+Xk9XBDH/zTlsB5QkMrIBQVFPT0
9OGkb7m1y2RSXKmluGpFLYiEjnY2BplbL/DHp3hylHR0dMqMXvbElpR8btusjlg8NM2GU/z123g9
IJqVtOytcw0MC8fE17h9VSwrItTU1KZsQPi7gj8cCT08PPS8jmxsbHx8fNucZOzs7F87Iubj3Fxc
XLR6QoVFH7y13IJpWhgUJ+msf8Seh0xNTBwbHH98ckxCbKysrKlwMry8vJycnfz9/Kl8VdjU6ZBk
Q8m3lFlVSqyOdqSilNG7sZSUlPzPqfzmpKBUGFQiFMnFvOGddezSzOTc/KdmMOzIuEsrETAsNohR
MUI7KmBdbsqbZr67yOzOxMKjj/navIxLEU5MWm1rZE5MOoyLhB8cJ6xcRHRyZMGLT5CMoHFtgLGs
ytLM6uW7nUA9T2ZdXa6suW5LM3k8DNKMUqGduNzc3Pnr2ZJrRaZcIeekY/zdnPzmvEIkFNyWVDk0
LMSWbDQsRJxSPF42FLSJbF4sCMucePz76pBbIg8NFu/t9XlLIYyMjPzLmJybki0MBIdbPL99TJdd
PMSMbPrLiszMy8ytgeS8k4F9ls3N1oZNIN3c5vndxsyulIRGFGRkZEdEPISEhJl2ZKd0TCYlLLW0
vKBsTDwcFIJ9jNucbGA9LJx8ZGBcfMG91LSehMS931FLcVgtFYt3ZBALJL6EVKWkrJxmTFdUZEwz
IVQ2LDc0RHhmcHl0jJeTrHo1FEw+RLR+ZCwsLPbu6vvl1lxcZK57TCH5BAAAAAAALAAAAAD4AWgB
Bwj/APsIFHhkYEGCfQ4iJDaw4cGHCRFGbEhRokWLB9VQVKhw4sSOBjdWLKgxpMeCIEseySgSYUeU
FyFGBDnyosuWNSXCxGjTJk2SOW82VIkTosyIGl9WHFhy6USiR3n2aarzY0iqTlsqxDqQIU2BKlk6
DKmUYVanR7kK9IrWIRoADrd1YammTZs6K/toqHOGxJGS2+CqIdlGShmEyOBKRDMXJolsfs1K6dKn
mkANNkS9QHnkEwCWR7KdyaYmaWCDR0jwZXuH8kTGBTUQzCaljcLTM19I6SRbb+bNCTt/BjvVLt7Y
daT4BQyXGGHlU/sQE01iooY22fzdVnxwcmWCbxsS/3tcnXO2TqRNKw6u+szKgq0Xz9U7u/Z2l7p5
g18vnfzMI4yFlNxyAsklUQ5w9RaaKP7IdtAZzUnXB3lHSEaZZb5pxpl/nAWIEAmjaaQRiCSUpAaI
h0WU2GX1teHgEXVk08ZgCeXXG2YaBucZXcblpQEJNmTDT3QkmogiYoopSJuLwcWoRGkCeYfhJzCI
0wcsAqGRgD8OnQFWDlNJQZCYfZwBA5lROoiGRttEwOVM25zZ0Bm9edmHFAnYWZAUDxaExiUKdIml
GmgktM0edkZ5UDYF7qEEnHIilIMGK5EpBQxoPGQnMZb22cefjBpkpxpgqsFnQmSaieadsqkR6hlJ
ef+50h2XZXonpgrhqWcfVFqJZZmXJXrGoIUecWiidy7a6KMoxYlmQZMeIUIOe+JK0KZk9nqlQHZq
kKiWjCZ16hGpwtBGQ8ZEAGZE0ZLb2yerGDNnSXbqitCpZTLU7bcJhIsqSXZm45Wt467ZR5tvRiQF
peRqJEVJnSSEraLc+nlJqNeCJaapYAU88J4oGYxwSAtX6jC9UeZJ0EG2UZQNUMnOWulA5z44UcLI
kmmWQG/uee1DGN8J3kQvR9dHEyIUFOhAuzKb7ECFUsWlQsIqNDVDtgqtNYBEw8xnpSut20fNFR/U
szHwmWWDwjYPNLVBGLNMdXcRNVGSKnMiVPMR1EL/bTTPHgnb0NWf0i0304ZfK8JAawtE9sEe9VE0
t0yjFqrPEgPdEJlcH+FelB+dsbhAjfMD5hFoUw6s6qBTPdDXmVaKNd1bFytQ0SV9DSDYqCaU+uqC
vx746yvFTq7mDukcEa0rJ9p4os+uHfKYMyGbF+d9PNp6xQNhfC67ljOeK31al88pauUb2naWDX0v
+e0034ta8KIIL5AI0idUaO99NL66COJACbL2N5HPGYRMDotfQTBmg/H1Bk1oOt/K0mes9X2qfd07
IHHQ9Lg+iI1roJsNRQjVlW0cJGJ5i4j7xOQp+DkuhGPzyAcJ2LivrS5iMxNgQwBIO4zZyX2h8p78
/5qXwfLVMC92khW5qrfDAIYQYzjkXkOCRrqQ9G11YjvDzgwmELxJMX1Ds19oXEc8zLHOZz6L1Zz6
JJmNFGpnjMLcApuyLs9RLH2JglbbsrjFpnhRaxCMCMawR5rhuawhqqCd0NIosTVWrI1ukRD85Cg5
OmasiF1UZELiyL98Ve5vD8vgSpzolZzNhox3JJN2YLjJmQRydYU7gpW+uLGIyEpreiJTHeulyTwW
TnWBXGKWioc44SUFWJjT0xVhub6D7K87tHPfrpYWQmG60CHLxNj+GHK58uXxmapTAwpvlxcQwhKM
u1vL0yQHlG2kUJho+qZE8EUmaSIkaFcM4ie3hv87yHXlfcE5IwEvh0BkvWx6rEPnFRmCr36685NL
bOZAQ2LCfe7qluJSZ0MpgoadJWybADWjnSaKkIqyTp/6G2YnAcq2F3pTdfDcJwhbuC73Ne5y+7OV
NVkKMpdyTnndlM6ursm90OgvNs8q1b9a2dJDCu8vBjzn59RgUIrgy387nRy+dkrUO2nEW4ObiCjq
xD2qTpEiopNOHHOwOA08q5bHW2oo41qm91Q1oOecykWdA0t85XFVq1wnV1kapa/eVSBjZZ1ZbclX
ZL3PU25NoWS9qlento6qqKxrZfNVEMdyUrP86JQLL9dNfBVWL7YSWCP7kFjgAeysjuTHWgtCjPr/
rROlRm3qaTWQWgGiEnWTycGpjJENUIgCq204w4wGAiS/FOgMXUCDnjhRm19J1whSQJMxRDGM7BKE
BMo5yDbOgF3O8aVlfTDGGexwhkS5Sgp1qBt3aUMQJcD3IDlgjBRGKgX2JkoE1HWuCJowmTPoLLl4
AQuCByKOt3RiltJJ7nIdh4YSCUQcUsBu405UGyP1hSPgde7BpAAAKaxrGxk2sECMQWI0nKouMmpK
XZRjFjSgYRhnuGId0PACghgiG0bIxv5+3IX9DgTA4S0QiU28FgQfhMUAcDFhYjwQFBeZc80VL3m9
68EUN+4IhfGLM9er4oSEWLwpRuCCFUxlJV+Z/yD+yEZ8vysFTjykMG2w7pb/G+CMKMAG7iOGkxV8
hjn3ocEAeHBD6pCDlhVkzWaWkVnGo1w9Y5fPSS6OctFshDKjxShLAYlSQq3OgNLIJ1Ah9QRngtea
fEUrDhF1W87yE1qP0CRkUUtMxiIRtbyaOB4hylmYEupam0TWvHZKU/KCk2FLEiNbAXavVa1s9P2T
2VKZyM6wfWyr2LrZyA5K5A6ybWPv5CnDlvW5xbIzoUTO22R597t9fRJV/1reWQn3rXsyblaL5NW/
vnezZ+1uXHMk3s7ON7WJnWx/L+WY7G44WxRu8G+P5dfH9PbBBy5ufP/tKwKPXLstTnB+pzvk7//W
N8I9XpW/sfzeKkd2VOzd8JInvNYAH8rCE06RkfO83/WGmclRvhSflzzgNv/nrm/Oc5roGuckZ4iu
Oa5skPMb1BRX59R70hGj75w4Vld6RbxC9IsYPSW4/nnP1d5ytrs962yPdlC4rfJsvz3r9GY6yatd
c4qH/dtc0cjZZ33ub+cc3mlvOuFZbncW3aTuvOb2py8+EAzthN5bj3y2Z351l0v7KDA5OE2kDuyd
cYXooW/7tgve74cA5Sgj/3u80V5qqxQeKUWpucAdpHl4g97hCMm8vCXPcYx3+/EWxzqwid93c2dl
SDr/9sRzv++2Az/pLhf2v0c9ErHEWtrjPnz/uo+ucWqXXe3cH7ur+d53kzf9988+i1kEzhGvM777
na/3sh+e7/QzH9+csWrOpn3RFxMCVxeFViErBgBUIWjK1RSB0RHJYWhH0ATDwR5n8CQNER4NgRsE
YSAqUQeA1hTGwIAOUYKo8Ri28WTrURAUAhYvUGG9kRCMZmEJYQgXmBBKkIBVxh8igGD8QG7YwSQC
wQl3IGJ90ABwoRBvwRF9ZhAkghKUNmETUmgq4YF9IALksWzYUR6GsoRQ4xoR0YRIkRycMIMwkgPO
tRLnpRI7mGBf2BD8ACRUyCs5eDB3OCCjkxoPSGjOVRIcyB72wVxW2INySIdUsSMNoYQdQYYD/1GC
rgciSoCGNQh9R4CDDvGG93FkQLiJBDFo/dEXvAcbKyOJlJgDgvAQmNgQIFIHJbFhurQHq7I6uXUo
CdM/jFMgeWA7mmVWBbENebAqd7AKBIQ6eYAssCgQOSCLFAGM2DMqZGIIx/hOokVXn2NHBwMDnwUr
qwWMyKJFIkVbcYRALGQI73BLxpIAjzNVfhUyC6RDZaJGBzONTMNX8SRC85g16XWOcKKOBUQS7XhU
7LRa3IiN3rhGM3Nh2riBe3CL/tM4X1aNt+SMjoSNBWknB4k4CXloC8lgu6gQxsCPzeKPnmIqnmKQ
C/kg8piR3GKPVRaMCPE5EnRVusiL7HiSjf8TJ9soj36FQQjpQRrkTNMDj3d0S/yjEO7DNE3Rk/FT
EadDOZ2lTqY0Wvv0UwbRURY1WWLjQ/ZDNrsSSivzUEUpRt9zj7D0jQ2xlRoJlNRjVctmLJuzPpzz
PVnEOmg5EGqZNxzBQioFQnegLCxllDv1SsGTUHlZOXtZEWAZHGK5TtDTlvqzM4V5ToepjBOBJrhl
O9g4ltX0LFhpl6m0OWh1SWcUPEpzEGCVOaIJbONkP6HpmpOVKO6zU6JwPWbEl1wJm1YpPt2jSFkz
Uk2ZUmiFmrkkSHgJU5YCmf2jEFoFUTmDbeZUTHpRnAv0VMW5NavSQL3JShwzmqSZKQBEPN7/1BHP
Ejy7STrMqUndGZccQUDSmZoRFZir2ZkNoZ3kxEpS9Umm2QcKQJzUU52stCq7KURQQ57R4SVm8VlS
YBZ6wjf1GR3FmD4MYZ+IeU1JqY+2JD8+k6BhxT+muQ1DspnAUhJAtEHz6ZW5iExCw1fdBKBVpBFf
tg2LI0z+80NFlECuSTa1hKCsBKAwETRrA6Mf6BVkMk426kI4CkOPU1s68VlsFZXIJEzfQjJEEx31
dKPpw0HaZlvjExItSlhBiouGEqJoSaJYKqAKlKFqujpMGTYPKqRjylSUY6YuxDlvlIXP4piIFJO6
xZflszddJTQiEqBDQ1t56kKdhRJ++pS0/5g643JLPWmo6pQ1aHqgiaM7tBJX8alZTOFOigSp0HQE
f2kyv5SlxGFAYsJQFlQdRuM5HaEGngpDoKoofPMeUjAklLqaGoGqESEbC9oRPXOWMOWoKAGoPCUs
uKpJCMSpfOmrfMVcyxdVUxGrL9VTKipBs0Oolro9iLo6xJCpaGOtiySrTcWX2FqqqTI6BuSgv/Ip
lLJYziE2GtAALDMRrCoQfzmtqMGX9UpshcIGp0VZKdWuSnNAJBE33yh4r6JGbjoVXFSq2IiNg+Gn
+5KiHEMqBysqqxY0+eqLDhomJ0M5xKAno7KpFZsl72oniyMmM0iLgImvr0VMqBWyuBixJf9LscFi
Wa7JW4pKMa7CLaaxr0xRLBwzspc0sQWUs7Almi3boETVsUq0LoTSFFmDjUY7FSartBFBTXHFDzdl
Fo9zr30AtcEhtQ9btSR7GTYgBcBhLOuVDWKpBmt7r+plBHfwJtVgF23AVy7mAkxWIecFE+NlB6Ih
EE2QDZIgCtozXiU2S5jBts1CXnBbZTnQBdmQAyICXkqgqJOxDYxCKaNRHQrbF9YxhCFDXgaGErpR
SAfzFlLwTP7hFXXRBnaGHIPIWjlQAWtruOv1t8RwXqWbDaogG0nDCQrwJKorBay7Da4Lu5AxE3IL
HbxLuOtiDCSgu3bSBL17Or+rXMHbIFn/mBp2QSNH8ALHBRjN+13PWxAAlGGFoT/khQbfcx00BhYh
Fh3T8WFV9rYY8wLtRb6ri74l5rxe2L5G8L4A8rbVe702kL3bmxDd+zjXISOn22njoht0UiDpG2nV
4RXbULmXmxRA0k8kYBd8KwV+y73Ai5qmC78WnLyF5H0/t3//l3o117KJJxTCh30mgcM5wXn7phRR
IWurt36sp3oeR4A7kX4MB3Mr13sS8mpKjHj0F1Dnd24+PG+7NsR7l3thB8QFSHlAd3es9sXut3x2
d373p3Cyd3ust25j/HU57HmkFm5M7HZIVxHCd3sbd8SKh3g8/MSCrG7t13Ihd8gpl3Zq/wxrPLfH
w5fIZbfIfkzIP+zGdSzHUJzHsgd342fF5gd8JtJxHyHJxQaAsxd9p/fDZIx/ybbJogzJVHdy1Nds
oVx8ArjKrWZrhVfLDUfK13fGvsfJfSx/AQh+7ibJv1bErmfMhdfHKCd+YpfDKMdX2HZq6Jd0Pmds
YVzGW3HFvVyA5VR7MvF/0sF9w7xwdxx/XJdw1NzNq3zH2VzJzPwfDCfGa4zJ+LZ/DvF0nMx4pzaD
p7bEnVzPziZ0PiFJ0EnDYGF8hrzDHkfEAvgXCGfNepzDFC3MjTcW7SZzA50QDo17wdwWG/0UDK1x
H83IWSfROox61RfLj5wV/8wUypfSQv8BGgQtdDI2ymwMzIMxOrcczjZc0dPWcl73FUnzd1hn08wG
M/qsz+SGfUdtfmUBdnhl0HQXa04N0gcoLZqXekFdysen0iFNEVE9dzVN1Uvtcs9K1XhV1EtR1gvt
07l8ecE2FjnN1uQs0EcGnYFBFMmhBCIwf5zQCSs4FS/gD/0ZHacxf2GWhVORHESoP/MhHXNYZ2I1
DEbjKmjACfdiB6F8BKqgXMRQEjgo0UFYwrBSEghCPr8rZ3+jG4JwapA4EUbIusZighHx11CSEINd
2PTrisGhBMlFKcqYIGsRI/HVFLpRIqMz2wdR21eI23vi2cAWuLFRGMC9EiQyf0cyEKv/2BtqgNwv
smAHwV2ZLWScndsPOH+qEF6k/Rkacdp9wd1nkCIC8d0CwQ/I/azOXYR3YNt9jRB/HdgE0ds+gt1J
cQQ7KGJ82MGPbR/KLQWxzYI7Ad1ggd6dXcvWbdiI3U4RkhBhlhfhXRtoSIqUDV7xZRYWvo9RA7R6
wTmhcrG7eSnuCZZvEkqwmhRNICfdIRv8ICtNgCjNQy9sAgP5g5564U4aYAx8kEfbALYpM1UvlRDa
qQFOhAYRkDWLhVn7SCtE/uL4KOMiQiZCRC55AhRmeQRVfuVZnhGj8jkh2eLZeORiKuZhgqjVuKAH
EwF8qRFiE0pzBeRCHhzcGI+eFFlU/x4bSs7kTt6z66TnbdLnbPlLWK7lb14QxpAHSmXoiJ5bds4x
uQVPZnNai6XmscHmlt4xK1Ho3BgndB7jGzPjmLI5JVE0OL4NOs7jaSJUm8Xle7KUa8qX9SJKrSSX
jbSrOnudd7Q6oG6tZjQ560SLxbgqudQd0EftAQWWX7kzZjmuw47s5TPt1NgduaOXvw5TAiueCqOm
O0qufZW01AiVWUpGoM6U5QPtphU8j2lBEYvt14MyCuPT3S7soAPuZrnvXuIw1s5KSiSwSaQx2Q4R
BH/vM7GN9pPweRU01e7weomcbUNCA1mrMkWYEEVU3f5Y17QqnASlHsSc8H5B+0QMWf/DQCX/lfuk
orTIlCDPldbknoki8y+7nzZfRRWaizAxKvuDMbUJS8zTpn2QMLJBQF4iAibVmp81SB7POtlUpSG0
lUf/T0I/ROd05BvP7En/SWiyLn9+UilKi26PJjcFmytv9vcp8mdE8kT/suWDQpi5gRoLQ7EDSIhp
Rir68MVDdlszroxa48a57qJJ+FHFOVMpR2ufUCrv+OxDmmgS+J0CpWkrRltT+ed0+YRfjFCKX3mx
LhNPTbZOmon/9J9ETX7K+AD6mNtD7V26Oljv+kY0nyi/KsUIqQWKOTb0PJ+Um1HrmlM5SYLvo69v
Q8kJlZCvpkpkMHnBpYrP/BH0nPD/k6T+4OdaO6KW6aE3L6bX9FcIgUN2BJiKFDfPlE4ztalgyUlo
QFZr8YxBaP5Xe0f+gibfP7YA0UfgGYFSjvQ5gkbgkSNSEBZUIzDbQzQaBIoSiJDgwzPEDm7sQwxk
RhsLC2b0F9HhyT4rWwpsk7EBw4EHBYowdvAIxpd91LhsaLITwiMERRiU6LMPyIkLFSIUIc5m06YJ
iWV0aLNhxKUZia38yO9gSYHEeBacqtRlyp5dW6btU3UlU5sVB3oFu5TmxqEMCcLFijJiDoEaRhLk
Shjh3MAZ+5BNWnOp2McZRSjwGdGGzqxxI2qYy1UK5YQZi8KqWdSihrM+Dx8h9tPn/8E2IkjadNn1
6pGfaj46bhPxINiYD4FuhOXQ9hmdaIS37VnUMmY1mjk/zPZ5pY3VBqUjLD7cNHLlehHmeJ4bLGQR
E6tn/ItQTfY+oCWDvsrcJ1L0DPtGxs63oiI6w6LSfOtDFZsew02gzRYzDsGRgjNOvpWkEC4+YsI7
qCli7kjPMbBAEsGfzBiEsEPtBtLOr8LugCi1AvfrY7nmQmzsCLIehI6g3eZbcSnRSHtKI9T0asgi
NUZa0jHmeLtwob+2EccOEp46oo1sSLBJLH+kiOkgNdpQgJOM0JCiixw2aqgNErhKEMyrEDJGilyy
8e6IbM7AUCBj2rAjh6fmy0YJBP/RNEKKbTyq74wzsrFJnGz2kSK+F8BUyphsunh0oStj2k1PKQTZ
zRg0jOBTvjb8oe8IKq3EclUuBfISUzHbOMNEgdQgAdOINOW0qk9DIgrPWY8wJgdUs+I1m1Y/qfJK
gdCsQFGuShQlJtt4PaONBetw1iZC6zjCtk5EAYMEUa5VAI1Zfes1myMNacMIQXd11lCdtJw1JMMe
jXTSSomq4wwbuFLDhjPIHU4KFrIpTqAX0HhBJ1OXVZVV4aCFdSF+uzziyzB96lVXkg1GWOE3UZKC
BGJhM9biU1PljQRnEc73UCkSXVQnkR8as8wz01xzITBXhqnlOZHN4c489+yTt1X/6XvIsQVNMwlh
x6q22qSMhLtaqTmtHtux57bGWiui0NbpaprQ9hrOsrZuG+6Hwg67ajF3xdoi0/LGWinHdksb8Lvp
Nsm2coHmu+pq2F5QDQ1gCeNsvQMf+22+DXd7obzrthtxrkMHne3RT79ca5P8Dv3rtRFfsHTR7dbJ
pL0FD7zr0Q1EO6KyF+KH9tbxbr34tE3XXXjhDYebedKHh9754qX3+nnrl28e+eRnJ2oPG3oAoAsA
xie//PHFrySM7blH/PfW3ddderXlhj177avnPvbqa1ce++c5N57xmNe50fEvgMpbGupyhz/AUa9r
DWSf7n4HwQIukH0ARJ1NJng6/woS8IAK3Fow4GYbwR2kGpdoAvmGMT4jyAEULsiHJFjgjVSwABTe
cAEoyrdCORhjGmr7YP6sRz+4JTCI+Dti4IhHPQ8msW4UFF0TLWg7/9kvd0DEoPOweD8gcg2DEbwf
CKsIPQUST4wWdODxAqhBAXpNBCS0SR4iwAcgRGAVaOCEDscHvn1woh5SkMIfc1CKM1QiHvHgBCcQ
SQAC0CMVkgCFHMBnvjCwrothjCIZp1hCs0nQdAO8nvUuyUAqbhKJpzRlKVU5OiIiz31StNooi/hB
KPYPgl2EYu3050UxDtCA69ufFXWpRDV+DpWue9vb6McGPhjjEzmQQg62kYN8lP/PCPmQgjiMQQog
NIBK4pCCDfyhhErcAJGJZOQPHEmPBSwAFO0ExTCMMIwYAOAdlwjmQiICJ/1Rb2ysi58ws6fFAn5R
jdOzoi0Hmk9iRrGJWVxo6PgJ0NqpjlidFFcxS2lAXP6tl6KjXxqVAjjCac2MYSOiGUP6Qd6hjXCm
48ovzcaHBihKFCTAKQnooUcASEIJ4jAEN5tgDHHkwB7iKGo9bKDUQzISD4nkRCp+oM5dLMCFkhhG
JIcxjEkCgFSvu2DXLBo8J/IGkxVc5UIoGrcpno2flzvc5S4ZO5luTwOvPAhAEZfSrQWvlmpzVRfk
tg0jJDBkojDRPl+wp+ecCnf/aADA1k4Vtsk6xhiRdQwaumA2Z7VBA/vakgbVUDBI6cQQmH3Ipag2
nzMgLWQtO4Jf59My3/WhDWDSyZhutpBtCNY0HyvLaAFmWtQeRLU4ay2cbssl2caMt6glWQ4YJpAr
kcBUxugECerAAhaUgQWSIJ8cXtAEOnJzm0NFbxOakIMcKNUG5jwnVBuZil1Iop0L6IE3dDgMOczT
CAAwghHmkQOy9gGysQNuSLLkK5/UQWGNjWzb/LEwWiELszHFlRK0so3i6jYbfiOUZ23SBCOQ9SD8
KFgnaNIQ6GqgCRV4LHQNbATK0nhBNvPWmTb7tc5+FjyhnZsxNqsTYvQqYryy/4EC7noQyJawDTbw
lnCI4VyEcNg0HjZQE/LgEK5sIw8TWRp97OOW0vShAatoikW87BI1GCMCTHJzfFqy5QWhgc57sYli
IJWiPvQlKEfQ8kiYdSGuPEkKSnLIVZCio4IoqSkjQoiWueyg6xzEz1kJtIgsFCMkHZpGitbJRrYB
A/2gBSFP2QYyzrCNNtThBftwwXe7u8KenoEP77gHEHTdBFIYAwhIXW8OkCqOehhSvgRIBT2UDU9Q
vNOdC2iHHPq7wnDoUHzjmwga7li1Pf/ZM/VhDENQDQM0aMXTDbmKIfIAmd/cpQ+jhkx0NlJqxXgZ
zAuZCGwwvYdF98EYMEjzu/+3/LU4m63gxtEJWeycJ/P0Qc+VFnhTYgQaF7nbzVVxy0sYsmhRwyDe
kM6R0bbmEvooJi5OQhubUJI7k8FndBLvSmz/suiSWAdAJ4cPXOTi7pMz2W9clvholsIoQZsEKXEx
K49gDvNSU0XkGc+3gf12mKohRi/b6BYJXvACFrggF3ZwgR3+CwAW5OAdSVgFELi5a/X+Wr3iKEU9
lFqJcdK9EgorxSBzoLBKPHKP8RxGO7gKii50ARRGYIH4xJcHfhz9LQipeVtKnhGYt9wlednInPqU
8ZgTiOh3kfndctPwpadtJO5ekMlSvysdXYfyKA99QxKOu9K7GylTRrnmuRL/dbtw/i+ebzdCuo2V
58hePG2R8+iFtDWrVx2s8YbQz7HDc5cohEA60cA2uJ3zjM+bKEW6/EnEnZTjC792IKm+UvRzhOxv
XzIg8T5DTO6SUsvm9X0wxDayUYc2cALs++iC/9uH8UmFHHiGJViFVVCvV3iHAui1tYO7SlCCR/KG
/moHI+gCeQI7SSiDfFiVodo1YygF8JGD8YmneDICO+gCFrgFxeOUBUG/M4ENh2OJmEMLwIg6zqsM
nrM/8uuJzoC5qDk1Yum3vKhB+KCf5rOJouO5oJC+DqG+kastHvG+GuzBjJs/l9uV3Ii6vFCIqxm9
lVCDp9i5+3MMk3MKtikS/6VwjpFzDMjICjY5uj17PCssEsWYv+ArNaaYlkIrv3j7QtSbQ9xYEDa7
Q4HIw+5bwsbgOQMzhiZogxeogzJQwX3whp76rvHxhiZIgHdYhXfAtU9UuyZQO2KLBxvghA5MhXxI
hTKQBG+QBFjLIbDzhn3oLi05AzdLAC/YRXGQhEnqgS5wAQx0Aa9zgWsDP6OZk3rYlXLbwaBgRAPT
wiZsCzQkiz90kMBoEMfoNsfbiM/AuTOkmzVMQ6NZxGiEQ40wR5R7OregP3Ysvz1ER6MjCeBonK9w
w3YDQhFxGyMMx7tRuUZEPbeQDdmLwuFYEIyDv4O0uqMTBc0DvcfbvAnhm/+ji0GEvD89ZEilOIvw
O8c+qAZSOIOtA4NiBICwAwVJIABJGgZxMIVLSMAl4IMlAIJ3IEU6oiNj2IadbIJoQoNHUQV/eAFO
6K6uswPusgNYK4MX0IYJMwZDWIUEUB/2OwPyCTthBDsjcAEAqCfUqAqpOAjC+A1o3MFGNBlvjB2J
+4t2G45Cc7eCDIkwrBCbcJmR68fqgblQcxKayA2V+8assEis+cauuD7kuwnoCDrcIKG1JLOWcEu1
GB2MiKk9k42vqIu3gbmkiClpJCGlQEOB2Ia3osMBYZHHCJLWAzcROZIjEAfhuBC46BPDkBIx6ZOo
qblvpEyNK80xQ80xK4j/1WxNCKnDR9unvzCMgxABNvkzcRjJMsChF9LKrWIkSbKHl1wCmLyHJMiD
mpwGICAGYghN3YEBDdqDnzwaEiiDWIM1WMuFMigDcFm1PTAEmzCRZxhAsgM7MLiFpASD8QGDc1OF
2YzLuLxM3IgpTxtDr8CMi/KOhOnM+sNNvyg0OJHMhXgQ33y3yzm9k9tMhejMiCiSBKUR7NCKM5hQ
00zN7aNNJeGJ4qC4sig1aBQJKbmKJYFBcYnQIzAEyLIBpECDHOgCQIKTgvEWMakDKagDv2FOO8CT
gsgGO1g13jCGM+iCbEAP0EwTKdizbSABFwAkgTCEJ+UTMbHSujwIEugW/xGYkyXpFqKQFDv4E4GA
BVzplyNA0yJtsByIiZg60jrAMAqziTpAg2zYjR0FgB6lyzRdU0cJE9Z80jjtgzltLa24U5oYrRxw
mbHhhG6ZEzQpg0pJRUs8PCOIJxniBKuSBFK4hCS4BC9AwG8AAhRyl2SiG5rQq4OYUzdhgVdbT0kA
g13VkmyIgGxAg+LwCIoZn2I0glvYh3DYhwoIBwDAlTqwmk31B0vlBFHgBCWl0k4hkNBiMjSwAxuA
OUFNM0NIkzEVCHMVlzJ1CiAV0l1hVKLAOiMggQZItydt0pYQ022QUiq10i6TAgDQ0owomM0LUyhF
ivnAVJO4UzUViAawgf9EcUbbugNOeA4SwBWa2IadGdSFUAJnKaEjnRUNQFdOOTpzXVONUqOXWh2E
+p8HyiXNkauD6qRaxSjPmZu9YiDNeSv+4SgFSqmrOZthAiKiywZtMEpQsINmg0VO8Idd6AECWIJq
WIIk+IZVMIVV+IOD+J0wqIMEEA5YgAE+QJqQ4Le6RMROaDUWgDUwkKF9KAM3QQNDMAbYuawuCAcV
LANt0MrwUQAzctmHuNXGKYytoSj5oVmGMCOvqSvXCaVPyllj8hwCkim6yhqsaSW9gh/SodlTelzA
eiC4ytkgChv4AdqV4pvMCShN4ofNBKPt0QrVFZsFkqU26gM+aLVcCLv/FLwhb/gBAigFPJA2cTiH
afiGS0jeb/gDS2oA9ekDQgiDDS0KvJGCZ0ibbGAVEtiH7hW7rQOXjt2DoNUGAKiAXACDIphE/RSf
PhAh5PmlGdSdtSocx40rYOKlxm2ljeqdMopc1NWbnxWgVkKQWPKKlXrc/TXg0oFdI0qezo0gNmoe
5nHZz00itMKdFdNZrzigChapmN2dbnmB9gxAFwCDlCSASigFdeiBBSiAPzgHmES7JUOIb7CIS9iD
jOCHBgAr0CCiu9WJBCA11NAuf3AB73LF7roUuzWElYIBAEiGLiiDEqCEOhA78xWhNwKrBj4rrRgl
zqHgCd6fxqXcMyKj/861YFNKI1jCYJzFJAfiK9KNXTLaIvxFI899YycSIlrC4yMihiltA0o8RrFL
ShZQ4SgwBwn4gQz4A7SbhmdIAq9FCD6wGDawiQTgA9yRCK/dMOyVU+3rg/FcCinYOhYwgvQsA/Q8
g0+IAHwq4ProhE7ogpIsAzAQBG3oTwAIhvft3zneTJSSXC5KKDuG30zi4zpu3GDe49FtqLNiKIWC
2TDaJWLWZJs14026XbtRYJsFpTw+Kfvpoin9LmUFu+5C0yXYghuQADyAgxFIhyRIgCSoBoZIAL8B
ZQ3gYYGIhU9oAz6Yzz54hm2wARdQgjtIgEl+h2wwhDAwUD8RCBhoGf/0POKjHMo9QYY8MBuThYVF
QAYwoARKyAVPqIMSGB824KVhbl1jBmHH8CuUvmAyPqJWutwLPqACu1lQ+iLR7RoI5iDYTWlrjqmM
Cqgytt20sp9fRqKgNtxn3qVaeggAXghjQE+3DTAjsEVtuAMpWIUMIAAJUAdTGAFT4MUlqJqVmIEI
YAMYIATbCIYZmIEjOSDJCYMcRgh1g4UIOOhnMIasnkS3dVtJzIZt4IM94IowCAMYSIBniABRsIOQ
ZgBP8IQSEJ9Y0CQkMqsh4l87buoMcmbIBecKAubXod34leMtkp9VkqlfbjKvsBmXya02aDVbJQFy
3ac+0K6OeIg72Cz/v9GTNrUJDdCSa80IK7ubS+kEv9EAGxCFiiGK1r4bHQUABLmK1X6Iy1Iwn1gu
sdmTlVnCyLqKq2jtFVMt5FZu5maITwCAjNITZ3ndKisuOy0YwgHSv9EGTNUKDaCYFyhJsbPFF8AV
PriEaUiFHlAHOICDdMgAOLiExznoPpiBrICBGVADk0ZcmnYMDaBrQ8gBPkAD/SOB7ure98QTPngG
DUhrGECGPZiBPciDBrgDMPAESkAATwAD8VGAM1CAmCLu5t5UEeDL3ca3bmmpqiQW8A4tzdusxzk1
6CqyLXnu05JuAyuuPmiCHcuzyOLtPRmZ+gjWBSFunRjvwijvtkHv/4wak9jOK5K9bCtjlDFpGe1u
raoB7nAZbswCcy31m0+AAXGIVHeTzbckDPtrkj4Qbpzbhj1QAqOziBllCBipD2eUAnIr0bJ4zfcr
DJCwN9MYNSyZM/VwtNJMEoT4hFW4WyQEvcyrdPNAg0tYUClBjQR1lT0QNLg4dA3LiCaQEjpBgzqo
g7Czg6R8T048iFIYcHPYghGAgwxIB5DsSYGIANNl5q2Rm832jQQ4AlVog33guvbkPzSIABiIgAjI
AxiABTZYhD0ghDtABlEQaU9AAEoIHxFgg6FgA0OQ9TOk9T0Ij5ZYdE/rg1Ev9dJ0xwRQOT3n8yPZ
iD+POE2XdOOAgf+I8bcI4PQc+CzpaPTCyIHhaHh1HNA61I9Vz8u/3A/XOwOIFpFPXz6LPwJH14CM
b4mN/w58tIkckwzdzPhG37hKywmMnBYYzIj/CMyVm8GKjZIhrF7xC7mbSw2B0BVkOYg7mBOQYAiM
GxEQ3UawCESkE5xFgQl47INE53lpVAq1NdEtm8T0NDwwWCw08OQjqIQe+IElcARTgIMkIIYgYIgI
wF4fr49eIupnDqg9eHZM5Tq3zYeC2YY62Qa89g1YeIZCUGxBKAEGEIQ6EAR4jywp0OLGBPsjcPme
n0ap1xN61AitkLiZv1GkZ4kFgb4MvRo6zLiS4PmRMJGhv/o0nIr/28mTciPLLX8Spo/qp5+TLvxI
QkeI6d5G4VS0jBgZkCALl3j+5MfHhZiJbKwRqeD4abHHyJC44nCJLbetvscKIJJ9hHB0aISM01O5
iFmJiCGL7jcJk5t67jsJ6atB0ux4QPuTOpAEQtb2MgCIbNuMHenTZ1U7Aq9OLUl3TppBg0dE8IsY
saDFjH2OYDzCZiNGDRs1jtQoso+ajSTqlNmX6wWJbGfaSOGTIAwbNmrYzICxKNYiSoKGuugC4I5F
KX1O5oioVOKZiw0wRrVYtWAbpyXPYJT4NOXTPlm7Zj1pUNRFg9kyqkEjlapBEeIKHqlq0G3ErAZt
qM0rsU9YjnbX/wLWGpcvXbxHnvI1WFUuXbt98BrU24dw34gKMIaVArewwad2uRILnXLvSKUFMT9d
fbpP041VPYc26I+zxSPGDJY22Ekjmtf+DIdVLDupRMKtq3KtHdFuQdWFU9a1SpWYiNq4DRrLRmKf
CzAtc9WRouYIXkc9QN3zkoHhH2kcSabt2odYgm1hMu5x22TRfRHx8Q0MHf11kX19JGDMSmVIkksZ
JLTRxhmGwLDHM2xowNMMGkQgAhtleKKNJy4AAEBBsVT3HFVH9JbDa4hNRtdxhh2RTVeSZWaQKttJ
tBtIqKVF2GmLxQiSdKz9lc1ryznmYx/QzeiYc1H2NtlrqhCn1f9qNl7WpFdbRUQMZaxtZxlhmEn2
VGm0RWkjjij1sY1VYYL25mQRNQaVRnuOhNmdaepJ42QV7ShaRGjdCZ1xoKnhJ46JPYdcaik1IMUL
LLjgwjD7lHFGE4T0RUwPPUhziilLmFKaFyMdYahFGvABZETP8MHCfhtpkEAesPQRRgQwbCRsArwW
GBE/OURg3xEnNZvHNmeQkCkLL0xIkyHBzgBLGM9k+IywsDAgSBslgAGAqGrNd0RseDrXJkZxYoTG
lZjFVhph87mLXkSArlhnWtJRxyZgn4F2Y0Ep0TnpWVUyemBzsFXGcJcR5RDvjna1FqfCALtLzFVW
FjQaXWuxWxD/Map5Fl1HYQGWkgZuciWYRYCKchJzCTN3Xh+K6qmRlIvJuRhdtJlXY79JcbSiFCc1
1pwakgFaMJV2qlul0E6pYQim2hgBXrXZGKNBdoARM0wP9oygqhcFlGaWQbAWRMgz1NV6yR0adJUH
HxHB0PcR71gUQUZn5KHRa0vxsY131NZBAhpoDJTthRn2AQsMyBjEgDaCUGIHAM9s5HIlVmdt2lIu
X6b0RDNXHVHUf51BzMiFA11fxKkllZIaMi8tdUlNCwk18Nb1wY/JF6d+kVIDFx2d80/SrFnwOG9k
jBRd5ECbGm1k08ZrR1AIfl7eXcRJJ0pgFK0dZ9B2RHkkdHUE/wlSyG/QNlIAIMW9FNaBUffOUIeS
vAAN6hsJGqRgBCnQJlouyMZT8tcFNFylfko4jRpIIK2S5M8FNngfTUjQG/idgUkSqcNMMGKMM7TP
Lt2zX28SaAT3SYQEolBfQdiHBr2oIQJoqMMLjOACFizgBf74xAyC0Yc7nAEU8eiBOuCQqkuU4kpl
M8QZ+LCHiIjjJLkKSUaOkAf79A1/fnsHjfJAOIuEwRD7kJNV2lAtbXDiDHeInCGylYCSqOFwBvFE
GcqQixN9Inv+wAsxSJCD+80pezQ0SHnGgj8ptA+EUrjgJGf4FOwBIIEJ8x757iKFYZyhKsbIQRcg
WBBDZMMOMv+ZZCUjEsn5KcF+69OfFBSDQhNuBIVtwIg40ACATojDInXIwS9H0gY0kOA04lCgFBqT
QfsViUIHTNgLpJBMfmCPlK3ZZeLoI06SwC03dsvNOA90oARpZH4lSec706LOI4TzIjyDnUHOKRF2
zs9ACVNnkcSpz+i0AQwuECILUhE5g8RCiX24hAR+kIF0JAEOf6hGRkSwiILwDSoYmYYxKlIQDdgA
blo8zR4Id4Q9+LEPmbPIMwwRRjUY4xvtlIIqMhWhEkJwG1p8Biz0xiu/aUMbLNgHAIrAR4tcCZ3u
RJB9MIhOOIZxnAniHX2Y5Sp5ZjU3zOInSbQ6VXyqk6zvLAj/rO5ZVQSJk1D1iWeCxArPdLIzfO20
aj7XWlV2bnWtTzWQRerZ13mGFa4kYaYg7cCChJYCDfOJhURKtQU4ZOAVryhNGNSggD2IIA8JKMge
LrGRtkQkATKVSO8SZ6GRRGCNfDhcQS4BuIKAdKq2ymd+TpONx73AWt6hiTFeu4cwaCAPLQ2GGoq6
KQBsUbBT5WuQMnIl6I51sFxly3XjOtfCluSqd6XrX6DblRGWNUDfXSde50ojtxqWu9fdbnXL29V4
0jeq8VVverdLKH8eqDSMI4EdwPC1MmyjCXHlRA/MkYEMmMILQeDIJWAxgxn0ARn07IMxfLWUT0Qk
DwXy4jbs/xOBPJRtD6f9huY2socUG0QDjkWcIV4TBr1ooA0kCGQd2uAPBbjPp56FRbAisggRFCIX
gsjHidDrV8LSF77Sbetevarf91L3vE7Op3ibHF54Ara8cp3vOAPK5SZXGbxnnWeXu0sSfY5VvGke
85jYCuVxakCA+9iHHQJpAyCUJnHV6MEuXrG2S5zCIBreAxv+tY3TyLbFQc7nHjoxDeIaJAEXSsCI
RfurCCRAA2HYAx9e42KzwEo6BolAadjlHW3ApBPfc19wMeTZkcT0cvsAgxK6YAT3Yle+YS3zO51r
ZfxSFaxzvrI83zzl+bL5vVzlr1O1zFatApDXW/aukn2dV//C6uu+xo62Xs2KTru+NUjUYe98dnhn
IwDxDgZuJ9oKcIoCvOLBgjtDdu4ggmAgA2btwrSlkbEHDUeAcflAgzFypYZLfCIChhBdrXKAhmxE
AKN9sJUhXsCHGYQzxrxByR5EkgBmcqIMMJlQTw3h2QRoWAQzyAMbxFMGF3jDDnuMbq+fml0qq3O6
135rgmiXEbh1GazUPnOvgY7XPm/7SmI+L1gTV+amwnnbx5Z2WXWO871Wu9vAfravtQ5GZ/OV3Noe
5zba0BJPsaAN7UKZQabRgx+YogBw+MY0nrGWLYqAw7UOwyogvhHT5uESZsc61gsShvyo/BIfhQEa
tvgXvPD/wRA7fAEdJVRChNukbjDVEgCUMI99VAAAfSgbeg10T+p+GdlV5/lI1Hr1iBAd6oXVV5bL
TXWjV7vFUw3g/0ojgpg08yLje802UGQRDTJSA9nY7UXE0QVmaZATdBn+TIqkBAF2JfkZ8X5GFDg/
5mOwfgOUSBOULxFO2M9VR9h+HeymBFH4o0jgP6ENQolhAEjdeyRwFfglDPOVjfNJwQrVwRC5RBsY
wkmogT+cgRLQTqncwysw2B9wxn70hEF0yDYI3tdtF3kpW1dowB60hkQYAizQyawIEEzExEyIjSEk
wDNcmAYAyOUkQDZogySYiLD0ARvUDwmYhTGYXkkYQxfk/0YiUZMyZV9EaFD8ScT9HQ8J5F/4xISW
nEby2UcDqB9KDOGBGOFZOSFdHAH6hNIRRCH8UGFc+A8/dB8Rrt8dMFIfbOE7CVNueGFGpF93DeH8
RKE0iYbQhcVVEMY27MFw/IyQ7Ily7IFkoAdd3MFqRIZjUEdVbEMeSEYOlOD35YEJNkfWuEljWKJb
tAhK+M5GvJi8RIVuXKJF/KFBZKLqDCL+GGIrWgxHoKAP1YGmLBYJiMMIVQUxlMIq9EAppEMFnsP8
sMEiLItDZVu4zZlWSV2Y0YdoicA2AIEUdALm1cHzyQQaIAMMTIM0FkQDgEIQGQEAZMdvCMk2vANl
iEATcP9ibrzYEUDiZUhilFAi/rAii3CEICbHPr4Yd7yDKm7ENiSAZcCjPF4EPaKiJK6iZLiiyNyJ
JXZiPqmGIRAkACJkRCik6uQADEjGHawCZUCk0lRNu6jJfLydqTWkQdjjERTTaagGKfbBIbYLczDM
6/iFRjSFjwjKKbrKmhhMa+jFP2qNUxiMWBTOSjJPSQjkUwwQg1SLC5RBHaCBTK3PaeRADyyANGzB
PZhCEKSFCJRRXEzjt3GXO41hnEUZuLVYDiiAtdjY82FlHtQNX8GCHcyDN9wCc/WBAmQHv+CjRYxF
Td4kw4yGx0jMjsjI27ULUkoEMTSARhjmk0zMolhFk3z/RkpmhE9SSe1UykVMZmWSxMKQBdBspnPE
SWYizb7YhWPJBU+Ozrb9H22uyCdaTR/YQIKozk4qpruEzGa02FUkCZe0hssMZZXcSdX8y2vmkyoG
lw3UARgsVhlkg1lODEdwggTcAByoyhYcQTXYlJrxVe4Nm7B11wfKVQRIQTZwAkzIxBmgARDAwDOU
EywYQmnAghGwgB2YCCwcZZes11cYhG0KDW4+BXK2YlewpoAO5fxQBpe4SoH2wYH6ZHFSSmhsh4Pa
jk5aBr+E31adTs2QlZ8sJ2YYpV9Eh5xERW+YzIaGpipmTe0USQOcxFOsI56gSV75pkDKDpBWjczs
E2Ty/0VKNMYZptpTqEmdYAxm3oV9NM+bvGjwzAdzNI4RSAJMWN4+zUnZAMACkMIr3IPb9MG7KRs5
gRnUnSfY0V6bScTE7ZQGbQMyeFaiZQRGpQQA7IMRgE4edMJncARk3oUa2CiO+gbD8KicuExYSJKU
uuhyVgyNTA2WGGrDBGeT7oiKaudIhIx0KIXQ5cufAMc5sShGlEbugKZz8EvU4Aa87KSWdGpiJg1G
HCIiFszJ+GNFQCWlnEbKcJWoVoUa+CRBsMyEZqax4qpj+SMcMSqcjsSv/sWQRkSshiaeAEEbsMQ+
sMBV9k5XxM7C9UAlmAIFkoKLGBt0hZNYdYSGYYSh/P/Tx2ndtoWTYKUdCWiD90hBAwBBHgwXe/HM
EeRCOAAA6KxFdrgJ1azL1OzJylyMrk4JcxZoxEgHcBrottVFVIVYkNxIRiCpw66M0MwkpbDqxL5T
sBbNVmQsW3JsGC2MRaAFVjEnvl1mVdRZRKCB3sTOfbAL7U0FbVJNW4BJyhJDar0MauCmsCIoQ15O
WigA86BVVWRDb0iShVqEPcYOR+BF0R7NbuaVW3yE0YYtv2jYZOQsMPJsi/msCCgF1yDgENVBJyzL
U4xlzxgEAPQAEJBCBixBKSSbdU1EGCXAHtycROxBG2isyeKJWRyOQGJEGBQek/1ad+XAGfQWhdDp
O8D/QGaVW0EAgAvYAeg0QNlQ7f/BTchEiYts7WkgxlUkranVLGzqDT88RmGYbpeuju0OrRrcAVj0
hjTlCdhybXPAbtM+LUpgBm5ijO3qU3AQiq3Kyde22Ae9wBgSn6s8SvtxxxkYwR0cYjVQiAjlExDC
zAp1QTT9BeQEIUhICPjQxQuIgg1goTDlEv5sr0BExDagUjbAyH1okNTKCQkoAA5NhhS4AP9sBDH4
UknUWDaogkjQjiD4Q/ua6RnsTzEtxfTSRbQYwf3m0wfZJoZtb/caxPeegT+IhDGoXRmwwHVKgSHk
gBHYQN/GTR2kHwHcwxLcQymAQlpMFwDxwwx8hGAC/4Yh+NQ0RISJSYFg0sXDYUQerMJSRMQL0EpE
vAMJHGhJYFRgFNYKfQ8Kcd6PjZR4osHmdm4FlJ4gBPAAJ5AHRVArlRD6MpNIcAT7Auz7xi/+zK9i
WC9dYC8INwEL7S93KEEFfBB3dIIdGPKcvLGopu8cH0EET3C0WLD0Ykr1mk+q5W8q8W8CaxNGiEIO
FPImIbIib4MCgMIjYZg/dME2hKIN7EMKzUkFS0Ex9d7OIU59fGBfdVmq0cfTWZfrdRV7+W28Wtm3
IptddRtv3MELzFyESMEa/cWVoKM0UGAUWFwYYXMfvMM2GIIxSN4RwIIxnMYz0AYsfEMYoEEPRsRq
Gf8EDJzmxalRRgRLwWmEcZ3SsWyE4GXEDj3O5RqDygEV4CHDKUVzHwCAUVRAF5RTfS1ZMa9Z1qnZ
LZPX7VkbLyNedKnrfT3jln3Xes6X2GH0RjubRb+lSQ8WuuWXtYn0MANzSx/bLd7YUXEjFXNVV26B
PWyBF7DTM5SBpvWBh21ECpbWaR1BGPhsREQAFP+FIUiegpxWUvuRfTxDTc8JxD0DbD3DTGRUH7zw
FXOjFAwEp8ECWYPLXWYEABiBEXTBOqv0Sx/dXWlXMJ9d2Y2ZXLfXXFeZeT7jW59dRQ8bk931c600
YYP0fnG0fVHVLbveMBeED5HAUVlL85ZEM/bBEsj/AR4UQAFswTTQ7c2xwSW+BiFUw0jZRRjQyjPQ
SVeo3Pet8x58gn3wTT8piMsKiIYlQBntwTe0BjGMEUokUBlwAoXgUcjl06dBnGMTrFEc4dZ5NEk7
I89RV3pK2V539LI9ly7T1WGfdHW3aWBFWbfVk1t9GVxTHVMRs75otFzJqzBztHl52+2qN85Jo0UY
AmQH0gtg5zspUTBgRKk8wGZLQ6plw0kkQDUYwrqIw237NlDnwUlcQm33AR+09RHYxHwkwAX7TUvB
VFV3YIstjEgoxojFhjdnqwaBcgwWarN82hHf7ImsNf+ptJo+mZIpM40D9utFW/hs90hLF1tiGbI1
/3ZJmLd3H57Vube2Adu3QluZYRt+aTSvwV25yZ6MOxeaFty9ekobNIGzmEUzzp1mR8FSm5beJA07
n0RKaXhp8QHutfOPQJwGwMCydIWJ8fSPGgQfCJ5kUMYepARB8EE/T2EuNfUcexqGIAdC20EX6CjY
Eco9mcXqSfTVXVhetTSbQuvt3gfqCXbSARal5/hzd3ekK7mcdbQ+SeNrHJ6Ng1uZnQfqbd26jKgv
P7fVFR1JiIAyu7qUTXmwoRMWsfBO5YGwHUEC9AAnSEMBlIIjmJ4aLExv7IaTEntWitFS94GJZcSE
R9c2uDZBWMQqQHVXBGhTEcMewEBKQAY7z0eHHP9BD+bSFfMYwnGaBnDLNCzCEcfLEZyIcks0ubGe
pPsy4PqtXJ+H6tW6wQ/5XZ3Gq2NHdzN5pUcXvBr5lKUZdkxX8gUUJUlVH/jSfKiBEQ2nwpjeCM1f
GdT3G85kF/gqP9QPJ5SEKAwDHKlBNqBBy6eGHUjVEajCTBCtQRgCiqREG2peob6i8qE8zOQTN9aB
0O0foXDCHfCSzNO8tN78tnF8wtSBP/TIhRnDAmXDC1Tl4TotynjPC7xGKfRAPCT7PRDDHxw0GmTH
aaifIxYEDLRUGLTcHozz4qwSDGSYRGjRSFy7RaS5OsGCDbx6HwTLSSxa4M+geREhH2jTFZ9BAxj/
wzvsAebvwSIM16lpGh8gdJLBjs9H8fEkffigwfTxxspLQct/Msxj0MzXfEH4khr0RrOnvPFJwRPS
MYUMPWyY3kkkMPS9RjZxwiO3wXSeXkEoEi+dYYyPRHlcUJGU4XzUmO6fGwnovO/nQNGHRsrDa/ao
vPkFCeTwkuW7BRbCgIxkRu+Uop1IAeTtziv6V3vmhiEAevUcjyo2ASPu0xmcBkCcUdNnGwwbfY70
UWgjoYZtfTQY43NGIcJtxBS2USglAUWFRwzxQYOwz8CRCtEkRBMhpUI1Hl8eOSJQIc2CBxMqzOZS
SsmeCD2e2WPIWBkW+ep0AnLE30YNCEUpJAYA/5Q9e9LOESugMEJFkiQxJhgY4VLFIwn65FnVtQ8x
DSDrPAvzsWSTbUeM3ZWpkA+JMsgGKnwGI0KdnCT3wBqoZttThTDQulToGE02EiRsbDOUJ8GzBHsu
wXj2EWRCAAC6dOFTMaSUhANzVNw28EgTGD1zSnnKj2LtPR5l0uxD8wxGDT/xwtj5WsrinzszIuR4
5nWfn8M/MvQ5sPnCkjCp9zH27k7JmgOPf4Supid75zo/arTe0WzIkx/tf9X9nf/3hAm788o1unDD
zrqKlkMoQQP7iCon4KTqo6WaPrrOusNgwg3AnABE8LABKUToviMsxGhCoCr0qjcAAwuKJ4Q2JP+Q
JI+uwwkhYy5joQwStongiJOui0ohAHZpwp5S/vgKhmAqgqWPGf7Lwxjr8viKJD6MmeuwBDZD6zAf
EXqHH5eOeCYPIEQLI6Ew8jCEBK8q2qOnbfb4EiOF7upjjz4iMOSMNkjIRooe9wgjAcI2c4ykI1A7
baQ7GZzpI48QVDHFikA0kD3pHoTTwvYMvG5EC4EDUYoxD8QuxgAhlALS6ygtkEbzZkXJrBIl5LCt
XCsqlcUQKTysjwQTgumkbP7LAcNbK9KuWDjhw7RXrxaELlX4/mNQ2Uo7tXXGrxKyFiNKIWy12Wiv
HXZRTY+FkdIIpMgmlzLqyIaPDhn0KAwAOJH/5owH+njlIzUhikAjcQhWo87RhIXW4YcRCgziib8a
7RtFoeWjmrSOUMMQNEhoQ9BtkElMjSM00ECNOw/bo4vTXICT0h//g1BdaYFVNydrf/LV0m5VFdVS
qSa09qBo0Whxo2mn7ZbEbtVoN1ihv9XVWmoFZPq6q0fEN7e9foIVxnR7u1ZSOM/uMKHYcrrvwHBl
zBrfmj6cNGsrhVvaO5yxTbVA6LzeCGzBQzxiInpf4DGPZ/vAiUSF4hmGkyYeKGXXue4or4/P+nCy
osUobtirhkWn2OGcMJIY2oSMOQIGhQzZBtA2BgWi0MNE30aK014WYa9UvU56bOTe7oNtb5eG/5tB
C8ne62jgKAUe+Nj09rutx3VOd8RYK0oJX9cSet5unDGEdHy1U03wOmKiR7d6f2CbLHqKAqOe5ors
9+podGcmvhN3vwK46lnrR6RpSQFhxLwCcohVFSEG8c7AD8b9LzgB9FRF4Het/fwoG2VwQT7OMCXp
AEs+VLmBDWxgjz68Q09HEAGqVGc6GZqudDO0obBWY4w/0c4YJYNFDfvAB1hEgHcAmAZdNJIbpekP
a8DCXkIoKCkRgGgnEpuf1v5zEpkUyDqBSRAaHNMenhVLgo1zYPSoaJ7rZFBsFxIRaRSoRSZWim7D
KeP+RFBFK+6qY9lAT88Cc6osmuUMTpJUQv/4IR+SPIU6DzoCMTZ1sj60QQTNyo2lMNKx5jAuI7QB
nnxiBJHojA06xLiDJz81Pu2QjY9q8CNEfqKd9LjuDC+ow46yYYgWbfEpURuSJM5wg3gYQxzVuBOq
VmdDZS5ThkD0Cm3YY4x48RAIi/BcMkfTBwAY4TTPUIMXCakQWFjoJSp6ZCQzUsmFXLJx/+HigVLX
neNUECGgNJtHxtmHSobnbPtxpd7Opk8FlGQgzvrbH88DS3oewZ4g2tgkzSLKRtINkmGz2xE+IQ47
kOAkaJCCEQZFjP/4QwpJLEkbFMCJ7kmhCzkoVRsMA6AcsEBQOTFENoygO5kcIRtnCJAx2mD/hxyc
xJXZUIIkPQrSizTkDGdAlkLEkY19SKFsLyipeYyRjS54VCE6dIESFNmHF6DhBf8xBhqM4NOItcEf
ryxJNoyK1I+GdKRXfU0dnEqSytSBBS9ogyHGaRmJ0Y4EA5nKC+xxBgIQA1JMOh0zIRvRyFIshgpB
xjRt0ABD7KEaojvMyV52Go+g4Qx2yCtCOKoKlkkzFzWVSU9/GtShugSuR/2PyEiAOt2B9IBtOENT
XEKCqw4kq1047RE4qpFM8lQKhSUJ7Z7aMba+8gjb0ChH4+OP3CpEgiQ1qRqEC9ySCFcjxNUqV8Uj
CjsoAUQ3zSn4eOpTaE43MKSji66qY57R/yXTSuBalK7QZr7P9Rdt/v3dfg88tgJLdmL/qWGCC4xf
/UqsY31YRSdq+QK/TumaohTWNACQijPkoBJWqqQ690uXya6YxRP7RmXgigZDwOCHDsOYNlGz3cfq
VzICRgjLnklgBoMrW/vFGIRTHMNsBcaTj7XvgvNLYVGaxbPJ/J1nfaxiZw65xfxV8cMe/GUaTjZb
uqpsRJ1ZZC+DmQ8NeAELbikFtoiZNDngVzxsAISxPVnIQi4dEA8srAqvbsumqy9EdNiJbMg4D894
y8M8ybth5JfOdE4zxBKSZTCvecebBrOamRlmLmPaSoJ28g13bD5AwwnIWoasmnG34B0ref/MleY0
gGWdYlV3tQ0vMIoCVhJhOA2DX/5IxTRwjeIUYxoWsFDZM59xiRlAiw0J4MNc4ASLPSSg1W5xNjJt
3WCS3NQGtDNEBBKgmBiq+jSn8fSTC73sTo+Zzyk2Nau/XG9789e++n53rUcdcEtbub9mFne4L53r
0Mka1Af3MbwXTuAjrMIY/qiDhjlhCGGZLzDEGIbk/MECkUKMDSxsmTE+JrGBuOkMJMimQhKwDSMY
gtUGAUBkvFKYXBx5DyRw6kOQqYZPGGKzZkmAobzMh5L6VDPblgsssM3g09gBAKcOt2T1jWtOHzzg
hx6wZB8OZVKT2tT3pnSn/2x10nh6XVT/ljeZAw5qJGt9V5NRO7/vHnc0UwwGaGhDGcowVppX2Sun
IcALJCEZwwEB28TYRheyxYY8cCYCXbFpoaDOhzr14RmVb8OeKqKBPhHiDC9HdB62YbPOJ0ADbJqz
Gir/jcqPRg2wOIPuHPOMkHhFJLBFA8r3EPw8zLkk1WjJPtqNYP8qs+G2jvW+vQKpG7vay2lPe/XF
DuV7r7jhzUcZ9GlN6sqK7inPf/6eV3dkiGRZ05DucybnTffx75fJoQ+iKP6u4W2IUDLQwggAhoEE
6oAeiCEBxKEkbOcdxuI2vsJ21Ig22GAbjgghPgH0DAUWjAHnXELbpMBzAqPZYKAJRgcG/2hOIaYB
jMSpO44gDEpwGwxJhPjgHSLgmnoPw34vAvhg+CIA9BQiDJBhOYjoZRzDfMrvYRyj+ajv6+RNA9jv
1Qbt7cRM/taMCQltyh5r/uCkCJPQv4qqDR6tD5rACFAFkfAKWf7DEKqOLl7gT95CJaquvtqg3KIO
DCHPK4whDbunC54JrrwwJ8JwDLtKD/+DGF6gpzwJDarOwfyh5eqLpHJrTPqouThkG/BQuuCqvh6P
wnALdY5AFf5kV9SgDNWAD7aBBfziDNAABhKCEvWLoc5ACYYEFFKhDvLBBlbhGYhhFaqkScJgNVhj
2qpOAbDN2SRmFWAgDNQAGT1mD/Lg0P+O4BIAQFGOYHE250Q0YCi8QlHYIyfMRJJeI0+yqQSDaBs6
wQZ8yhhwsCCsjSS8QQ0SoAkqKQJCq8Y4yrkyork6rAkg7zBIwB/a4D/UQGTcqrq6QBMtA3XEQxB/
rBBpwg3/axHrgLvwIg3h8BUnsRID8hI/IhPNYhMjxBgU8pHI63MwQwGY0CHhUA69Qh+F5Q7NIiOz
wTHCw3jwJA92gmWW43FqIw/QiGnQUYAoZTZKYht4Uj/yIFPQ4Ch3ajhygnqI8iY30ibvBoEKYkJI
RCZ5ySd2ZUDO5iamsjea4Cj1y6BI4pXSow86YWf85AzgrA6M4XW24R3K5VyIjRNYwB//MOKI2tAQ
tGQbRNA8+IAYOEwcAmMa8qAIxfE/miAx6K+Q+g/m8oQknsEXzyIBckINWich8mAkwuA+puT7+uAT
AiMCmgCuOkHGcLAzrA2auKImGmU0TKqR/EkoGaMoSYIroQM5wFIsA4MsV1EqyeckqpKBys9V+mAz
9oeTPMIryWc3QaWdRug3r0aewIdcuioCgFI2FoMoy4ZKMkU3g4U3FoV5ZvJqriY8iOE8666BhuZn
mig8ywZ74MQ86UghxAt4eoZbJEQmf2YgioOTpIeKKmxr4kdE/CRxeMQYJOZRNiIw0CAIAEAS6kAS
TE5NIMVJMFPFtkFL3EOc+E880MYY/7Jp5FKwxuAk5oQFBh4iIZ6BB2GvItqkJABrIPIEGWTiALlC
h7LBBtAgB0UgZcLgISRDYU4GFtoNLYQSe6xzaE4GcAbkPxkkQHfmCenTfe7zOiAoQrooZ3rDP0eu
J29zSiWmSkMl09TzTtiTafpzOL40eW6mQReFQfnJISyoejZFTe2JKQ9sf1IkjMpSQDxJiXbFOr9m
Z5hmRe6jjbRSP6+Dp7KFexRCWb4HRv3klgrxQ6Nnf4ojQlPBDnxxNb6wxlrHLPggm/ghQHpxUXyx
IvgBDXjQK2AhGzqsIp7hRDZn8DYH50SvIkgRIt7BMYwBI2DxWvrEqVBR89ZE91RNFf87ZpsAYBWG
Y4lWJE+jh3oMRH3MIrqWx1MMK1/043esZUHaR1M/x0KwVT0elW/gFCNWyUXslFQqIqz0lEP+h1H3
pnjSZVjc6W5K4j6u6Da7Z3RwVDKEh1/NyE3z1YmQI5UClnDIBWgs5Gjmhk9HwmlAxFii5RkbIGQK
Uc6+wly8AwBfwBugNYiskDLg5BMM6SUcI0i9ogQPAw1Mr0kcs2GmITIFQ4vAxCVWFfVkVJL44Ckq
VkjTwhCoatEMwUuarWBJAgZoo92e4ZDciFLcpro4RBQc6Voo9mMrRFj651KqR0LUNFKuxVoPdmK9
omILJ1MipY0U1UDm5kSOYGDNQxz/irBGQmRTMo15sPQwsjNEKslcmSYn8jRKC0dTCuSBCgwmVOVN
o1S8cIN+3KhB7mRF4HZLo1Q+uANiv+VaUC8b6qAOSCAHdjFnrGVTXeAFXICF+KQPou4pHA9ODCGb
NOCpXNcYQG8UB4wxNPAjxmkOKyIBGuDQuCQngpYujEGd+OAT+oAfdMk6nndAjLMPYECa4EoKNK8t
oG5FvyICnvY09uQOLklS/FPFwspGpHeJRmlznUhTGlc9MQhTMAR3TndsWkV9IUqNgIZxytc/58Yj
Avc9bSZP0wZze0M48iYq6kuWPsVzfuSPUGcmseeB6usIhMQrhJIubHcmWkRiFFjF/xJkG1HidwLk
KqNFnqDnNYqjVy4TJp6KOz4WoRTEJejnJzRgMwXwBURhJRxMfC+FfYjBCBaAHkDBR6ZxBZ8hGCLg
dTTATfrgEgZiFfgALXJQMNqC5mLwMF9DA96hDtAgAVhPMNqkDmbMaQVDRV9gFSTmG6RgDwiBGO6l
vowRFhaBLI5gKPbgGYxhF6tkDyzPdY32erNXDZ7hGUpv0NhkNNCQ6tBilXKzl/YDgFyiYiPJhauD
i2jiLA2VOdqGhOvLn+6DGAZqPWVCDWwAxWaynN7qkmMYlkCYJNijl4REPuZJKiSYK0vYgqElg1XZ
lV4jG3LgTUQkB7pACgLkJcoNRv+iyg6ASpzaQAkmarcq4yOUQCOvWArsAK5WkQRcwJhhJxtMa0Bc
KZg/Ag2I2ZgDowFsgLdyog6koA4cQxzOwLiqaDiy4R/vKgfK6yPcOSIhwmiNC0S8OBsy6WMAwAZA
xOcoCVLw6h8nowx86mMso17Q4Bua1xBsYKsABzOe6jRUNxsWcTREoHRFQCS+UDAigAX6YBqW6NzQ
4JpgIQFw5Az2gQVc8I4/xgVsYMa+yRhcgAWoahv4gDbKRBwi4BM6yyx6MQ+aYFUNRyQ88AU6sz6O
tkcbTXbagAVGdQ1dAKLRIAzmcbz+ZC/UgBPu4KhcAgiwGa4qAq82SSEGuqAREaH/c0KhReBO1Jmd
4fqd43me88o/D1Il0MAObOBqBnoyANqn2rky5PqgE/pP7loh8loKJqQN7oATPClkovmjprmerJkY
jDabn2obuNmYF5ugqazeJAxaaO3Mpg8sEOz6YES1obAhFqz+OAQhb+jApKzIfDtCDuOGgzl0b28X
yQ9OtukFjOCPwa372K7C4m3rCq3KDsyitazIjPbnsCQCJCIP+MCMO0YDqqH8AIDqYqjJ+i3IYI23
9261R822kywbs3B0tmwpH7PM7ovhDI4uXPuxdi3B7BvtJG7AIIVDzkyS4C76BDzWym50BCzh2sLr
8JvrwOXMAEwkYMqd99jtEDz6/04jF4ZBHL2ikgDMmVKnz9ZO4djb/WT7/JRPh5pKMwgBCL7bm9K7
UaJb4QRuyAx873z8Ix7c7nhcwSSsvu2tt2nowHN86/zvdHANySjcxWtbS6uwyscu7MYuCj9NwZvJ
wQaMdUpKEOIwA/usYYhNEpiZx9SpksLP0LpMymdIdY6w7tZFmnzq9wyBEBwNy4eE6qzQyZcpwdpP
x3WNyXN74ADdgWZI1ACOyNkObQiP0OftvQsOCvFu+QhdzbAwyxls+27N0inGaNuAE8wtvSXrNIzA
BYj2tRVMwZd80gGc0SVdhqwXDdBgG2yH1UfHWfM74h59wHdc05m8/xpu/mRby/837dgjfchRzSsg
cdKh3XSQadVYO++uLtqj3ev8G9SBfXVYAqY46kMdBhCHwQj2wQhGectIdAuHvcugHf407TBq/QZt
vNQUT5uojqyxD8ULbNd+vZk4/dLJjttfXZkKvNKo+7l73cfNbuHHTtu7/TIZbtnoztKwsOKLHdEN
rMCQSQQ+JmSEa1WVcL+IyAVAoQwm/swcnvmuHcWPXdHZnXVQMYTesnfbjiS2yZ+hj8consAg3t5v
3vxg/edVzBk1fuKRHdNr7bPWLOPjFA/bIlDeBCDbAKb2QgPcObcCgxVHLiCbyzzSkxE/turgT+of
aSP08KE0wAZEoaxg5BMAQOL/48uPaIMVSUMAVzgh7kAPj1BQlGsyRMYfDsPu/8OqOuEIETH6pH5R
AtLqG6JjgWAbFIAhi06fWPEIzZGWy/tlskEs9OrLQR3KN97L+yRqpXzZc0IDnmECrwxOwoBZ73gz
KfvWcbf8Il0eAcAXYUG4UJ4kkCEN+76kBj8NC18KDr+coZ4YFn8Qe4ruLaISkQuvlnLvpyy+vHDs
dwUjzB5N0x75R+fx5L75v+n5qUy46oDJfK73E+L3hZy5HBpPiB8hrComFeITYOAAPccjNIBS6lUN
YkOEAeKIlD59zsAYSLCPFA191GQjeEZNH4EM+3xaZSxhwYpnCEpJ0HGiwiMQ/0miufQw4ZEzsBqi
mbhtT0iPJPukjKmEIMkcGo6snHjkDkENaEhKgVFUZ0hiCD/BENenZcGhM0OqydEQ6xENfLaRyJbN
0LY8BJvkQWi050qSAOyw6FKRWEKJEhPwqahSpEa9EmvqTCg3IR+RYYDuPUwwsEY1EQwZ4hNh7x4Y
akgmgGEMRp8EsIxtk3IGDRo+30iq0SAib58mBLe1bUPw5UQ0ErdF8Jd3oU+ER5NOXNr0aVSIVBOy
dAlTpkYpNW/uySlyYR+mFS9mNC5xqkKQf51ClYomAW6Vx9W8PBJz5sjZRkkeod3H9vjoanMYRVrz
5/SBNdv4PVOTVn3Y59MdPv9hRRBsNQFY03hHGEPSHYHN5FNKRimVX0oe6XQeQdmYVpYIJKmiUUgk
5dReQr5pZ1N0C2qE2xFy+cZfgv/VVCOBQe1WU2Oh1XFGHpolpMp/xhHUBQD7AKDXHs/0MVgfYWxz
WB4k5KdRHqIZU5hI6PHRJUn88GFIQtcJto0hEWQnESwR1OFTXoZkl4d7DBnSxCIEJaDGHu/0oVkE
xmRzxjZoEBJmGDDAIFUfe7xAEACSyuYfcQnVaGlBfsU4I456VVoSQQJ+kh2JR4qk4BH2qWhkphX+
hRaAOmnYn18egriaiH2YailJsFla1XJ6sagep33QqBJCEiHUBwkizWQDQaL/XJqQCNG6J5tABEWb
aa99QKeQXrJ6mNCvF+p0hIbjhlsRs8wyBdg2L/YhgjjuqSdbggnRqmy4+pIE7YYEYSYFWGgYohm2
8dZ0bVsuAIBXmX3kceeZEuWxykvZZZnHHhHU6V4Yo6mpURMSx5eATnxABgMfeXTJRgKGlIFYlH1E
ENmxpnUoZQJHwPKMIWhkg4ZnESimAQwYV9PHM4Sw1gcASSJkYo36EVTvvLFp9GuLOvXLrLMkcduH
DX4N1C61iTGLntbedo3puhMhJFeEKqVr3Nl9pA0wcbt5qV7W3ebbR9caen2rwOuth2BBisFHEK+8
qZjYb8JO9OGpNJ3rargX//al3rgABibFxg9dSJKGaNm0MYJXI76rpzRZymweEZzRBtFo7PGf6UAx
14chbRlh4R4TRcDQEXlkFzIhGrl3xJMN2cyHkwRdItRWjtXUlZnbPKk8DJZdsoi8BGUHiyE17VHm
1b6pkYDPR7xjDGiifVJn5cRoQAhDsByxpqhNanOaolZfpnKu1LVOKRo5XOb8hcBwga5EC5KRR3xn
EvdYTm3palUDD0M21Elwg6HSWdtKOMK+/U0k2dgYWuIGmHyRDXj+6pqJYLcqr2nIbBpZkYZkIxcL
QZBC2bKUGshmkzi9R3P+kgsNZ4KWzNWmRF8Tl0rypTrZwY0PUujiaMhCEv94TWdxp9MAAFxgBCY9
SXrvkMrJ/jKNOO3lGX0hy2kSJhidbINKE+neTlTChz8BcmNDsVkEolSVmiTgGVIJg9C8aAzjnS8h
2wiDaQZzBEkRbYPa2ldumgMiPvYKhomRodrUoJ4PKaxbdFscD2uCBsX8sHIW0toq53XEBsZJBK6T
zQs/CCtQNiQ+VMwUKv8SEZJMK1QOmUgOUqMBtg2kL8ATiFH6skxPUusIqPRgAY+pzUvZkllJlFZ+
yFm6vT3RJ687nCg4MpcbnoEYfQsV3t4jpm3wYVBnkIIx8sdKuswkSUuK3kRasgdL9gEIqyOI9PRC
kkbxYZUECQMfpKLPhAj/TUWVIUkenKcRPioGFqLcAyaZlb0j8OFJFflMDkTRhOrFqUuraRSVJAWA
PCwzIpgL5nIkooFi6eWdmSKGPCvTh2w+MVkwwtE5f7q3bJLrSNxcl3oacsOpitNV5HxgSmSFNxdB
FZzkwhE8+1A/AKCBhi9AgxI0SIw24G5jbUADCbIjDikYQQrcUgMJpHBXncj1rbCUAii6qJO/Xqk1
Z9grWoAEKnGgAQCdgMr52gDYwKzVCP1MbCfeylg7nIFbR8DsYhML2Jp8BgBSQFBczwAngqR1rabJ
XRs2Vtq5JqQOUvBH0j6TDX9GgCSf4SxpTeuXfXTBDgCYkkb2IEm0/iUh/5Cabh3+wgfxpYksgomM
QB56iTOdTKVA2MuZEuLciewBjDZr3DaMIQJLPkh3BwsDLOyL1Ofx4SVJ6gJoGwKW28ZGr6CpiV/P
sFgRNEEKXejsdOQa2wcxOAdsdasG1WBazaJhGGfIYR3QUN0jGCIbe01Kus7ACb18RrRoUWxgiuvg
2QJPspS1bEMyPGDOomWwbFKCbo9F4HEd+LSrlUK2gNTCYU3XS4h53l5wexgoq8YwtpoI85Q8ZSdP
clhXRgw3sawYLS8ZonupcpWbnJfsGMIYaxUuiKocZpLsAQBpREMZWkKWMETXGGFW55KlMI2E2O54
wx3KR1rz0ARQySR4If8Ed82kGpElxGMNgdBE1BebVTTNGBEAjRTSlN1nLHJjhnhoRnCK5r9sjBiE
xHKWU83kuSy5y6n+8pY1QgxdYdkvBvbyYfxCa1rDWtWAabWS5YguMbs61k4+85IDg6Uy50WD0l7M
r7XMa1/byi91G7avn1ztv5iZ2RpR9NAKpWlcLztOkkqSo9TwjI+ljCAXJeSUqA2led9sSIuKU1Ar
Q9Jn1O0ZZ+pETwgSgUvI8QiigPI0MuLRb0QF08/AZBhecB01fKaLOeA0xWbAJ2xtjAR8kJQdUm1s
ZS97mGh29rCyLe5hw7zZ5G55uMk85mnDOuWvnm6099Lnlee85jpv8pn/o31ll3tb2tHetsqfvvTK
Rf3lBBFaP7fhvKMbvd1GaBIfZUaCUrtHDZJONskIQghBNiYhGsiGVCKpk0U8MUwuex4aGLIx9pkm
AoVhDGSQdwQYRKCSZuqiFO5gDEJwZhXLI0hnKjOlF8BCao3K+czHmGWlX3vo3/a5znnucmGjOehL
p7bmp2wr0htdzFI+/dRdH/S6ud7byO687W8fdWDjXsyDX6s+8cJ5jYChLQDos1w0AAsyGaIwYfhE
G+zw3kY9Q0iTWYUkpwGmZ4ThEmAiSQTeEQZ+hCEB3j0CEBYJi/VKEt4wIPklUlYTGNyhteKrqLxf
vY3QNCFNq4AFLBYZ/wZ6FgHS4399kCRMAnW19zyqZ3Obt21Ol4Ayh2b8IHRcBmsKeHO15nIb2GSK
cXkxB3Qslx2KIXqIcUBFtzcg2GoaxIH58Wb41nMXWHOrphosqHNalwefAVOGAH8xqBeT1wVdIFUx
SHbfED/yJReX8AlcFF1HkAAKIFd3gBcaEAFyZQPLlxD8gAb+0Aln8Azu8Q1C01aGwDsJUQ0JpW+e
B3RsJgqigQYRkADIZ1+EYAyGAASmJylgBG0WuGu+ZmzC9oHX5oLD9HMM6IN9Vog1SHQgGCcniGai
p3X4NnvQc2tQd2x6YYjKBoOrx3kQOHWY52yXF4ifiBjdlgdCkwNFk/8zredkcnGACAh6SwaBb6YR
1aABYcA0qmZfYRAXOqEG/JCLMtiAVBc8ayUaDfAylaEB1RAGPJckxvZzGWgYLBd8NCdHjih0QYd0
nYdss0d7llhrnAh1wJcfrrEX5vg8StAJAkYQnHAHp9UHDcAkfjFZz2MMCIh59RhS+DgbXcByR1AH
NsCOIgBh/JAfuSM2MIGApkECCJYaexNgbCJX8HgEDblYRyACDcmOR+BjsaWQGsEPJCCQGyMCPsaO
CuGPAyMWXcRpAJYNSiCRKPaQE0EC/iA1APCAw4h73giO1kiMoxgffHUHJsMo1ShA++AaGqQBSgBY
KsaP0yEICMY8wsP/ax1pYBBmQfHxlBzZCVfiHuZIjykpEvoIFA2JIkBhlZT0lA1ZB8yDjgTBDxNJ
T4mVDV75kSIxZGxikU75ZJyQWhNBDBrplvw4FuqRA3tATgVEDKejLPxhCO/QEV+ZAF2jYGexFzkA
A+pxFI3zIHmgHn1FNXPJLCbiHPNRNgnBLaTFG+6xTuxRTvrBU/pRmBS0QtoRVttwEH7RFXeABrbx
HnWzmnOTEKIgF8R3OLv3euI4jaQYiC6nAZ/xXk2ADHFYjZnEWp5ZTGElBcqhEhJCL9yCm6cDERN0
mg2BEIeZmKTZGlriF8YAmV6yDZMpLqbRmkcAnjAgngVBnrOZN7Wp/57xsQemSTapqU3bqR74NB0G
8pqR+U9XVUBcsxc0hBAKYpsKgVvE0ACH0TUhtWQbekFbpR2Noy5xwpmYYmKyoaA6pDk7JiqnEixM
JKKoKRKNwyJqAAOGkAOGUj00lBIaMksK0W7rJo1LljzgJmbkyJyfKBGPIRrbsIQJRW17KBI4JRGa
STnZwR9awzaxpDkhsVTlshfjwjY0+qHoIkqLA0VVxCGK8aLdEqPbMqNMBUurpKBHABVYOo3jMh6j
CVXAdDmsYin50jVLFKFM1kl7oSHZ4aCaKTsPxKckxCLug5E2BjzuwkLbVDUCc6hl4xeOeiqvg0T0
YyhS4DI0wjnT1P8ilXGAIUaK6rZ5EuiTY3dznjhM8CcaofFeMDAN+YVmYSA1+cOovsJULJdiwqk2
mhqcEKSsthmsV3QY4xJUVZQ6x6qsv4SanSo7zFpMJFQU9QKmapodziKcnbSp6rEsh7EiLMItkRku
cylE07oX8IEl5CQXchNBiPMrzEKhqNoRgZGfzFFPkdlJL4oeqdFJnXAqhjNJ6ASmnxNB2pIdtiE0
opEH1zGwn8osNwmLmfc8urcYsneB7ERz4RiN5OZ9LfEghtIAhpAHCcCLYqZBZSApw4Sw2kSuU+GW
Z0Uc2aGw+NpDtsKvmEdO8KpBhxMtEkFa29AXh9MRPKtN53qs+zr/TP1aVgQUEgK7Ok2rEw2QNogT
OkrWL/TCNiNRIHPDmvO5GOajRMc5G886THjKQRozLgTyoOphKvWkHSZiadXErhJ6IOwkBRSILKf0
oDXSmijUBjCwDUMpsUCxt2dbpSrSbvlCJUClUjlHgk+ndE5HiV5CgTm3MVIhPtOgUIVGEEAQGv+0
By7bavQEbElyFy36ItPaIIjKQGHUSoOLFi8hFyIwtqKjEeLKPHKjcXrBpyniOftROYMrMFXqKXgr
VM/iop5UuxoxQz5RFH8Dt+fDcC+HFY0CmllhGrRiIs2RgkfiiGhgkHqhANb2EmxQpukUEtEaG5UB
TiLSOBrQAGe7/x7NpJ+WcyDnk07pdJr6YVTcS0r0eyw9wQ9LoazGsDLbIArvVYZhFZvuQhJBpbFm
IhGL8hgq8wzsOhd78H+9hnm797mu2jRD8mQvYCvGAAuCxxApoQaG0ACk+g6ry0iyCCXtIwUzmzfY
4RIuJG7MIQLmsTG+oR+w+ZDjoirDUb9VVTlooxHLJEeHo6DHhL3nAzk6w0AbVBkJPBN3dwQNjDWH
qr/8CzxIzEElwU0DnB19dSx9AL/xIQ6sJRv5ZwfZIEoY1gac4G+8BSqikAMVYAMIYQydYAeH3BrZ
wGJmkg1dIA4hsQ3ZIAmiAB1NcAasZVkacMguXJZ16bnBVayr0f9YdzAe1SCX56NYw7SYCKYXGpA7
qpA8FdkGt+UeLwAaLTVZRkaXzlI3atAJUlDKbAYAZ0DD2UAmB2MM9SPKErGYn8VyGiCSD6EGNwkL
ZBcZQFMbzchItkNt11UQ7+UTKyMzQ7kXGmBSDMEnQwEkalAjJPCcb8KqLUFwjbI/yNAQfKcGfJAS
aEBhhwIDCTANeNEnPqEmz2AbksJHFNYFlbw3K1GXQGUMZ9AFfPUXJJADF4kGjdVPuSwKNpAdniwF
oIweZ7DHosQPpJwQn4DS2YAgxkACHBYSmmwHrQWYkBXLtoUtHl1NLxDSEdvL2fIVCclNhyyupmwE
aPArqoxggeH/V4BF0RaN0SJBAnbFEPQkCP6Ay6bMydj2jR6obcipbGI9ZSsIdWKNgaX3bCuXcqYH
ddioE3mADAv2T8A3pCRBAjeZEbBQDYwxMOCzGZiGXuLQFzJTUbbzDB5DwgQxDYLCaSsVfxGQDecF
JTk4XgTxDc8JNVIiSHnQEilzMEYmGmrCGQdXURclZy4DxJuH1zXnjcxjwlMnpYKIgmBdgf84srRa
E2rNk3A9LN02qzzsg7mnk7Img5E4pNSohkkaikxn2yNrsoixCmTiT5lR3NTIFpJycC0hGzCgJz4B
C3eoEp1RE89wd1KSA2zCgySBMAkhMxGlq2OxF7yYBxOFGHyX/xAwIEkZ8YUkUdGe8WkIEwbapxPT
4BvkJyl4RKvD/dy3TdzBh9YV6Hqnt4kgmN2wWrJkDeE+d+HM+eHZBoNs8qp9yOG4kts/t7nDDatL
twfG8AmqWH9/gRc22CM3KSQDISsaAAQjPbQOYWBSwDSw0MU2MAOypW95ADXcw8LPNRhShgY0lQeL
AOBqkAfY+Wn9JBo5nAB58FDwXBHTgGodm2wPDpQ4921rTeHazY0cLqTSHWWlN26daG3MHeGpNpfI
xqvGjXva6ICbq3sz54g8CY5aN41o7YmC3hgLpjR58dowZ510dnDzlj5/caa/QRIi0Hb+Yy751ho9
+OJ7UXdOBv8DgqRkJmblyZMzlsRmXaSjEbAI32A9chEGGSERdzCzG+7m2aiIw5bnhHjWxDhmtIpb
Udrran7Cy62cDS51cf1qttbiGRhGyeaLRbfnJFvthT50mpdfBo0l3lhlPOeH3rdmnjFR124r/ICI
N/m2EBzqlwLN55MDUkEMhEdSNgV/3TcRtS7qeKQROONkanBM2XESWpIYJtGkqbs8YbAILBwGM5FG
sSsSfu6TDVET3s6Ica6G0F6dwbficVZtFv48G3NAFX7n0gbyBmbynreNnYsrUsaKyQ51ImIrlTGT
ZAbpsXZlJC9rg7h60ZhrNY+RZH43hlqBavJeg+ZqiPgXk5X/6/t+UQ5F5Hsen1Rhv9lQpE0gSRch
Eu8uGE0uEi074mcgAoE2N+ADS4YiGp9GGZXR6AeFaWqQRo+oGjE/1rmNehj+7XxBbLfWdKyIK6dn
82AdegvH3HN57HbvbDSvEq5xZbylBCIAbZywjv6GWW2JlnKF2jnAJHFRB9lwXRujy4KQX/dIbe6Y
ZACGBsVKEpAv+ZILfGRJXEwCbaZFLw0hyDWOBl3Q2yEpBddVExqd+g6x+rBiByR+BKqAO6xWdThJ
FxX5+wBEJmfAsmzyAjYQ+rv1++fr9O2m4mxQh21gCP8jEk9ikHxEEe7RBfAHh5sxMWfSEtllZtit
Ec/ZETml/9u+WNG32szPoAGGABAaYEToU7DPkT7bAADoYwjAEYQFX7Q5o0ZNwRwMNRTkVydbnYsF
j6DpEpEYPxJSOB0sKGpYn5BHFMbsU0eKEosGSW7UyVBkQobERCoRVcZgQ5881XissxEixTos+7iE
WVBNNjQrWdY500aNUJjbuoQ82EYKyINHlJwhEfEIiTNGDTosyLPjR2IRjT2UyulOtpDG3qGp2qdi
Hw1SRGazqliNlIuPCzIu2OaglARnEF5UXPCMSBsINYhDiCYCmohqPsPUfOSw4YuHE4vc9q7zERFN
YKCOuG33UcgF/RUMrmbbxSO6FUeUslE1TBtWW78+7Dt6xP8+oRFvQ2yMz+qDTfghVIzMWB40fPYc
XO168ebO2/IAXgjA8s+CMFYl6BMGVlWI0DCEO7L4+K8g/hqCSQ02YMgDIYRg2YaPBI+4yBhBPgMi
ojDcOkoqNRLz7gw0pNiGoPE0uAQGk2BaKA/fKLvMoPsw06yqHAw6LjwYliNuI34+S26P9voQjLCQ
ZLtNvvZy2w2ignwjzKDg+shBqBN9vGjKPoIL7ojrmiBSJNeSjE2o2Q4yBgbG4ItsOcqO6EwK5rCM
QEsrdSrttNRWUw3CLsnyEbxBiatqtc764FLOo9qjkzh+DDVISPKS9KyxGRECb7IP+5BxMakIZe/Q
Dz91tNL/Sw3DFMpHWUo0G+xaVRWmHI6AgY8GjDHEkPUSbVUKsKIDSzEY6tOAp04BPQqWaSosKA9j
0Pi0jzyGa+Mdg57powlt/OHjqK/ycOonsrAz6IgItkFD3W1MNCYCYxjLJg+yCurCPtrUiKi9RRN1
b9SjTBUp0S6xQ1VSVbGb1tMPj2gz1alCPepfRhPuEjjs/Fyu1U0vppJUj2cVdd+JHW00rUAhtnhW
OUmGaUoZhUyUy1n7IAa1g6IrSGeWe05UZxmXO/WnTqD8+EPwKvYYvCIZPnrWRFcLOmCWNDWoVoMe
zq4gEZaDwZhtJiQIZ8Nc7nm1fOqTSiqEwOr0bbjNXRvu/3MnbrhTWAxBIwF1DTljV1hyOlDhe4+6
DmKak8aZYk6f3lTrS11umWpzCYZYae2sLkgo8HRGIySCtZ6aZVlXZhrhHPOcDFDwOJ/0pyJfPWpR
UQvizWM6NW9v09s8Hslx4CjHnSXKajeI59frJlhIkdNCQygoRfnJx84enpP46T+kvtFYqxqujz2A
MIQPQyLIw/ifg7d3ISPgRk7uqu9OFib44ae77qMiVWNAE8M25pMIKOVtCVjI8roHMEmRRySfQ1nv
fJSjiNDMducynmfktikFvi6DCEQYotLiI0UFDyHFexrCyoYQnZ3OaSH719OQFzpXGYQYvIsIYzhj
EH9c5P8OyXvU7z4olSrBynY8aV3vzjCeWXUiLZ/pWg0LE8IjCCU2dvtMSFJXMRUej2oWPOHW+qBE
iDDPaczJ2rmmFCAywuRWekMGH4yBPYRsgyfS21zv6mMHts0tfvLj4/3shp8/dooEBeEDGtDwiTMY
AzOGeIdz+gCAeh3hXo9xyxlHAiFLgrBKHUNezM7VO5vRkFMxIQyUpli3KmJkgd1zS5WQNLoZsQSM
7mniKJMHMUQ5cYzP+1grLVVH2CGRZyKw4UUy5yPAIKYzNthIYsIokvts8F+wUIwIynYQBm7Qd6vR
jseOubaFtUFZaqDdgabTTDpKh3vEkMw2d5bGS0HvMfr/qlkfvBJDmAwyIhHYlSGAAAOn5EhfneFH
DpATMkUBoHD9md/bItXHQP7RfgYTCViEkgfFGEIKuhJQiUTwjQM1ziALecpR7pnBI0SThauhJrg2
pRl2OqYy1jSICBSwoOxACIReNOk4yzmqtkVzhBy5UXNgYsOZHi+N32QlTILjzH9pYIcpc09QyeQ0
YtzhoAS7jZA+IQ47kOCMbchGWzhyBH9IwTKbocj38qnWqsSrC2eIk1gtAz1iZEMKZj1CtIxwhuWo
oQ3+SOZRs4ETCJHVrDbbhg1coNeDiCMbLjBLlKTQhRw4qg0kIIsq1AqWvuYgF3qFiMMAixw1kCAb
hb3K/2HpWSIjmCgviDkDXSMi2X1IgXkvoKtOpOCCCLgRgHzYRhtEIE+z8NWvgJ1UfQjyxjXdAQj0
9BB+ong/ZdHNQ3ITgfne0rJnEMMYyACsMXJACHFwxyAw+FNEFMoJKcQpXrndLVwvlI251jUHCgCt
IkebO9NWyRhtsEMOSrkNsIoVmv5YLDG2cYbHLkeylI3PZTM7sDbUgVVSYEE27iORHKAFIWbxh14I
bGCrrBaxZSlratr118W11SCpPYMNQqIGG5xBw+ThsIeP8gI0vABCyw3sYAsrt+zm8cZ1QxbK4maV
u1HUaMmyX0MnRpM9WhdcTp6xzZLlNohG+SdTrhuZ8/9YkOC+y0GdAnPVAHURDQDACAwpJYvCIK4Z
h0ED1cBylc/lZ6mwQQMdYgksvqEtgB5kPUaSAhqakEhj7CGkc5NkF/gzZUCR2cx/rNdF2nwQ0G5Z
j/VLVp8pDcgzuw/K1V31k/GX5Z80GbuofvKmtexHPbpau7PeNaCVBb96XRXXY36buSaaa/wBOsyu
jgAygGAMICBj2H1UKAASAAsNNKAuxohIHsiHBmQc1FbbqO4RYAEDu6lhD4aYrVUQbIzzGCQCCWqV
HKNliGiBDQ3rAdSgyS1JAGgrotOmNa19TfBOBZvLCJfoE/no57bp+tWvZrWrN9NrhJPay3ZDcrFR
rWz/gxec1xxf9sFB7ua1UXTgfwRzi0TyDUKciA8ROHlD1batgc2F0NMwxEae0WxJPMNcl5CCHQRu
lT2ItlzGEPgzDIHPvh5Fke8y0h4SEIFvYCcMPWJBGO4l8Cq7fOLJtjLDG2psQG532BW3X6h3/fa1
51pubmd4x5cN0ZonHNXlErndKy7yMpOc7AqXX9hHXnZk34+f5IsAugnvR/cupA/PELgxQhKBSxAV
LJcIwxnCcJQ9DKQigArDHmA0LtWExOk6KQgs1pOHbU3o5wf5TwLQzTV2nm8h9Bw7qZOcajDzHdl+
N7vHA/n7t3+a+HBf+bSxDGX8Kd/jrD42sVV+fePH/w35iV/4rSWKdlxDPOXTn5jhrU/2D+2BuO9A
xirGPn74taEL94L9EfIg8AQ8CCGGmPQ2CD0xo/qzMHgj0agYNfiGBLiIPdiDi4C9KNkGZHiHb5GK
BJjAupG8x5Oy8mu+u7uq6nu47As8WSM2iyM/xEu7J6ou6Ck89APB+ek48eO0DtQuC5mfJVu+LhOJ
JhMN5RONXVO4uWOJGzw+5DuCHcSPYAM5g8kDaIkAfhK5g0I/h5gzveGD23uGNxoilnCwz2MyKZi0
gpgB9SqIRQACg+CDzzuCb4ARC+QDKXhDsDsINSAuJLwX7HM47sujFgHCwojCFoS+gUuN9/MjP8yf
4f9rOFFrvhrkQOxaREVsuNZqAw1IrBbbnKWwLQihi594gfi6sWxgi7PaC+hLqTPACS8zC3GSQ7I6
MrGol20wArczhi6oGmJIiQ9LLRtQAA2YLTRgiJhoAxsQJ9TSK846RbXCDpIAl9WSxIhoAiN4KITo
CEw8CE1kCU5krU/0h+MqiPMgH16BAWoigWIsiGq0kFWMCRLYC8mrGz5wROyguV9riCQ8AjMcqaez
pk+YqBLZhmooiJRoivF7pC6wiWzox7bhCljJRJ+wxq6YxNJYSNsxgosri1L0NHs6RlVcrZhoxXNR
LJO4xIS8DIjUAFGEELRii5hIq7bAK2J0C4U4F8H/0kjaGIuOrMS0UAgPKcc+uEZPBMU+GA9RLAxS
VAKXXEhzXC0iiojUESJGQYhZWo4mOB8RaifIgAhgaYg84BnN8SKjuooEEpKolKmEmI+NkwmypBI4
yx0Vepc4qRnFEIoe0pmupAw0wKjSuibVkQ/GAK02acqo5B05nBN9qRjfOIM8MITDVA9W2RNZuQ2g
oR8XWIhZrCiNohb8MIYE+TM0CCkIYa+62Q00EIccLAhkCBs5GjGn6BjYK6Ao0oAxfMrwkErg6YNP
eAcZUYN3SZqaQRTnoIyuik2xZKov+qEh6SEjeZKBSUo5cY7lmJx/sQ71qaqwLAzhPI8bURPZNBQL
/xFMqxQKxNTK3YwSGHghkVgNIQmSy4CQ6DAmXRIpvKSM0dGcYQGdo6KSSDmD2QJMtrEc9/SkgrEZ
gZlPTikNnnAMWFqhhHkOnUKa9kTQ64TPSSGLO9iDVSAEICCEWzGhHEEi/NSc1OmSb5DMRYObQnoB
EiAGgjA3W9GzI+jCIyCf72gCg9jFwOsDWCgkQ0IWnlkNBuwDFgCAN+IYpepP7gHQk1mb7xHQIxCo
oLnP/IzO//SUGuymT5ERCPmU2+gM8HgYNCCik6nBDq0nB6ohRzycMpoUXYrPWRHQehKSM9EcZIKY
mTkUCHFNqYiZrdSajqmd5oQZfDoIpkTLPQoOof/oJvN8mnaS06e5nrzoF8TQTgT9EmzyshsxQu5o
zxs5HaVswHdBTCsspVgaUI95mNWwg2o7ChbJQ1gIgwRAlirjzDM8iDtZlywkDl2Sgj24l0uNmgii
04Ow0/ZMlHnCD046mj4VVX8JVOMhDLgEFFAqGEyNHB8KGfBIVIaRJmUtId+pi0sVqUwtI7PZmVuy
VusRV+0cGim1VUTlktT50JdCpTNloGtKH9arnLdJmqjpoCPdyh2N118yIZ7RpFJZ0HW9GlVKlaHK
j+CaucbDmD+ly+TJBlioj4jQliR7I5oii3ExiFrtg3bEHw0AAiCQghyYBjF9VDohIACQF31dHXX/
RRhyuqV6mtTsaRx5LSotqleEbRWmlBU/QdnZoZKtvM4K0pkNQh5QJR0Puc6CPVh3PdI//VAvOtpU
kYzJcUtXURjYSR5CyRiDGR3meZRNMinoIwbL0Zwpio0NWg1rgqGXFYVhiRyEKhKN2ULL8RWtZQkV
6trkQYj8W7yG3cooTZ26BZOCuIR7AYD6U7Qu7INFOJcGcEI2mBJ68bZviYjM/Al4awKySZo7iIgG
qA9PkxmzoZ68HdqazVtQkZSwPZhNuQ/OKN0YiohBQpqjcCuhqYpfoSlK8Zl/tScoE1L1kQqjDU+3
9Npz8SQoiR1LKRPPMKa0BA3R4KrBEQfkmJPN/+ASYripjbvKxOAM5FhPPxGiGzIX6cGyh3kM56Cj
+3CmzbnOihGB3XETqioSIWIPMzGI85VeZQKO6r1edY1ZjvgUNciDdcsDGCifPVAaw7UZMKKOG9KX
M0gAUwXSKLqzGUCzDC4IbROBI9ihI5C2wBnRF62Dj+0DfjKkBLg4+3VcI7gXWHgeTdGU6AXU6fXf
BUpLk0gllpiSYYGIYf0S8U2xiwMhJeHfNImSPKqS5Wycp9odKWLa63yOoyriUKlhCPmMJvtCkbDe
WHoUAbYZ7v1hC7EBmsJLKr6KzciGHKhdhIAL4wIL1eiKtJAsOxiw1qOIxXoLtoASQ7IDG9CaOv+Q
lveBCqkY5GyAHr0BABt4FDTIgS54w5BoABuILbJpgzvghIMiAYqAkheTlqHIhuGICZtAC4qMCnLM
BjsArDXO5AWCZEmWjmCsY1XGYxvVY7eAi7ZAiBx4ReayChJ4BjfiAwPOAxZAg1Ti5FtkYzfWgDMQ
BSUQib24lzI4AjZwv0Wog9t7VIQ4YzaYjAgIiWywWD4opAYopNXwm9hiIhKQTADYiFrUsZ+wibZ4
qDleqyOwY1uGhTZYC0+Wgr8iN9w8gwogrKNA5F+U54hAZEXuxUam3a7YRtagY4h4MCMggQbwThvI
r0PxMFOqgxywDFLeK9HQqLlqFYamRoduFTj/luiwoawpkZY7vg9+7mOR0GU/RgNAFmRQRgyTZuWC
SGkyAb/s2j4ghB9Z20FAobu0wA6+YzsiJJe6ITxZk77nI0K70zL7OepOkTWTZIk9ANxUNb67nNEB
upf5iyNYeNzJM4SIMASh24NPYIksbFFYmAEgQIMGaIIwCAm3saYZcGdByANRiMGiRrYkdDj7UWoh
/Lgpe2o9rNG3iSToi0Kj+bRGdOrAUzv6kUO9axik/hDGzmyM8+xAssiPA6QjbMGsljgShLW4ITze
CyR+uOqxw2wNPO2NO7W1We1iS4BVgJY8wFCeUDaQiwA5AwA2IAjEiDqEuIP/WEC/vVwRWIVy/xaQ
eNvtI+CHXlyICgCACiCEGSCERbAmjXNEQEJttnm80Ryzv8tD3kbvtXm8Njs4SxQz45Yo9t6ciWM1
3z4ztQM5zOZvg8m7swO/cvk1cxnwDXTtEBQ5t0lwJxtwWzOaAi8+7/PBVfO2SHOQFe5v8Ms1famD
xGUIdImARfiEBYaJRRONVTCGXJECQ0iAaWhcDYiAFyjxLkiG+asAQViERUAA0aabFRS28Cu5RIQS
t1jwaSvy7vvAEAxx0D4KBg8zAy+8EA87jRtE5pvy9pab/Ua8LRe8PvI9RDxyAH/wLm9wQAzIyc6/
XXkHJkTB7LtDDTAEb3BnAHCBPPCP1guDGf/oEX17F3i5AxKoYPbxBkNQhWSQMzBYCAZAhxlogKNj
RDXnvr8Lc7yzdAyHPLk7xIiKQUYkM8pORC7Xo0hp7cNDv/cuS0+X8kvv9EHUdDx87boja+9bc/1o
tsNEYBJ28xk8grD+0RLX8zmrD2R/gQjo64N4hjp4hndgHxeIAYWqghlAB7b+5hN0cDT/QxMEPPiW
9a0G94g7dVEH9XJ7m1ATP/ODP7vBba3OdYnLakE8PnsH9febyAzXo5iod4o7NaiObF4zc/BZt4Eg
ZvOJ91aP9z64OnyLrxd4gX3YByNwgX2YiGeYNHOBBRaAgT2QhC4YhnCYsy5og2t4hjPoB1z/pz4A
YcT9rvd4vPfE3iOKovUzp+/E6/c2d/e6qfIS3HkZSjxj68WJEQtBFKwMgxIN4Iq2CImXpCfBkgK5
QAhkMErbKQlAUa2VJI5Z7EfEsAFRELK0+AS+AJBPBAzkeEkyIQGuWME7mMwIKolHBVSMjBKfgBBO
7ASe0ACwF3uIIPujb4OkFw16XsSXnK2oHyRP+0R9qguyKjEdgUg1cDomtEKEN2DROAMDywmYoIi1
ipJZhBCzdaMSsQG2fwEWiPiUQMy6EAlVKCueyAEbqAYpGAY5I3kwQAZMaIBF2ItIsSYR0Ho3S8Z5
Jmmnh3uM0IjFEAV/2NgzCAov0/rr6pKu/6+LvjdJ4TdJ4mcJuEimi9DlG4OLqe+Dqm99upfEtPAI
r8B7KdB76w97kwR8KEP6HUMMEghk/ekD8AfmuPiJ8p97gDiSTUobDX2OHKmTTYkaNX36SOnSp9rD
TzDE9YH1EE0Cfw8fHjnzUE2OPmqkgETZ5wwMlQ+lGDyCxuG2CB4PHtzW8uNKgytfJhCJU8qRh2eK
ormkgGdIjWrQ5Nwj9GXRPtkebtujBOcRnS6L5tCAUKUUGGiqhnxIjGzVo32SXv2Y1mTJk0WPqGTp
EqJBNXHPOEyL8M5DDWchmkXLJ0LdPBEiGOKz59O7CHmQSY6w6NuebbDUwIKaZ9UeY+/4bP8zhOZM
Nk4vyrDY52KfnX0s6pxBBkNun7BYN3pLAGQBADugAAAIZwwTiVwRRPURYbTwVI5XAxM9mBdGG57G
GIPsLRavz0+rjPEEPB1i0PDZVxL72UdD9QTXtRdVIzRbfJlFs8tEk028wTSWQ1I41EcnBwm1FlVG
IXVJXCAJdZJJKun3EH8HHQbgTH3UdNNQ4yEIUYJCSdHeQVW1UdVH2eRH1WBjfdRdWzj1IeJUEKnF
003/UYjWhDxyiCOMJj3UhAhFLfWRUEVt9Z+LUCX4kEcuTuWWlQfFdxiRKslkZIwQIYQXQiU9ZCOE
Vf1oTFF3xNeHDUPd+NGVI73FUx8w5JH/xzvInBYBDJEZEgFmhsDAR6F85GEMH3wYsw0abdjw2j77
eGOHcUbYppAhq+g51ZzzybHENATI0QMoxNVhTB0KxFFIJ9L1EUwnVZWE1hm0ylkjjtvgqCGWTsol
kHtBgjQkmFCFVBVKuvI6Kj+5urleljw9S6yMZ43VpbMvgcSssEiSiRC3AD5brXzXfpTteuVya2ay
euLV45vFivruV3PeBZV2XO2IEJFQtoujllb5ihOaK05og4so+eSSSw6CBKRc29S5EU/dadhxmsdW
zC504D4kAr9F/tvreiKIc9eO/qaHY1Ei5fFMBIyqpqgxhhiyMzLI7CyFIU0Y0wAaNpxR/8Y+oNgx
jBFdQG2EHS680MY2eTDlZVzEvFPJOQUA0A4oqUrSwz5gqHLHCyKIwA+Rfaj50MJhknzQkCbBTAzG
Dy0YM04c89iWixNy7FLcvckF86hEzcz3itnOVXLLJE8oFOBxEQ7yilPF5dLiAgslEo0u88Tytwg7
Lried6uscJ0LnxHnW1Wq4uTDeqJMskDDtivwXlMBCWRgO2p5VJx7FSn7VRYXlU2VaM713u+85fC6
k7J/+FDtJEuM04RgWlXlx3rutY1DCcBgmWN58LHKYnv4efMqkvpDQhmSuOCNC5qCsv8+dZAADXk4
QmB+0jiDfOMGSfCCOnbBiRsAoAcAYP9BPiqgDUHcog0aUcXp5nUXl8ROW1UqUccQMrn+7AhMR3oX
mUjmjw7ajSvdk89bTGi7ghVQdER6kkqghyIYAq+G6+levTZirhuCK4dDWc8Rqqctg/EmTziS3vjk
wyRspYQnrGvi4D7ir/jExWI0pFud1NA3YfXriW8LV1Xi854j0cRvRQRh4sLTQiIB7kmok1tVMPdE
FcYIWOQ7SJVGtSUxYgQrzzOJ+2zgDxZ4wwhSc5rUpFaGF5xhGwnAVpz8dQRiVKIAphjBPaTxClLs
ogdysMMtckEJANyhHyLwHG/29i496hA7PXqjntAgOxF9EXViFArMJlQUW9LQjyg7TBH/PUan8dHR
imR5IhkhJLcqjiqM/mLmXox5x8JlsQ9gtCMx9OhMaxrLP/P5Sl3wE8Nnrg6LBDwY8fKzo7u9x5DN
tIqz0IK8Pb7EIfTxEY5E4ZPQ2VOLoZIOMZaXA+lo4Csowc4H/0PRNUUOoDNzUd3KJS9+vvMhhoyA
MUjwAhbsj2nDsIMk7XBJKaCBD1hyiBoM6QU8SGABjjjFFu6RBOJMsBOZyAPbpNMJNTROoaqLqN+a
aiKT7Aigz9IP76yZIfgk9UUGKwo/2OKxMIbxjgGdz2E2NBeDWiuhWk0PVx1aFGKMjJfCDOt7xmqY
5rmsqkcwRkRykB1jZAMUotBnG87Q/4YqkcAGJKjKNs7QhdWAhBME0chbzmAEKbjEGKIYBmZBQgIp
LBYrlu3sQXDToocY4wx2OMNU/CKFOuCkCZsdCEiU8FpcoaELUiCmFFY7FRFINrQiaEJEzqASYhS2
DlVRQ3I/Ig40AKATiRRnYQ9bIzSQIEHikMJlR6WGz1rXJCQ4Q2g9C1rGSgEAUkDTNrhrXNSmFw3Z
YW42wmuSNoC2k5t9L0nJy4JNSY2lUttHGT67DT7wpA6gpVUTCLCAVGVgBKa4hzp6MIx9dOIOnSjD
HaZaXdkRV7dgSmx5G3vZHrp3VEfA72KrsprVjvi8WHEvhpo7kjbUt0rtFTFI/JEN2P+alxNowa8G
NzLa3wZ3uQqwAeCQewbl3vjJzoWudBOcg9MWxcYHIUF940SM8Ra5spdFsozva1j0GuG9uCtWeDga
xTcHi149WpFJXORmArZ5zXZGC1fczBs/447PbGbKmuOs50AX2o4fqdKdCZlojkI6iuKDM+4SZGc6
sy8HJECpgDs9tX1UTQrG+Iaio/OQHvwA1SOAQwMJgJxhlKEEiwhGdHxSaEb7GdCFll2wBIYnctlx
0qWu9KDtFWlFt7HYUbzLsBEtZ0rr+tjkVLYdmR3sRA+b2ZcmF6+5Au1se/vZiz70tp+t62Y/Wtx6
YvSh/2zocDu73dimtLzh/WZdG2P/UkoTcEun9umqZTICuwbADXrwihHcQA4LkIQcjOACAFSADbR2
963DnSBec7Q/2Jb2ud9t7TUXUGbIjnehGw1yer+b5N1O98bVPW9ql9zlgP54xwUtvnPXXObmRjeh
49xxnrOc0NHmibBT/vKPrPzo4gyPWbKxb34HWFMuYEGojYE13O1hGKfwwilIkdMfyEEOw2BBGz4x
8YnPW9ok7znuZKf2lh/dz0X3uNFLHZ+5uzzRSG33zPMc9KXjvdkZVzqgQ67upC/d14TnSdLdzG6l
7xryy5Y85eNeeUUXfc/YzoO+adNSSYLe4bYZr9VdRKtnvKAJr5BGKlKxAFAYgR5G/5DEHWDgNunw
6vI//zmwgb7ztbdb2A5pfMztzfKhizzvL0f+x4v/bltrW/nL5r3i4U0Rix868D0XdK/R3XfhTz7P
l/bz3X8tO2HzXvzVRvrkTd5mQRdt0/tjKdQDPBsSkADBemLDklYBhIMEgSnsgiNlCihUgCgkQBh8
xJIY35jcG9v53nz43Pp1X/c1H05on8flnPQBG/dFX9DxGUdZ2gZCIAWumdsQXdrZi7zJ3fYJ3fKd
3Lil3F283aCh33JBYPWVoPOpm7VxH9ulX+XV4BEwRh1w2udVktSxQBnQVrCgoE/EyRE0gT+UQg7k
wMMJwjPMAD+wgakhmq9tG+LpSf8UqiBIiGEQVoz3jdzjrdujqZ0OohwNpuHRWVoMlhocrltyfRJq
AYD4OJl9bQMAcJSCAdlBNIEgVsx4MQRPQJeeBCJTbINEWFodMFmVGEMfMsUlFguXtUhVaGJ4cFl5
qcELYBf01YGmWZohIGJtPZmLPOICJhc/tBGOFcRHcMIdlFcfNAAABAt02VmSycV4hdYngRliPZml
vWLJhCKj4RgJcEUjeuKP5YKm1B817oM2jBcM5IcwusgL5NdBrEIlAMELAMBxtMEiKAAvPgQ/CAJ5
ic8lclQgDuKCeZZhJQhzkdeYNGIiEoSLjFcd6Jg6rmNi2VcffMIqPsQucpQvesf/KiKEIpqipqHg
EagiUyhBK35EMkZHLLqiQB6EHqqFMMbEW3QBWhwBRMrFKQoCWlQkT/xjgnhXD+0B8jxJXGSFiLTO
qFyNuKxEQh1THuzFHawCzOxVHuxITMrNTDoiUIZHhaiEIRilHHnVR7nFXOjE8hjF8GBFVF7PML3V
8mDIsxjCO+hQVyRA3LiFXaBTWZHOSmgliHClURDDMM0LiMCASByU02FKF7jA/PWbC5RBYcnUWJnR
QYzMWsSHpu2BBCEHCxhCHYDBHiBDLiCHArqEOMDAkKDBHuCkIY2Kik2lDl3N77SlelhlXPYkjTwE
Zg6JOHCei5hGWWoSWubHe1Sl/1BcpcG85dUQz1y+zWg25Vt5lcrs5FZdiOocgU5mpm4yyIPQENyE
isDMjbswk7hklG3KDPhUkZOMUMZAJ+7kynQkVXyk0FpVTsGkDIfIDruw0MKcJ8moiR6R0IoIknNO
BZiAk7Wo0Y64p+2ABRY9BKTUwUmBgWwEWCXNhkLUBE5Mxcis0LMo1jScAQAQR/8AQBfkgyDcwR3Q
igJwlA5lkYulUR/cQR85E4ju0wyx53P2Z8zY2T/NJ0LU5x3dZzip5xMRD0+06EeE59soU5i0pX2i
ZzPJxHpqCxWhp7ZkFPCwC5NUxUAxCEe5RIKcUZLe0V7803NOBeDskyj4jhhly/97dhSY7IXDvEgH
eQkxJUzuIBGU1kvz8CgTTVN6ysngdNCT3NNH9Fc2LOG+xUZLTZ2CWd2ZFsX2EEZz9oY4JMAq2MAw
AEAMXOg+eEIEFMIi8AOt7YWFhIpcVMcRsEzvvM3BvE3koIiN1umZdpSmYovi0Q1bUUeI7lF5DmmZ
2mlHaam2NGkfeOir/gucjimAFlHmeJGUIolIxAlWQkScPEkT8cScOARRrlF8mKmLOhPgCBFvyOcS
HStBpUyTboPbLCm5XA6eYKmvZNWo6BBK+GZY+apIIYmKbYN0FJEhWc5aHQiAQqfw/EScoIka7MHQ
3IFkAVAZuMCBBqqoaWNOhFP/HhmFPxiDqznqMIDCFahCJxhDJyADrYkAssJVtSHrQyWV6BRRdRCI
kSCJSozryeJr3HRssOyFrzLbkDirynQFuOZogqTsvSapmiRVVv0QEzHrR8wsvILrkIgEzq7Vsizd
LBGId25P40hJwXSQjZjoINHUrxaJcL5ZWFWlu/Tok1QLgKTrjWjt0nlJuRbrt0jJYLjTm1rTogHL
ncIT45SogVwr2jqElqgrjbrqR+QBVAJWG5yU503NbWTD1bCJ1PoLGxzqCwyDo0rCAhBAPkjNCwgC
A3QC1kjHJ8SJQUiBb9pJU+IqSITtXVCtM5Gq25wtgOat2krg53KUM5JLsxBd/9zWzdiKpzgd192y
bk+CSxcxqFoQxl59qdTe7tziBMV4C8nsytsyK2W9hVhc1VwujAY0AIvgiOw+RImaRH2ODo5Y67P2
QRc+VfmGCfReUUrkhzERz/D9hVaeyUhkz7XOxVwglbsIBZSqjIWQxPpy6hwOCfdmSPxeyIGciDjh
6Ui4rXzoLxpIb4OQaO+dBaNglxF2GqjhV1YgRAOQiFH4xFF1gR0oFiekghLQAz3kQz68gCqUQRws
Atvoqh2xjkvcVcrM1/sqbMVMKbNYSDlRiALjL6+uFRbZmhVV7fb6ZNA+RZV4yVz4cJ0F8XwEUZO4
Ez9kU5zEjfaSaBL36/w2cf8Cz4cNSMEL3EVj2cHhLpoYa29qGcEd3EQ1tEEc+6Z8ucB6cYlpMZsZ
Z4NQNEE2SIIobAWITKgUJJIGiDEZ54RloTFW5EAXZEMO0NRnKcEHRcQ2XIVYsIYzui954YgG0GK/
WJZx3YU3Og9WQBdMeVY2OGN/MFcbCFlRaICCnVYfiEIOVIAYJ4lq2fEnmVYn45gqGMSScIICMMQo
S0Epg8gpe1IockVNgdZHXCxnZUdjdUF7RUBj1QFt0F+g4hca3AwfyFcdUIRBKMCTHaQ/JMA72EAp
PEAq5MMC5EMZFMELIEAnFIIgNEAdaJx8GQF+cYhlTUphsFicfNczb3Iu6vH/hGASYBgzMkuKei2z
KuMEy3CXP8uEaj0yapHALfOxLucKMfTyk37yP6cZgHjjGfjEQ6Pylkl0f2xDIz9yYCQWHPUBCcgx
UkhBHX90SAt0fYFySTd0yGUgsb1fzF2gmxVxHOLIUNebsyW1s/1gDEbaDzaa25Ebxf1e4lXcBFK1
HZbcoDzZEWoKGFwSl2UDGuzMHlAgH7zWEi5cKsTD5OYDPQhCHXSCZfSDF8KgwKAhvD21odUhxdXg
DgLhDJrgVstZV1+eu/Vd8umdCQ423AmhYWP1C1q2vZEg8PWeUYtbZEMeznk1Zxd2ZfMgT3yDIYjC
SVGj1MyGbbzGeC3osD3D/zTkgxx4A3HQgxIQgNK8QCcIwiIQggJ+IWFTIPXtdWcT9+LVHVG3XK4Z
2gVKNuVB93NTNl9bXmMfH8odtnZzIFRP9/jF2T0Cn0kudqB9N2On4GbT3XIrXYKYhT+otqf1pR2w
wG3gl8AlmgaEQSUonCRMriSEA3KQdR4sAlpJIHvrmfthN7mgn3eXN72k3wf+WoNz93FrtgsCnYIf
nW8qXoOXm+Sdm1XLDA5edgUiuNGR33hvuBwq8GQ39dLlXQu+YIeHOCGoMkpVEuhJnaYEpjFcAp5V
W1WEQSn0gOTmgBIoARhcqB3cwQwYwjO84QNG92CvnHO/HIe7yN6Vdw1Wuf+Db7a2ZflwR2BpEzYb
gsTcgXZ3a7mtabkPlqEMWt6kVfUcOprfabkdChqQw2BTvxWd67m13Tlzy3h0fwQQkJfSFKymfJ4d
8CULcJkhmPlHBEEf/IER5AAQ5MMw0AMLIIcRZGEhzIB6t1xgf7icYdxSn9vjoQVTQ/Wb/zmqKzec
c6CV39qTLloI7rnI2Vyw3BywVUnI4aHf/RxS5V71WbeEt+G1USDiAdqSYDeuL3WfhYd4K3vyMfua
OTsLRhpBw9uY7NWTTSO/rfan3cYZRACfkfpDVMMwkMIl1IMcsIA2GAFyUIJmNEAYSEcBRZ/70Vn4
vbqJlw4ebpubIwmLO6D/OIngiM+ZZmf7rRf7VONJmPPGr48beYs2RzV8TmAiTiiYEohAFHJCJ3Si
SbyAP+wqTfBiFLKYqamBLENfbrURP3wWJxTUMDD4WdP8UNiBeB+BKhgWMSSIKuKZLNo0YCRIDvAi
FCoEbFWJNwqClsMjjtwiMnfFxhdFxzdEZIm8wHjyawXGEShBYYmF3CS9Wiw9sHljdtFK1FfF1COj
1UPEzv8aHsOyEqABQOJEABnCGbyAbCi6jlcSGHjDPliNMbhKTKzYGaxku4CCMaTCOYgD05SBkkPc
HWDCJ1DxR0rBJAe9IDqELBYWCUTheJUBT7SkT/DD0oMu2z+E24NEINZh/8d/vNaPfNfjPUJcZHmd
JCffnSzrudNDPSK2/R0gs1+gQc7/h9yTC92TvMkHUsqDBIsJTMsTxMuXpFrI/GvBuOv3gWlQSVau
U13yL5m+hFlgS4LcRImogfkY4k44i0Hwg+g0gVSEzInQBAycjEjBMrBogKMAzzYABLE+fdoMlJLg
zJE+avpIGdjnzMAjNhRqEKcQTQQ0ChdG7KjQ2Ls7CweeYajBYZ8j2QaqceiSocuBLAcWPHIwIcmU
ECVS7GMRo0aOajwSBZknB8k+22DYUPmQpkyYPx2u7BPBmBQSZVzY6WrHSNiwYFmUIbGNz5GbAk2q
pGnjWw4voN69I+CNxf+LLgAAXClUaI+Cpzk1bPtpjI9HldsE3jTIUYrAbRGqkkw6cGOfjJk7tsxp
DKnStiglRn0pJWZVmo4bcvRnMKbHiRUvahbq2bPathAZMnXKsY/phSlZS4GB5mFDhsEVol64jeGR
JjAqN9TQh1hEormfOjc4+GFljztZKrTKUXFV7TyT0ywpcWfrh0WrNufYHCpwKcBlI4efXLb9DOLn
u/lUam452RoSqED2GgLvQYbGe8g/leILELLlLjxQufe6EyE5+bqD8KUH+7iMDzRIIIEFF8CwAyyx
YLSjLBI+4aPAiEDc6YgcjuihiUvq2SWcfMjgi4wqMKGjChD7ECW/8Pj/M9DB6hRTKUAAOfROQSmc
NLFKEkma0MP0sNQJMgLB5EmtDtmjb8v7HlSIzOCeOs9DE9e70k4qb0IwTzY9/NNDNfzLxjwfqbQw
vDwV7LPBK8ubqVGo7nRQUUrRo1DLgYjhzD2nBmUPv0Aj2tRCVA2l9D3WNOsUO1AXVbDLRfv4rb1L
izrUQNb44GObNupo0QUjYDT2WBfMkoKPBKzSbDkoH3Iqj10uEacIb3K5JYZud4AEkjj6EEEE2TIV
tI9OKr2MOQixc5BWicC8EldSBWRvVUjrvIzdlBQL1U9SwRTVvfgmpbOlQxOd8r8cp5UXUjDVBdO9
VyUyE7M2U9rp1FJb/33zQDQaKxU/hZLiqMI5+/T4O5ZzKvCIK4kzscdKHVxz0vgqjNnmjUrdD2FS
ZZaXuH5tNXhETiViubWf2/ToX2PQyIaTFsGK8WoX9nlBCmMSOHHQ/dRM6BI5gFhFCUW8YUIFJvRp
5gQoMikkmCeTHsiGLzlmFUyek9tJ1AbtZHnnU8H02USgb3WUb6gPNDpQpH9+ajWaH5u8VZch7BiN
6BSStmSwBwczu785Yomhnfxh6DINrlxPdNYU4zNwfR9iTSF1dXtq5QbdO8I/tTIDfunqvJsUjesc
JGbmM/hRKPDSpaQ09YdW72MkDwUk/kDjl0NeeWnPHOz5xT0V31LeVf9nKHv27pViD0PaYPHFY+13
gQUSbGgABp79xv4hMjmCISpxCVXMgxUe0AcjrACOL2ACFdwQAT/+dbvgiaA2fVqNyBp1Hy49hHny
ch70QIi+e6EOTNfbm4hoshp/RUkzylNMCAfztIHozn98a9D1Wvc6pVxGdjbDW65KQqfyBU4EglED
Q3ziGIVk4yT+0lD5uIclWBQxZtfRAPq2M58jEEMqCmnDl3yypog0BiZBq0l0aFaQu/kNFg4BUU6A
x8b4EEcxSVwIE81TGShSBW9aBJps3OgxOMoRIomy498u9hARvGaJBkLjH0lzK0HuDjv7yYMhsjGs
GY1lLHbYBwnQ8A3/NSiqLSJoQzBEICGVvCMcSrhCEXZQjhXMYQVYAEcNDhECEARDFEv8H0EWeQSZ
dCiHxCjkEz11h0VW6n+P3OOt+ki5KJYkipjUQPa4pJvryGSO5unc3WgmqjJuaJLX5M2AxHm7M1wx
kTf55pW6iMVj4nEx4rADKSXShmyQgCPP84cUbLKQNiiAExSSQhdyEKD5LacPqiAog46QlVxkA2gr
OYN3jNEGO+TAP2rIRjaUoAaMSMEIUmBMRc5wBkQNRBzZ2IcUDMe1gjDEGNnogkslQsqCjAyjgmiM
1IywUZWooQ3++OMRtqFPfqokqQAdiEAJ+hSknuE1LSFBVXGqU56q/8Sn71ILRqVa0RwUtSpIVWp0
PuFU/6ABpSolhnkGWtCrZnUhW33BQPKwjTO8gCvHMlZYtPaCM6ABDWdQXh9IkA039sEYZzBCQw0B
gBjkwgCskMU/eJCGZWBhAzVARSCywIaWtqFN28iGJFp6oDqcwQbLUYMNzlAHjUmBBY5NzgvQ8ALz
ENWoxkzqUtu6z+D5U6p9oKpdt4pXNZAAtrKlLQkgOlASiJUYZP0tGtB61Mb+cSEjLelJU7pSldTV
qgdNKGYW2lD4PPQhbdAKRY2Rg4tmNBsbjY5awQsciCVHTrINkX8h5l/PhYghDAKwgpPDxhDdjnfm
IfCd/NumB0MMov+eGjCHLmyeDX9YIQKW12I53OGWhKgxELbwgz0MYHnJKcQnHvGFr6KVF+zjk1hz
UR2kYIg8/ERedavbQJxEjBgAgByRiAQHRmGJNLgiAI+gwiFW4IBxmXjFNIYw77RMYRq3eMsutqqM
n0LiLh94w8CR8Je73GIPizjMW/bvdSacYBaricVt/nCX+XypPf/XxGyesJYHzedCAzrPh+6zouMc
aDYTmstiNnSfeQfRFHVyH18ZbBdEyYI6ZMMYl1D0l/rAlxL0ggzF0MMoaEEEXKBgDIeABggcHWhG
BxjSg9b1nyXNZTm9GNK51nOhGU3pQ1cY0GCmdKApGmleIzvPy/b/87ODzWBnF1jSx+a1nKNtbWVf
O8K9Dvayd/2ucEMbBoaobabtZwcwhGUfdWhDRjQM7odYNhlMMEAxhBEAXDyZCDgwQzRAEItCDznD
NG62tBvNcG67uNjQdviLv41obDcc3BUH9qPD/GtiW1zMv+61yNXMcXHX2t6CNjbICSzycYNc2Cs3
N8RfHvI0sxgGWdlKV0A5o61tFUcwv1MC+EKJNfyiBW7obAACgIJjRAMYpNWwQoR8cYwvx8Bitva0
o41yW1sc2srWdtfJnmiaxznhzCb7sV2ucGmXe9y7JrmjPVxyX6ec7Rmn+97BPPe2h9vsMV+a0LP9
kDwQlCs8nxGM/8BgljP42O4V50s4mPCLYjxhCk/GAhHmMABoSP15CmFQMOoGUTNbvfCBV/ntPn7z
RXt9z3L/b8vBPvg4t172WoboEUj8ZjJb28G7B7yb7158Do19ywkvdgDBnWIB097ZaYe+8qVN5wsT
CO53nzDvaS7iNvVeXpeugwsUv3gavQDUEdB4hPmxFwOswQAUeEIAOouFZbiDClSgwS9tP64hM1wt
pK/WSm77wK/SGi74VAzbPA7wZm/9Ik0Dtu77IE0AkwP7BvDFtqELMmwbjKDZjsAfRAGSFgL92gIj
jEApNAMAQoS7CKwFk8MYVjA50KALGmyk2kADzAO5OAKMXgtRzP+jsiCMa8BLpM6AuiTCuo4A+0RK
K+xMvlDrqPypvzRw93bQU9TAB9tkgGTwKYZQtvLrCGtCK5RQJbJrDCViG7hQuEZKeUTKsXJwIJrA
CNSErkSQJJ6rqrRKvpRik9aN577C58pg3iLgIUigDZoIqdhwIFQBAFJABXrhA1pBDEZhHLAgAMTA
DI4BGkxgELRBIOaKADohmJ5CHFZQwvyhtqaqomQQ69rgDJTgPtLwdhIxG9rwBuGwD+SQDpXrtTpB
C6WAC3+iCSogBdEgGDXDCFwwGYGjsaAQM2owgG5RB/+JByGrBs2DGLbqsZ7LBhQgAjFiBVvRBlAr
OswwuZhKDWn/kc6a4PCUYhvygCUoipJeSCX8owFWgSau4x13Qg2MIQLoyR8NpyEODzjQgCCfhiMu
46WcKF26RyXYcWiMaWMSRC2k4JscQiC2R1QsMrxg5lTYsUSoiVFyxyGlIw8i8p4oUp6Go3vMwyN8
g5HG52Uu4x3jsTTUqROy6ZAwI+cIigVeBFnsZx887Qw+AQY6BKlgRlQUoOh6IQU44BGIgAewYAoe
AQmOgQoAQRP4oR4UohQGIhjuQCHEYRU4YyXXog98LHDU6CWbIib9ZiYHoibN7TxCSDr2YHsgCwby
cSnasSUCssEAszvMQ1QMMqMSaSAUspoUYi7DQydnZyD8sXLM/6QiXVIu3RKahibC4oNiWCd9AmVU
BgKvgAOveoWIWoWCUkUlnIKPdKhiXqaFGqaCMEJ5XqJgCOQM5upmZuaEjEkkI+Y1T4dVgkhTYshU
jgoidNNxlNBwXMV3PFN7UEUhIiBYWADHBut+tib9/iczclON9iIGTEAIfkEGxGAKzjPgzGAMLAEd
skBAAud3KiEmLccjGOSDekVClBM1m5MzYfM0LTNEHqUPRtN6WmI2GOUz2SQ1CWUiUrBi3GM8RO81
ze14niJ5jtM3vdNBVgLMnKOPNCZS1OfBdsNAsC5zHgbAHKI2KSdPdgI5JMQ8CoN3IJQtM6dCdmJj
QqY4eWQhw/8EM8YkRg1DOIsIXjIHchzkmHa0ZSLGQ1PFacrEVoAlG8qABa4GWQjLGwSRWWABr2LT
Y/BtDeBPBuaPBwLAHVCgA4ZgDAAhFsTFfNBFcSBlUm7mTRUjSUcnR5nJMe8EOTLSw2ZGcLApQJUC
VUL0P1ZUTzFmTwWijBynQe5UMY7UTiXHcpDDvzgzJfLFhU7zIdhFIlLmUxsMWkIkPgJHPeDjdCBD
PwKoQvhlemanUGlinBATcGaQdzBkJlTVZvJFdPqFLQu1VIkGRU1VRGNSU6lkhRQiDyKLSosFawir
8aDLEDRiMAfmIZ6BLyJBPIuhBf5hClCgKjvAGTrADwKBG7z/8iG+kpwqxIeENTGTQ1Q8xpw6KFAX
8l7wBcgq5l0BDFTr8XbuRTOHqGVwdVFcpU7a1WNeRlHNR16Tw42Wg4bodUL09DFS9L8qBkAZplOC
RoAAll7vdTKphDLX415EwT4/RkDusyZOzGOXFGRFSGQ7iGQhw0k6RmDuE05ED1PFBEbnhXfe4RNq
q0pz7GpECf0mA1bdRDGOgC8MgAkq7wlaAAewwA3sbwDWExC4QWDf9Gbw6l5fxi16JWgABWRYUmdJ
dUQ44rpItcIANWIAFIvMCGbNtmUhxJV6doV25DTfp2Y5pEsShGUjDUqw7qVkgnlQxsL01U5MFDm+
BDqTAzog/+ylsCRBmEidDrSSDAKejkAcomNjhtQ5XOdiQsw5PJQ1i6JwVWadKglz72hzOxdBT8gg
5uliBMIovAg3wks3KvchBrc0Qkw7OPKYVmNpt8EQtCKwnhVZ9kEbSIkyWKozdNc8+CIZWMEEeqEX
xAAFznQKMMAZBqADugEBgoGpEDdN4OObKoQYBINCAzBvcDd6RWp3BXUgfHc1KyI+hHRuc4Vxr+zE
KiRfjumJ7mM32iK2AGlGrUp4pcWNUIIHX4Y1pCdmbBdsX6aL5HeAjNEGBAQNcqALpMA7+uC1UCvE
eKwOlEcczsAOMMogssEOzmAbjCmyuiAbcmA5tmGhpOCltv+BBFwAhAeCk15YQEQqB9ZWIaBrjBiE
KM7AJjjXhTtqIGDBFc8RidsEC3PgpiTChFsxFTmiDqamMQxBg+8FiUVAiU/rQGLKDqC4D6TYCO+j
ikOME+5ACQiVx6RKA453p+7liyeXiI24gz84hEeYIzSgDXKgDjwnqQqiGpYiG1yAD5C3fmQEWZTl
tQLSnyysjxnEGETBDioAAMhAGVjhFziAA5YBBcZBBmihAwbAFwCB9GCBE86AE5QnsXYKhVwKoDAC
DezABiqmjwcijxdqo7x4aoaihgHZg0FYttBYLfzKCEigAQQiiFm4IVwYhmX4DGjYhuUSGHX4IV7L
O4K4mMP/q4jlpYwZpAFsIKU4ow3ugBPYyBATgjFRamokQglGyo7PcJj32JizQYkVMNJaLMUg7PS2
7ewoju6yDMYEGsFYLOvuoxo3zERZDziEj/gI8MKkL6L/a+vajKGzbKB5p6BxDdE0YucE61m1hgXa
wBDSYqBFehGQhAGUYQ2KQXul8hGwYAyOYQO08v/K7MMyzMx679ZCGvoWUPf0TPBIouLUjKE3ruNM
eswezMw+mtBE+to0rqEV8O8c7O1QDMskgvpOTMHCbtKmqqJP7s/uo6xJ4qxtLqtBiPqemu9gj/Ue
bBVU6wWKBTuL1gjiDbqAgK3LsNQAIBnIwQRa4AM4AAXE/4Dp0BQrZYEG+kG5BtrbhHnkOKyht++u
JS3tBLrO9M7kZu7sfFOqCS20TWrAgAOMbm7QQru1vUzGJtqz6y2tte7LDq2gS2zibo/5Bk+ikwOr
H6y3tXriJM7ekNu383rNDJSplVW16kASVLrniqUNXPrHoJrG+AIAnFYZegEb/iEqp2AWxiH/fMEC
HGDIGEQCba3tiI23O4zkkvq2Uy6tsZq5l5vc2Fq5ASz7CC+45br1APDikhrl8m7blo/aMK7mAFzm
ym6zJVza7Mzc9iCnhmWSsQYslIVrzoAQE7wTLKsCmGCxewEFHkEPeABcsRIaZOEQYqEf+m6puS4F
HXrCEf8av+X64fqbAZ1N27LPs9Ear42P4yKutO2usMksoQUc4/6uxodtyQPcxqE8toVO9FRvyR3u
CA6PRXDMSgfLCLTGBbIBDXCk5BiMI2CBL2KAAYoBED6g34RhFP5BDKhgDKigG6AgC+pGyaOt3G7t
2i6QwpM79hwutL+NwX8bz0QV7/hbqV2suIF8rXscxwl1KEBsq9cutR/NRNsO6zI99WaP5Qas0iO9
00Odyc+t43Q8OSJ55zRNpWGkDC75KB/67vYilBmgG0zgA9wgAPTAElrgKs0AB5hhEFgp2UydqT8d
0Qq8q0+O0WSb1S9d1W9c+06bwHc82m38042RuBvrusz/A6mE5fv0548YggReK8XuoAaVR6MK6if8
yR+AQxbvhGs6QXk0wAZEwbcORNwprLJYWyDAXV5iEDtCTL6uK8HA0MHOYAU/kbGo0TyGcN/7/d/V
4hMAINNXYqT4ITruHeDZ/SncHcjcgol5x5BHyt5lsOKlQN+FGeMlLOAlLL+gKDruQA1zERpRZgWp
c93rJ8yDch/MYjJejGtsYLHA3bIsSwWUQRbkPNihod/GYAC4AAW6gQYAQAQ8bN1zszvevTSY2Pog
IuLfRdy/yCBqsJHrMRiz8Z8EHgAIXgUhrAl6PjFXEN7zS95XfnKXwuVVwuJl3t8lbOMzvdxtqyLu
GLVl/1E3kUor4BoMVV4KWx7pdVh5jFIc2thDRLdQkuKYuqjeWWUb9qCOu+M6SkctskcDMsM4zLI+
P5dIPcLz+/J3mCJ4BvKOvokmTJAjj+ATVsEYAARw/YaGABYjLoF9L+aKVoWp9kBmhrT0T785Ur9j
WF9RXp+APUX2k5M9av+dFsJSmaI2mgMGHguyKKMP+qqThlZGrFRrjD4C4F02PKIBCJLokMQEuqEY
WiEA3AAgdD0SM2BAhxXdaLDr0+fIESlqGGZjuG1PG4ZH+kjR0IfYRoafVhljyPBMxD5nGEpJkLJh
n08wxPWBVZKhhpZ9tuWZiHEbDDQZM0qBcZGksQhoMP/2yaHBYUqHd2zmEPozY8OWHlVaPZMRzSWe
GFuqkdJnbFCyKGGgVclRDU+TVxseidpHw1SNVcMyzGq1jVWUVslmnArVoZSzDY051PgXKEmcnVwe
rknSX0NifRxrVIkx6RGunP+i/Qv28eI+lhNnvIMZJUmHPIWGjagZ7WjPEjOe3Na6KOWMSiQ3/gtZ
OGWGlo9grs25oWfQmzM2EZFRFck+pSm6JJntyJ4m2eqwsGPHCHnz5dOzeCHFEIyOmQO/bgkAQIwY
rJTJ+qAnQAAUj4whIBIWWLOQCAzhNlmCxD322hGxbXaVVRC+xpBfpoVG0mgk2XCddn9h1yBDHgq1
1XX/yS0nn4RH4CZiWVo5BNRDJF201WmpHaFYH6xJZJxrlV0WX3MNoYXZWjYC2YeHEi6pFZFZYdSA
VUyKIE5QOGV2nW88gVUUktv1cRFHG1JIoktzYYQWk0r+JuaGF3boY5wu5fAgWNBtRuZaa0XZ0JRn
9mElltclVSN3c77ZZJJ4imYhdh+qkVQYxpxBwnjlGYGeeZrawUIZbWzDx6FzYvZUffWpUMw/2Gzi
hiXubMJDB8d00E03HgSTYZOfvQZom0Bm5JtgJYVII4xg/jXmdaI8mp2kvp4o6JVxkWQonU5CSqds
GPU6J58kiVCic2oGCuSg1Sa4JaLsMqTAioxRBq6S/1y1BpGcsmUEFofZnLSUXvFK6A+8ie1FUmQf
ouFvahKuZSihcDbE02gtQbeWkvluFpG3xRZrr7/jEruvUv2SZGe1C6I1MJHEknUSwteJVa4afEhx
qQvpcXqeHWB8SgIaozbX68bd9UFIfcmQYQIH3fwiDBI8CECEDscMoEs57Oja0DZUHsEPQzmA7JJj
EAtd9HHt9qEKwTp2a65LPJ30kNiGwR2xvv5S3HGTGA8J5FpntJaZv9Y1B66+d2OXd7nSdnTtvity
mWiWRgaM02hFR7RNzOU22dK1bKYrp4WlrdVlh0El+HWiaOHUrOevPdycGqF3F9S1lBu84OUYZZ4T
5/9FEvk5u8fSfl3oGT0F47F5oNGGNvvkrHOnnr5wxjYJHIfTEU2UpUZ9MSTDSgvdUNMKCq5s8ggX
YxjkhwcO6Mpx7vAtWLRVaAgO1smYxdZ4i2njmIMsRKyNVW53d/Pd5gbYh9cBLnZKAQzYsNUSxJnM
Kqc7DuZ08zsG4oQYFUQJMZKXoQod4S58OYyJOqeSiGhgdw4RYGlEQaaK6aZiasjI60YHPDS5rEhn
EcrGsqStGHnrI9kCjRqylB0EsvBFDaTQxe71whs5BUXboSFllFixESrJiccJ4ofQEoFttKEO+8CZ
ptBDHjvgrAx1sMEdIlCSk2QpcA1BVTIi0QIOuOP/A06YhRMSoQMBUcEPK7DG6hi2lmO1sC4XKyJj
jiACrjSOIUtUSuBI2EMGYukv3HqkWYp1RUQFhkxM4uJ1sgMafkzkhBl54Wt++BAx3quWpBSgAraD
xKcYQwpdyMFk1NCGbLTBX0dowxmOWaNskOA1nOiEEqyyjTPY4QyTOUIdbAZKEnCTIlIAgBT4p8w6
WIWYZ6jDdl6AhmmOTQpGkMJkqumCbKBlG8BEQwW9qYSTqIEEltoOPl1gg2y2wWat0eYZStaQOizT
KpW6Jk6IidAEwRObGCGBNKlpTWwGZZskAKUSvimCJgATox0pJ4UciqGyFJOZmDwoCVqDBnhKATSV
/4onWoRphOvxgQ9tKEMZODU9TrlgH9ogQQ4MkVEpTDMjhjhDPIESTvukwAST6MYjnCCAWWzCFcdg
HxJksYJyfO0ISg0pOLuA0j5sM0k5kcI1DerU3VwULb8EQE1181J/1XQYZ2iJMXLQBXtCNRt2yEZL
8DlXkrxVpN+Mqzgf5lCGKrSl4kADADohE8fmAEPCQgMJTiIOmzLpnzaTmzLdqRv2YIgfvwTsaCrr
rw/Z9ra3JZNtj7CxD4UIt8aKIG7DlLrhXue3xH1NbY+bw+v4M0xy2e2DlMLBMMkNuL09rnGhq93u
Che313Xbo3CrgQRUSjzn2dSm3MiCbRojD0pZ7v92IoC0ZKyhGxz4AjYE8IhN6GEMHTCILIChiWCc
RnDaBeVxT4PJBj9Kvtz1baRgdNvgFjfC3o3udCUs3fF+l8IRRqaFVlcW5EKXwdL9beqCm2ETb7fC
thUxh4HrYA9byMQXfpSCt/NbCOd4xxJm8YuH6+LaLjfHwg0RgjNMEiDc4QX7iN4aM7UzO+zjBdl4
L3y2K4L6kgEQk/iHGFqRCBmsr31jsMQ/aOCAD/MYuMgVnItbHOEie1jFQ4bxm53bYeOaycV/SeiH
l/xdMxE5zys+MZNtPOchI7fROp7xd2sLaT3TOM9oiqCQJa1oG2Ma04bGcB+M4bwyqHF6mTJPzw7/
ygcfQxdVKUiGFuDxhS8I4NaPQEIhDcIBP8Tiw4becaWHTGhGn3jYyV30oT/tXECLGsl63nSnl23c
8G4X2siOdqTFy2ITZ3fGgA61o68j50YPG9sGY/a1N7ztFyMjB9l4Ac6oTL1OuaC9Z9DykKtKhhhA
ABxi+MIjZPABGRxABzpwhg4CMAVNxELcfHZzhSv9FwhbGtE1frSf1d1diGP80t9WdrKRnGgi/3g7
rg4yd2Us7YgnF8Vu1rjKOQ1i7cqYum7b2MnPCWM8y9fIM78zyl+cum80gARlwBSqqXfUF5DAGEED
8nW6bJ8YkIECzBDDFJbxAWzwYAw6GIAOaCGL/0EEg8QRl/q08RwmOeNcwUj24nV0u+c6K/rCyD1y
pg+NmedumcLOjnnNIV1satf84ub2rrGcfRqde5raHk92BOku8wkXWt0tX3CNpy1xOnPX3Hk4LwtO
TeX0uBEMZSBBNujYeRiBL2lMgIcfpzBwHCAc4R0YhT76we03N3fdj+f4pZlspt9v3LaU7zOONRx4
nP9d8I0nSfJdmk7lCEr1o32NMmGaEwCECKBqrUs2wvMacXTBWADlRFBEAFCYHkEJ1SfJNgDwofnb
Fp7dtJQ/valOjDTB+9BkM2jyfunUW0ogCv4gN/b3GnHEfcYAAJRWTM8UFAuoG+CHIOJHfhhhfv/o
dwaCkFCGAIAYAX/mhBENeBLs50zIJIFoolnU5U0kgIFotUwRsQeGIAV1UAY70ylERR73VgedYAgR
AINkogZ1IFr+Agb2kQwxoAjM0A1PsALj8A84MAZcoAND0AHLsAKZ0AiCYDO69YAfIoavQQww2Fvb
5y8AVQcKSH8kwQ8kYAPch1bZYB27IYIM0QB4qAZkCFFdQFxrGBRHEE3ut4AmKIcoWE788BeG2BCc
cAfh1wd6GCYu+BpkeB3/x2MPCEqNeFqt40UPJDEUsQcMky3ZwiYTswdZ0iJBcQf6AjFw4S06kSU5
sAeRpBMcAhrHsiBMohMuokQw5ByvGBc6kgf/WeKJYGOLH1JBPFERpcgmTIKKKqGKx+UYIEQRMPBK
dVQtyChCocSMo/iMo8Mk3hJVdSBv0sNG1LMeWRY0GuAYSlQKJbEHSBNrvKAMKLACU5AG44AE7NMB
ZrABFuAL3PBr2dIE73AyXqMTJ9MZrTiM3hKLi2WMMRNDoVghOdE8f2EM76A8R4A9vlFSeXAxrCiM
L9IrxXiMmPSJoYSLmrSSDWEIHYkmIBkuTTCSH5IDMJAld7AK15KS1+FEDdkogzFL20E2huKKDSET
JyEYN4IcE7RFDAQsipKTvMQusYEbAgRGo/ElU3kvT9ImvkFK/8I4DEIuPBIUTBkaT8kr+eNB/2HZ
EkNpGkVplkMCQGkZKM3TBqPXRqbXg1YGKlLABxgkPLIBAF0AAMmQAuQQCt3gDlOAA/3IBVwwBwNg
Bt3ACH4gAsGgAXTREA0ZJKcBHanRkBUzlbTYLuPSkCd0f8hEDA1gWzbSll6JNnARl1EpSf9yIpwk
RGUYmx8ylvInXMKJEnmzImdzkXc0H9ZCSZ1VlcXDEM8UPN6yi09kA78VSbY5QDgRQu9iExUkMnBy
LI7UJikTlMsIMGGEE0BhJaQSPBQ2nVuJnvB5nlCknD3EMe35nDzBB2gQb2nkl0WFHu0lBUfRMaKw
GCfDFXZgVU3IDLLwBfqYBv7YAVxgBmYADv/AsAJZoCs8gRmWgSBndTInIZ+CEZ5CczHYyR3wUkGU
w2B4iZ4rhhYlihF2Up1TFJTISTBtghO+EaPj6UO3BRYnETpEUkS1+SayEREp0RraOElA8hTk6Rpy
0wB7whAw0xKSgyy2pRkv6RLdiZtyEZoeEhHkyBvwiSecU5jY4jecwaRb9qQqFKVykYu8JSU1xDkn
saVeQiRJ8kNN6iNWkQPUQacW9A3VRAIBWnqAaWUvECqsl0F9EA+ckQfgY3WTwDRf4A66gARI0AGg
OgBfgAUEhiBZci3WQgxVeqV9kKXYEjd8kywa4xr2ol0RYkGFogaryhCvE6YOwqaKIqu9GR3/m+FF
t6qbg/NmxAIfeVITKwJASyQfR3JJhcNJdCqoUHk8ZQJLhvE1zBExJ+EnpPGlanCjirFCGgI76KpC
M0IjTUmfAJQR4mo511Gt9HIcT5od5EgsUaIihtMZZQEdhCFBbWKvvlpBCwQDn2AD2tCX66Uz6bEP
qQc0ZWEot9EQHjIDXRADABAOycAE+uEH7oADFPqptLIBKAAMGxALIiAKCxMUZ2WkbKJChPEQ3kow
NEqwxOKr0ulgnxEiasA10YWRo8OtKuSuR3qx0Zqu2pI8iNGWmCS0i0G0r7FAzAIj7/oYGAgaLXET
1tIUmdQRrWkTgLKLuqEwiQMYqnovYFki/y6KSTQCSklBE0qxS2qSEfzQEtnQG9sxnQyhlJkkIysZ
EW3bYEnBBo+kEXIzt1/LW1gxtnVRtrZxtouzHfUiKX5FIW+LElvLSV6bIDkUttTRkO+IGPFSuhlh
DNtwKWCQXozaRi5QBi+QA1CnJZzLEPWAGdvAEeBTBDGwDpMADiKLA56qa3MAYGLAA4zgACKwS/yw
HHUBPDeytoRbpNXiLTm0rF3Lnk2RtwyBIGRBdxVUmOIbQZd7B4TbGqelJYiruB2zvRZit0BUFmBR
neSrp5TYXFZRirTRB+2rAQX1AoKIfWhCOwLIEDl1B6lRDco0U5h0hnVRKV0gBeTYBz9DAv8c4RAk
0AbHFBQvIAo2sBuaJQWGUk1GkA1Wuw2ElQ1h0xEAtbcwQgIK8FSZIQUuME6XwVLboQHFpAocMUKC
4A8d3AdNcAbi1FkALAUCvDVShcIkYcB+m8AL3MCtgVrZpwGVIk4VfMG3I1Ue1RDswVBJvMQa7Exo
4kpSwAkkUcRG4Dw2IVNV7E1t0BpNUDPZwAJSBpjUc3obPBThB8ClQMYaoFHgAwApQAZMILxfsI9p
QAtXqANzQARTsAEhEAf98DXV1AUFRRHZAApnsMWilcFoxcH6+8EhTBEj/DAEHBRQvMbWxMIIrAQV
sMmj1gl2QMvbgFgLpRQXLMpBPMTVdMT/NhHAA2zGmPGRK9zCxPBYvJoDs4xXtozLCuDJa2EM/tAF
29CLNrAPD5UTRiwFMsFznmd5AwhqexZoomZteyd8hwZtdXfMfWZd6iZiMLdxwdZ6PivOQhdjN+bO
j0IIaOAPZRA9OdNGPGgeQkUC27AjLncdbAA+KZACawAPFiCylpAGPEALAtIBrkAEG1AD8YOB8fzO
6Xx54sZigtZzF0fSkBZ94zx8CaZt4ybTd2fOhnfTFqbSMe18+Jx4NJdiQL3TM83OFndjykd8nDfS
11FGAGrQTs1GbgRH+QZfJOF2rwFrvwsO8OAHU2AJF00LOsAFx4ALj8AIG0AHwZAFgmfU//HsziTH
zq3nbUT3efvMzj7NaXi2fKJGY3oNbsBG0yL305c2tX8taX730szm1uacY4c9ZxTS13M9tHx2CYYg
CnUgCfMG1TxYHvdWBlmWB78laFahAK+nCDsACBawAjjgCrTgyFwwALRABOPQAZlgDVoz2MFXd0g9
Z0XtW4rN00OtY9l2bcWV1z/NdiGmcgwmX3j30sVVeH8XbPoM3EB2bnRtW4Qmcy5t1Msd1Hud1M+X
boFNbkKmdn52gzezg9KzM/fWBkDzDCN9BGHQBcmgmB+L2og0CjjQ2uzDBcvAAzwA0sHQDxcG3blt
1Y89XIU33J2XOshU3Ep9W1603Ay+zv/OB91AdnNPDNOCTXFP/Gf4vHLmrHeI93zFZXzAt+ErvWiO
rVxs/XuMvW13inEkLlwjiXQu4AJT5rprlOP4dqAZZ1uvFwMqAA/g8A/usAKWcACODKodPQcboAmc
qWjwXGI28eHO19LMteHottLyKl4dIdLIzc+ahhG9LXLN510w/t1JltPLo+LxBeeL184hnkMirWFu
k2h2hs8s93jUAbSUpHkvLs8W4i+GzmNWseCJHWl6buEuB7SYNJJBlUabTVQ7vg91kGWsR27ORwJI
04Q7IAsWMLIXwAVpQJljwAMoMA6MUAODIIMITudsbucdd905VHxBDmKGlt0UdufEUKj/R713PCeI
ca7rHAfhVS0CcjZ/1yVXfsdSi6EGL+AP36k59JdQB1gG1xGCKg5M4QqHaZxFw0BhboEGaiwZdvBc
R6AKy6SqDBGCd7qIG2wSJ5EDANiUXeBCmJTpdSB3m7gdj8hQ5X7uQpHuDgbtrUXtHGR/CSVTglIW
j+Uv7CEIv/fvViEK496G17VN/SQ3qsBNJwHvESHvyqSrYEN/qWMMMJDLA63jEDuggenehNkQ/yc3
7NcGgnAEebCxipkCrMAMwosDOGAJxtsBSCAGabABZqAPIhALTTDuRcjvutUi57cX4K7GF5/xmJQN
5q4ULKUGVbwN+a59OKhz827yS0F//2SyzOQn8Wksym1gA+pUqEplWczu9XUlN4S4GDxc9nJBAuyO
9vZeXd5O+GPfEeCuTovxMwzFkUmxGzAwLnMyFmUxGrbxE0FZ77obASRpCP7JSxzhvdxDjXJxm3Dh
E5K/JLG0OVjMB9uDpsHKEq/h+bjRv2eJBkhxTmJhSaavOZEfJnHjMpavEpi/ISeRGvcStkewohpA
LbivGaMfQo5PYXAhSxi7+hHs+lXLtxoh+zCi8keRTg77l0XlRvsAUMaQPdOftbIE0USuDBWt3xft
j3OghbJdAydgDZ6PQmWZExvTBAABQ0qfI336SNHQh98Zgk32MCR45IwagxP7nCHWR//DQILGYGQj
2EeNFIojDYI02IaglARnClLkeNHgERsvSR6k2MeGSIhqXPYx9u6OyIoUN85EaXJkSY4oj6g82NIg
QUN80EylajXkwYQ+eRr0WbDgTaxSCoYcWBBiTJBi21acKmorxLMZ0ZyVubIs3p5px54dOzUbXrNT
6V6dGbOPXbwSE2NleGRsToh9Ix4EfDDkWsEhj7zNq9kxzLNS+BlUHHnv1MlTY0LUfJIw35mI9eLt
k8CYlDos9tkxAtyO8ODDjRhxsY9ENmN8DGc02GnzEQDVycS4pczCP3c4RiFBwmXOACxi5oyz0u80
SoJ0YZ+E/Ng1bZFpC4dGXZYoZ4P/to+kTqy002JTrTCy6DoIuthCSyuvgSjirw//FGNspsUkpO+/
1vBTrTOx8lIDscEIyoE+vQyqaTOsOnPNMKxAY0+xt9SaqkQP4erPwg4LYi8j2BBEMKad+ojxRc9A
FFEsG3E8kcCphtTJRRVXBA2us+i6D7YliZxrKttkyqmiCNBoowwwhhMuTeKG26eMNrZxLsezcnBx
m+oASCEFJpgB5wt3eLCEC/E62OCRcRixgg4RRIjpCMQc24q9Bd+DscW8NIzvShf/8zI+g4i5Cz4U
WUSDsvyYlEnTlVQNUdRUY3o0VQslZfFUB2uVkLXAtjJr19cuA3DX9lYcFq2Q6Dzr/8sGnVowP2Ev
Imym9zjiK8wFoWz2LY6WtZBa1CSL7Vdwg80rsiOGsnXamZIl1j/YYmowtWiLtfWsJsYkoYzfgjvu
OOOMCw6MMkiQwhgRUGWvrS6qS6aCNQDhwE8c0kBijjk6mGOWNHiw4oR++pBuSkczGrfbY7dSNiSU
3l1R3oKGdE8/Y0m0NNzFOOXyWXdrvstXcGGWVma+FAza2F21nYqY91y11R+K6NToPYZygtpRvKrG
Clv2YMO5IOkk65DZBdlzdN1Qy45IMYKuAuzApL09gx8aQY4o7JancroPqDWQmii95YPNn5DQSCg0
YtTu+tNpzwIJwlrRluzsWH96Mf+CbbLRFzh/+f23XztYeOGMbVb5Sizb0DjtzmRSgEAZZroJYAoc
xkFigxo6wIKIDRjxGL8cTM3aSCYT/9oxRhn3m0MpC4Oc09Jyeovw/NSIUS25o1R8NS5hwpt7HJl/
FGfWYn1SeGgvuh5KERoPkyGSqTeKI4sOuh7t9mAZtiB+oAopIZeuPAIxlFKQNhwMRaWJz/tIMreU
UGRXT+nWWQoHFXChhBh3cGCzqAWRFDXLfQSBn0bklxPTmI41Z8AftCTSlYEc7CeOymBMclJArIhA
ASKhSIqchxMG9qENMZwJBUVDGN2coTdo2ty/1LSPF2QDDXygyDb4UpCj9MEQ1Yn/QZ4o8LplrGAU
OACPGXBHhIqdIBOxkEvRqpFGsEgtgEpJiQF1gsA53qZFGVmKCMEWRJMVDRYtPB+kECISlGxwKjbE
YR13mI34FUWPkIIgWs5SjZSwRiMqrMgbtxW0I3xCHHYgAWLQIAUjSGEbxBCLP6Sgkpe0QQGc8JIU
upADLLWhDuPKAQuycR9DZMMI2+jVZ85AFmO0wQ45QAz1sqEENRRklKU8JRXPcIYR9UEc2diHFFTz
glUSxRjZ6MIoDWKMM7hACfzrwwvQ8AKxGAMNRhgmCNvgD0aCJRvLbKaESGlKVBJElawUiSth2R9Z
0jIxbSBBmFRJggtJZpeCIJk7/+HJkWIek23b+GQog+gPEtSFb9Q8yzWzuc1uUuSbXVACR8RBShgY
Qgr5ckHnNlccfwmsDVJAxh7QYIc2JPOesDzLnVIQg3Xw6R+jkB3tOtCBMWCDEYyAwglEUYFOOEUJ
aFAFdI6wm1zsUjLCJKYxkWlPfIqlDdno6KeAWcqzteEMggMLwVRiUnBScyahVAnJPvPSDN50REdQ
wzzreQSMgvJR80yrQo7wz5CogWBwFYlcvQlOcQJFFHZI6Vl6+ctgZmOYDgwsPXOCm6186Eg5sdZW
sJIZSx4JXKplDdGmkkFiWSgzr13tZXRFLNyQtrZi8e26amtb4qJ2Rb5lLVh0i/8V2QLXQrN9bmtz
u1xL4pa60GWNVWAqU85prjj7qIPo3pG86J7FCNVJQTIMIAQOdGMKX1TqUomABUTVwBoiCEZrrUUR
2RJEq1ihLW+nCy7SUnG1wX1uaj9kXASbVrqtfYlyLVQ44R5XwK9Fbn+fi2ALD9fDHxbwg0McYg6P
GMS/PVJjPexgFDf4xCdmcYdBXOIXT7fGNh5TG14Ahpjyy8c/Dg4Te5qH37IWDVhMgSIM8ARZBGAF
ljgUxjowhWXMARqoqEEw8hvcAn+YwwXR8HCRO2MvrzjGN4atjdO8YtX2tsU35vKn1CxjObc5umh2
cGPo3GEFw1jEKB4woDv83y//71m6NH5xcksb4uaeOA+XewELXBBT72pOTXZwwcCk4JwSUxHJt4jB
JADhBz/MbhwWY2oikMCIGtTAAfhddKDhXOYaxzjOsPXtf++85g2T2MJd9jOv91xoMRv6Q25WMZt3
/ec5C1vQ5XX2oE0ca2V3uteLTq2vp61oNHeYtbihyB4uR4J9uMBzniNOTVlQBzQYg8jMNsidiJqC
DwDiqLqwxDIwhgQq6GEKYxhHNCaQXzku29vDNnjCn83r0QJ4uv0FNrGL7WZkR1jZvI5zb11M3N3C
u9t6vvCBtZ20qVA4t8TO+MKhjegwz1rMZ8Y4s8eM6Mbw4QwkkASlLd05S7sA/3Rv2sPCJcIwMqgg
GULwwz90gQNGVGwOZiACEcbAAypMIAv5Tfasby3jiK9IQSaHsKBTPm1oy3rAyO72r9V+XJOzts9s
zrZvEwJykF8GuW3XiIZbXtsAMzfmYXc4nS0eJtnS1rh7Jpnf+k5tCc/5LGHyreEbb8k8kMlMxan0
mtDExDpswxAp5nMy0GuASJBBFtzBwQZO3QEzpEEPOkjDGGqgiYNx2yCFgznjyXtnDeg97RGJ+7O5
HfySQ9zAxSY+VuYO+F4rsw0asJcRBqS/8A5GLFe0ZOieD64j++0pNmhDGLDShC7gxhgAWBEaugDg
e27fIE2Q/nONsX6xEKOJFv9xJvqB64+bj3ahRzgNwNqlxCIs9JuJwLqn0dqGLoC8s0osVFKFM8gr
kbi/DHqn5Om+0WoD8AMsEBpA/vKhVRILBKwngljABkSrulCD6iMwKTDA22uCCsBA9NPAM1ACWCCE
JtCx37A0mtq5IHOTbdgGI/CMp0hBC7GTLoiB1WGCZCgGP+gGS+CBcdiAp+MCDMAFWtABM/CAYDgY
YlClfBC/qSA/3CIBf2iDETyrEiQsBmQNB6wLoKA//6rAwdG/iOC/OjAIuTk/CXsKGwQMO2ENElRA
NwyiI7yQ+fMMYpCsuLIBBei9/PO+DQy/8Ss/rOjDA1zDwqEcqNmGPAAJrWr/C+dpgjxQFxwxhghg
FtjYhpL4xA6Rgjy4DwmRxa86n7/pg08MxZnQRaFBjG2AgVBZCU6UjEEyiYxgHogARmwxpCMoxQc5
IDuqpyo6DINogFVAiYT4RLi5I8wgiCExxkLipGf0Gx1qkOJJC4dgHqD4iNvLRVnUkanYBiCANBbg
uZlKt+SogzYwhKB7ErFoEENYhTOojnBIhjWIhF9ogX/AgSlQqjEYg6gTlKpDABSZu1YUiVeMIIIQ
x/whx5wwx5DoRUtBG2AUxv+YOynICEPIAyhhIGWEAWYcR3gESYAUSVAsi/jZI1RUxXg0CIxUA40s
jVokycogiIXwDLWhHEmR/5SfIIamvBCcQBX8sBLzSRWktEliYUpcgazYwBnYiB5OzBQI6adT/AvZ
8B4ieRpcWRqZgA6yCMvpiZHTwIge8pb7GIwcQp7HoRcXeUuQXARDOINI6zHN60F/2QcWOIN2Uy68
7ECNyAEAiIEYIAMyKAYD+IV/WIFxSANGuJgxwAUM0AFcOIZoqIKD2ZoV6YnPCJCLKEuh8UYieUwu
qRVJ6Up48cm/RJXIIEu73EjZDJOt/B4wg0rdpMq25E3XnBtucY0MKhsfEQsN2IZIqRmTkBIfeq7/
wQts0YvCYU7UcE7wvJAf4ZXXSs1UsZ9fAQsZmRmO/BCWMYgS8ZVNsZXrZP+QmtmkyIEPYfmM9+SZ
C1lHb6lPVIESs7CKOiiDHuMcf8k8TCuDzouAy4DPJykC64gEJhACCFhIh1w9Z7hCLqAFM4gGdohP
sBAi35ESpEEK/xzQm/AR+sSMvcyZqYQS2LDO/VyQ/pySZpHKjOggo7SVGw0NdFIhwAgZHOWIAuUV
KsnKILWNvmnPLzkCcXC4Urmb8nGWAR0ealEMxbCNwvgRVWmWIREWbGEbHMEUJBEV8aFNrMAa2KhR
UqGMMsWKM70Ux1wVKTGKNq2RPuoDuTAEMnmBScM8Bm1QMFg3KUADGJCSNK2IaZDMJYwEE/iAD/gH
FDiUDUCCY9ABLKSFMYD/AkWhmxxhDSmaCVEAoGup0y7J0+vsmi5d1d20pJiAmlFpTzNlVUcNDfGJ
ECgVFmEkCCqFLnFYPiHBEZMAM7WBF7xYRSk5GPZE00pSLeT0SWRdDMQBEVmBSrxpkdGITVGADnO5
FKnED6ggDSZpEM7gEe2RD1e5D3A9lQLZkPcw19hkmcA4C4Zqmd6C1j4QHMuxATMpTHRDIjSxAzCo
A+Z4N3u1JIa4k0iQBwMABAhohSn4AiqcgzFwhgu4AB0YB1QAhlgIhiNFEOwsn7N0m6mo1yxpWOVS
jW01CMiaRcrhyE2Zm3nFipUV07lxHAgRFoh4VvMp2ROFJHKNjPmZnz/1/74UqSLUSCEY0iPFaZtP
IQvJYCN5hDzZlBbKCBO5aLgZHYlkea2qHSTavAm+kZaXwAjDeLyeGBHuuZJGqtn6uFaxlVHBmNo+
EAH3sAmYcKCd8ApCirAGuQi5pQkqUozpzIy2rCac4QdjOIJ32A0E9a4k4rnhYIGBaYB3KBwbMNxM
4gPrUIF1MAEh+AAxmIKn2oAxqIUD0IMB4IFDQAUHiAV0cRTcgxSRYBulcNvBnYvPBdv76BnxHEbd
TZobispeUQMbkCPKCVzq8d24FaHneouR6Io0goqNqAvKwZT/GK0juNqfRK3eJaQc0FdHyYEukAKy
8Anwi4hrsoNiMghYaP8DJfifXCQlNLCqBPwUl7KDeyqIbSABF1hfg+glOximl8gG862N9F3fnGgA
G2Crs6gD3igccTiDLrArCMmGNHyJOsiBuZqJCtZDjXApDb4PdssGkglUALCB+yABCRQBBQkvDxYJ
Er7gM/jfbckGO9DfmVCCbBCc0SLhGtRDCtZfFj6yF85XGYYOn5DAiNiGMzACEmiAlezhXUKNHv5h
giABG8iGhEgAZLi5QV3Q7vKx4cg0f0CDbYiAJi4g6MDgYbgcLCqCNegFZnCCN5gCHniqDqgFZxAG
2D2EDbiGYIgFQTgDTkAtIJCC/2WP8Fogg1BhJXZhGHZia5RgRaVgCzb/CAzW4Ma5iBR0pp0CY6xQ
4ds74QSm5CSmiiXG5DjW5AlOiTtg5JAgAbcCl7XqYiMsQWLwXwDOxQFeXyReYV0Btl4Lrj7LtksS
MKJxrhGzRTVDO0sCu8dTLsCIQzjDraw1rW+WMzcDOw8DO4jzvgPDC29eND3jsGYmlmuOAN54AW/Q
PMy7NER9gU6Ak7BzMwAQPQNYg3VQBi34BRRIXUbggiGohderGCiwgkV5M+jKs26urnU2NmfWL+Vb
kbajsWlOnmPjuEPLjKxt5nEOCWimLo+W5jRL56gsrWbOp9/bNQ1j54q26ZlotIsTIGWONlw7QEBj
MZDeipi2sZ1es44e/7C3272TSzBgezR/eIFcQCIfXFDgAAWb8ggIOzyDEAH0koc1oIAW+IBJ6GNG
OAAdQARccAVC0YQQyILrgjek1uqbBj3/6jC8q65vq2vh++mQXjGYRrSL8zCaTi7rCrayI7tt5i0u
k2tzFuxqFjmSS7RoPueoHDOZwy67q7A6O7HE22zEfjAMIwg+mGLCTBMfXJPjkIQX6Kk3Lrb/8ucY
AOhfUAZs+IAvmEIkOIAhGAM3GABdsIJDQIdmmzHc2Dvibi3H9jZuazDjrrViS7TI3rjFJruexuy1
uzOau7atY+rJU7hlqztnS2brzmzAuy2zc7nQlumDO+qp2ANyQtBJ+/9BJeKX5ACvHIiABDDs2hIB
WEAvFYCASeCFX3gCLOABLrCEMTgGdxiDKTgGKLiGt3bpaBtvn5648la4hiOt4ONuC49owUts5Ibu
qQhAlatuEBsQ8ea7DxdxEzfxr0UxlB7x7064DV9xMpNxF/890mquCLi5zGFQNO6X4/C5GHY3x7MQ
ERC9FJCHddACeMCHNyACd5iDNOCCY6CFDkCCDjiECYDoa8NxEQ9sQ/M43Qs5jxvz31MQ25u5ET/v
7q44v4ZuGGfpjLYxtLM9liY+Nk8zOrezvQYzWhtEbQvqPt+1uiv04wZq3soDYyAB0zbU7kIin9OG
M8hqi76z88siE0j/Bnh4AwIPgDQYBywwAyrggoo5BPt6CZqm68o+tJCmO6Hz8wTjuAp/9exmvmBr
aRC3cc/ovqRZDoZSQ1sCFw2o4I7KCUHsp8B6KaJ4yv6bC/RLvGAPINRYP0rSCBsQBXaKiE8AAGwW
JkZyIEFcFxIIr8S7g/XDvV2aQI04K3/AC3IXC27qBNz79U8Jds8ILGKnoi+uJ4ow97UtiHR35r1q
dw1Yw3g3wHmXgnqvjRc0wUskin2/pX4H49MAeGiPrDMoAwtBBojvgwiAb0kLctRO48R0Ik7LdzA7
Anarg8Lp6skkBxWgBmX4AGwQg2XgAQOngg6whAHogBrIgiowwHUX/0F5XHiCoHd7h3hGRKtF9Cxx
N8EXlIyAt0WCX3cJXL6LkPYLofa3vPaHX60FBPeoV4Nxp/ojIJg6QK0Y7viQ+Hh35Mij/8mkPwJu
CmOD+AQYoNIUggi0jQ6woJOwPZEzEIiy6IqVcaCy/YRVMAbIEMuoCJJURYNLkBSJwJ9WIayH0B6U
2IY9UAILyQHocwzJQBcNCBUpCEbAgIjD0Xu+7wO/vz3yFInB54jAhXdR+fzQPxbSN5fTtxHVP8nW
54i97/v+SICuhBSluH2IOGar8UaodWPl3wZyIgEW8AZ0C3KeyzS3itC/hw3kVQNjUANi+IQ6sI41
SAF4EOtZEAMsQP+BZTiGAeCCAxiDQwiBTFCFWSX9bVn9ogEIYlL69PkEQ1wfWATPENTAcKFCNWj6
HNm25yFBKUcIZiNoUQnBjVI09BFIsuAqYwQXqlmYMcHDjQYRKuyDJoG/lRTPRJxY8aJOjRTRiNx4
BE3LbRFyhuwz8siRHCJhEA35UCBFgm02LuSaI6tUqHegftWatc8ZqASZHjG28Q4xlyGPdMw6cCdX
ukFD+uS4sWWfJiI2qtIZsw/Ioiuryu3TUTFanTmPxGU8kOvWlWkzgoV6ZOwRoaEpuoVsk2tkjna5
YuwzuTLXy1pR++0DWCNUoqGNXnYrF2Pru7H5oGlTxoURI3aSK1f/bmf5cuX7WJCQwufIZqd2bae2
DSBGMnK9ALX4hU2MmFAczAw5gOtYBysi4pztnt01RdicMaPO/lUmYIVp1lQbFEWFGmP2rQRVXSJZ
lVddZ2WmUzZ/ESQYYYYROKCCK8nWWGuvncZZSHe1dFcfJGSFkQ0EieLhSiK0aNREFN3VYmNybQTS
fl2tFGGB280V4X0DnYQiilgRRMw2rBEkgjhGtVajWaqVSNCJKxW4EYsk9oGjUNotmWSTckEppU5U
9hGkYwveFddbC2L3o5dgqvUQQ1DJNqdheWzTxgv7PBcddIU+Z4QL++zzwhnG7IHiln10wg9FkxGU
DADJFNFLJJNg/+PEExTw8gQOQzhzgQ6HnEADOyLEGGWOarIZ4WjcoajiRjh+iZqRXiaJYkVOapgV
mx/eZ+OSWd0hJ5G89nHkii7pmRWfT8LanU06zUohhbF5GNtGZaEVF0FIrSSgmCjWCGdwIVXIYUZq
odidgw62VC1arFGWEWBt1tsmiRtl029Z+EbYhyrexisXkiDu61S/j2knMIxZDbxSwa0dTJCuGzH2
UMO1nnbUSjY4e9YZexiTTR0sDJrcoS8Tuo83jG7Dx7tiakfSYWcAkIIBa0QCDgdOvMEL0o/UMkQA
Q+gwRwhV9EEpl0IKTLBV3P6ocGT27mSYvuRKEXFWVaFZMV396f9kpU4dT6zdva1lp1uZ+cJ4b9e1
Xo22sSsRQ6WuYd7F5mEHS2VlhCaniVqE6wLsYGMko4ylro6pJTm2bzolrJhpc7fNsKNxjnmEglcJ
MJF7lbR5Y8K9m1TofTeVLcpenY5jgzWaPe/GaGgQgRQkHOdCzM1B1xyiLryQjVKAh9SJq/ieUcF3
KvTySzfU4ENBKJMIM8YQqB4DBTBVuLpabbBzKHpjf5dcsRoaX05lu6uHqThXaJALMO1xNTj6UGb3
EDVUrkIbEUHBaiQc3i2IdZb73LC6E7+mnEENG3mRj9TwmBy4SgPAGsi9RCOUsVEEg3SC0RHipzbN
/EVjawsTRkT/9sA+iCIv8yKhB/UFFReuRBQnwcgEV0SMqvlILwcqyWVw40AZ4hCGngnRWXzYvsOw
zUf82KCriIHBMNUlQg16W0aIEYHilAEMLkCO8QZVPDuAoQxtkALwLOjAGiJrJZ0oBAB+xgoyPEEM
+NAC0mRgCUSgagDQgEI5ghGUljhEMlH8od96JkcTwtBNkgHXlTzESBNWMU8qhBeWqMi/hdGLd1yp
y2b0gj5N2saFsYFkH4whBQCgIUwvQIMSjFKSNpyhDf1qAxpIABhxSMEIUsCRGqojzJDwMpf5kwIo
pCAcZXJlG2cwpnDq0EuuiAMNAOgEQrD0RhKQq5ZGOMM0O5FL/4+cwQ5nwNERxomaI1DTI7OUQlmI
wcs6cEWWtBSKGtqQDV8uiJcE1Uo2VBQSTqizmu18JzODN896iqAJUugCOpe0T6PIsgs5EMrKQCGK
jrXBBgdd0xnqsCASDJRcxCDBGUjAlSZkw51hYsMZqNKJQKFRZsg7FKKoIwVDHOGW2ajJEURQnQk1
4Zp3+E4KmKCCdTSDAr9gxhsmMQUfAAMJh6BCIEyAgE5wJZkxPaBFMfqmjZLmoh/lyi3X+ZdxlhMN
wzjD4fpQBzS8ICSGyIYxzZaNM3DiLNuQgk1DokxyHfacd/FnLTfSzW+G0zZ0LVcxM0qRZgJGDUro
JWDMKYXsmP9VpvYEgBRqdARtXow29dHl2tbm2n65ljuzu+3lZAsY2Mo2tvXZ7UqA69sU1idZsaUN
cm+r3OL6trnPai5xXbs/ncwTus6VbV6Y28DhUpe7ayPGHgxBWBYIyng/PV5QGWUMGGBpbbFYrgY+
kccisKIXk/gCVifxhK2aYRxUoMIxqJAFRRKjX8vd7nUbSBvh2ra2x+2XgZc0mOVW17a9vXCDg3vg
61poSREurlrk1F0Ed7e2vMUwubKLYV2aeG0fTu5ruQvj1Tk4wdqNcHJdy+IRkxg1cLIxhl1sYx1r
17hAdq5R8lAcbewDOWsEanQSpd48NJdSB44BACowDyZAABz/zeDAEzjg32MA4xjHiEY0snDcIOvk
wzxeMYJPbN0D77jGbIZxhXtr5/Yi2bsq/u6a+6xn69q5xWcB7p6P3BQVz7jIG1b0dIFc5zc3OsiV
5nCiKbzhEOdYJxFYWcuI9+Q02sEFkljeNvJA2yM3AFMqYIIWVPAPRnxhCrQYwDGQYOYadMAB5zMy
iBWdZw6PuLodDnRsGXzdSAv7LJmOsd+ajeBVO1rRb24us+H07CHvudsJ3jay3ZxpZSN7zsz+drnP
XW7n/vjC1VgEEETBiTK+zDlAhZkdptOGOwDhtucL8W35kUcyqAAQWtDCF5DQAS5wQQdjMDOa1Xxc
dQv6wsit/7SDM21nqhGbz0j2tqRrLHJsx3nNtY1LZ41Mbt/iTcErOQlscUwtQs+FO7ll85Bn3uZo
z27Hi662gbQL7gZ+WNm1PYnOA31iape12GMElKCeHB2YuQAM1DkDH9z86D4oII8qYAUg8PEGLCBh
DLRwxQCcAWBoOECRm7awhoO99Z8HveU+zrlvI/3n/WVXzi6vO9AzfO2ZD7vPIRb3nOlOcUsHHtqM
t7ZxM95jEkM+8XAneZHn2XTK+9bKcbf8dfHGFaSXdSN+YlmT10jqUrvg6nzYw4g9Xx8NuKofmSrC
OnbADGokQg+4cAUGuDAGMxwiGg6g8+bn/vPDyz3vSvc4j/8BPvSOK9+76y4y0p29DQCsbfuyVUIn
TsqJO5iWIA3gPoK4vyBjqH91Nmm/R+B/lC40uA4mBYwI9smPvAgUVxTxflaU1vloQDYMVGfxUvlR
BEyZVlLB1EEdwWfxU0gAIEHwAwncX4x8Vhsg3fbRxgKOXgEeVECd1UrF1G4ZAgDMUwSW1UaRC/sZ
mD4ZoJakFFe8VEyRhMfQX5q0Xz9xX3ilFAuImnkhj3MkSh1kw3pJgUrFxRCpQifw01/AlAL0gat0
QabIAxOAgxi0ggDMQiIIABccgxlQARRkwa8RgyCYoF+l4IKsoDjRIGPBH0WAn0wZhfchiA6WDQ/S
0xkkhoH/uGH8rQ1M1cFuUeDUIOAQKVZCXQ4ARqEa2sYCGpYcqgEnSFR+OGAhwl+qtUYOPMrabAYx
PIaJXIYhvEOe/F8CsElF5cG89EEOwEBwwIC4tEUetAYy3cUZJCKKxERdWARTcMz7fEkmiZC+DIXA
nE0FfU0fbCLYTIuO9OIe/KIwAuM01goxFtFDbAMMSAxaxA01qsFddGIrppIo/sVd3I9HvAOVrGIr
vuJDGMM2CE+TOYe9nVe+vQAwUZnI5OLUbBCW0JF8AUARkMMkrMAXzIITCMAj6NohQEEguB1FwAUV
4og2cmMy8sktEoQ4fqK7eISSoYYxmCK1bEMq1o5tOBFF/1DkNqKMNy5jLTbjPnbkMkZj2wSjrtSF
FADFglQFMYzFA80JLbaGj2jLCylMpBwGCYUEMTRAbLGJToBOfTglv3yLXIhLs4SLJeUPjRCET6IO
vAhHkIgLnoASJ56QMGLllWhlAPVBV3bRV2bSUOwPcJBSa0il6axJMOYOtQglXsYWVMKAIUgBT5Ea
zOCblOUjNiqMPwBGXYiAAiRDDDAAK4ADOPCAOxABDpiBLdQAKgxCMExYdwCL/sALyHBOX7KQl0RF
bCWlgUAlXfLNTsolWeqEVb4PWiKLWkqOTx4BQtxG0NkNfuhMcETYxuhMuQgLlbAJ5qAQtbQi2wAG
XwaHwv/kzC5mDbxUC1FACVWGDP9cRkycI1zuytZ4SUzIzYJgRHZW1ggxZ+pUTMCcI9cY54ikhrhg
0FxaDOE5J8DAIuqVGqFAGdW1ETBFQAKkxhHZjWxoRPTkkTzIgzL4wQrMATDMwSHUQNtVgSIBRmHV
kZd0Dnx26DhaZ7zMk5oMZSPhZneqznu2DeNwTXlGEHYmVWUpp4kQhEKJzgJFkK3EVoJ0B46c4kAk
4hdRzNqYS3bNS1wcS9ewTZBAyna0BEOQCzcq0Vg6431WRPTcRSdwyLbsqHtGCghFhpSeBQcRUZ7U
ypVuA9WYJ2B0KZAsTgT9aDBWkoGIy2LYnc74iXHsA3P/0CM9DooLlIE2GUIELGmXdAhBdEIFJAMD
7IAH6IMvWAEUnAAIKBICENf/wZJLtOkJveli0EaYRmmHEqkuHUyLtAQ8bcO9HAxDcKqVZMmXPqmY
qga4mKmBCEdk7FYDQAv/mCeo8pkIAMvmiIWN8IZJBleZXE5xLuem2tYN8UUrecWdmKaAEFFqxIRv
iAaQ1mpYhAalWIbqQKm3QEZrVGuHYKtiAKUDnaKS6Ee6QOsBCSto9GSxlsSytIW88IpRGMWyUgkQ
WBNPTR2hpFHr1UEbGEKBhiluSEQdSQ5JqILPJAMriIIH0AA6xEEwxIIiCWWDsKvmgGvnTERcBGsD
ZUdr/yjUbh2LGoCOi66SbLTrfD4rd2SHbNznWlAQh2AEN0rjNA6rboyGbwbXEbzIPH1FTUwjONrG
4WjQedZcm2Rfq9YHGuzfWUyhhk0EG0wlxKTGidqEBQXRYIiLBjSAsbIO03bj15AFlpBQUs7IVQwQ
+3AtemrAEfDDQ4Tty+3OiKrSRZ5pWUhEvzAGnxADnpxPUqrm0WZk0k4N7pBLpKTIcw1Iy9mElcEA
MqBBGewDGBzPf9rbPaZW1t3oAIGQaBzMJ1BKIcAAO1iDCASDKPzbkCoo4H6qdfLJGZxPdiDunabQ
VeyMTmBQiB2MT05QbmCJuRxn7cKt7HSt79Tt3YrM2P+WLUAdb+d0RQqxLWAgU7Zk7TKKA2rViDXZ
AfMEVxu0ASeohQbUgRRMiCjkQAXYwGN1gh3Ar0fUlGbFUjZ0gThkYzZIgijwSFOhVjhpAPy+wL6y
lP/VbTZIwYYGhlMxRTUgIpYoE3eEYkydhQYIlCrgID2VrxwV1WidxDZ4U2opoorAiRp0AgOvRFMZ
QXE0xGVBYvBU8GD537MIVGYcxTWhk1G8QAg3RAHbYTuNrziZL/pe4OukiAI4k01IgQto1jbYL4qs
jP4KBR/EVB1EHRFyrnTgozFEwGPMFcugrwaWkw10QScISD84YRmAxRlIgg3AU4rkAAOiwQ6LxguM
FGD/ELBgCrH4uuYVrTBBfMIQl4UxkMBdPURT2QE+5Yc2PW4GDxSN3HEP67FHkLBqITC1ENAMX8g1
vXAfRHBMkUsyBQ8jGcMZdMExNQUJBBNJDJEg+IMvbUQAS0FlOZukuV/m7TK68VzzyRzn6fK+Vl7P
RVuNId6fFdmq3Zy1MVqCUZvWWdfi3Rm6HUEEfAIJvMAZFQpzgMKf7oMb3cwuyx6wJV2ibdtuJR+k
PRpv+R0uB57RvbNy1aCCgRts7Z3QFdvkEXMwb1g0/12J4Rz0yTPkuTORtdhBAzTQFRrL5RxCU7Oh
XdrgWdhGXII1kUAQ1tvAHorV3VIEyJxE93OwSZ5C/+PWRF9eMl+fSge0yQm0tKW09Rmen7lzQRu0
yy3YQDcfOxMbtQla4V1bSLv0TPMy4e3c5el00imfhQDG4hmbzqkBK8qjRjNHzBSsFBhDGPy0T9u0
4z3fnAGcUAdgMGv1Ocd0UgtZyMFZuaWcWidYIgKcHBU06Oky5+VFoaHG5OJ1V0ubWTubOid1nj3b
yAEaztk1uzWaXi/fSTsYcWRDGWT0wA5h68HUelFayeEd9cUW31VfSehSXmvYsCG2UQcdPRfzbzpf
X2e2RDObg/V0SPzzYvdWis3TMmPJtt0zMPvZStt2Qwgt3WF2TvdZbjfFbC9IbdvGbVMXbPPYZndX
cf9LWM3BgCxhtBD2aWEiyqI0CpU1M0oPWun1Nm/rXG0x3WsLNUxv3UZMF5EFHnJB2FnrNnrTdcxp
3Hbdc3sNs1hTtMepmLo52GAsWFLpc4X5HHC59307rYwpFzGApm3/2mmTdlE39OyQN11P9H+3WYDX
d1Hbt+AVF4X3dx+IVzYEisDW43IkShkgYaHe9Hvvt4tXG4djdt9peMw1hYG/M6bicoclmgU5+Iyz
HKfBXSJqOEVQeJFd+AQCAHCprxKIQIox1FZsRAYr4b1AIC/RrUZy30kQwxGqVL/4sCDENfvB1vhd
jG1kAxps6EYwuZMvBgBknzc1kPel2DhRoW2o7wb/7mQX1KAFKuFZkEAOmLkGpXlTIFbKHQHEtkGB
EQQKEtf+kQAvqQFg5ICWL0mXWxiYizkbckWZdxaaq7legVaKJfqiuyIPLuOmZ0Sll8Slf7kS4qBL
HnLA4hs3lxo4t4E4LwipA0ajt8SjR/qkrzo/dDltocGeL0mfFxZXiMIwNNj2LbkUKIGkL0YXwPmp
z3lIKIEotPFKoCB4q0GXc/A+RVGzezqhZ8UjqwEpb0MX0NYbEeIfkqACngG3M7r6ncSws8yQj/lZ
dDpBhOREQCcjuc7anmRLLO6bhgZMWEh1pqSUwwoajFFZDVBaYIfAo60HTeA7CEdFUUWIaaOaJCVT
/5DQyt5LE8DAh4xEK9kGMlV8MqKtNs5IyUg56GiAMVzxgmyD477EZsCqgSqOBkC8xIdSKO3QxfNj
xjv8s9T8eumGR1aOIfDB0gpnSChO0q7soxhCMB2HocTMcoBCG6H5inMMzT/LzceQzleJFCw8d4iL
qlLEyac8Sdgt3OvkRgC8bSVj0lfES1JExzv9MlLFImlkXCiFbLQElWBvStZ9TFg8S4zLswjHekkM
OB78ZTTIhzpF4QOPWItLVUQ8YwTRJ4lEv9Qsc4LMzHoJlcjQd8aGlc3LmW7ttRY8+3BsbG2MEbXO
10Dp2rBqiZD+b9A+ZEDODDmQga4+7P9+Rry+hv/IC3TKRdLuhu7XRhX1iHsaqOA8v2YomQIMZvEQ
rBvBUaGPJykdvyUlb+/HTlBUF2tWJ+PcvmxZZA9NTtPWEZCuP4dEP51ef6iSp+6bJkAcOdOnzxEp
BAkOPHKkjxQ1CRH2UQixoBSGEgmqQUMwG0KFBwlu9IiQGBqGR2wgTEmR4cCCDVVyRHhQIEGDFxl2
WhgRZESXFWdSxPiyT8egFHu6NAoTYceTQ/vkuFiU6E+RQkueXNlnq8uWNplylUkQpFeLQqUe9RkR
q8mxUCc2TIAmGwkWLozkzWtHbxcX3rS1QRMB7M+0Mi9aXWvTbU2iS8P+pDoVY2KbZ5sSJcsWqkH/
lU9/EoO6Es3DsJPflr1MOe5Plz1zEIzNETRJuIXB9oR81XFYkwxBWvw6tDdT4IzVSu6JOvhLoz+X
i2Ur+fjI4QqPoBG9U1TulyCdMqVJ9Tvb8cvPTAVZfL3xq0l5RgzfnOFztecX58YJtHzB2ZEj8keD
CNCwax+8jODLjgXtcMEFO/Zpgw8+iMLPI/VsUs67gkorqLrjGIrtoqsQ4g266SiDqj+IqitIMgBh
Wmi8Pkgcz77N4ruQoZVcSw2h4sLa6rT5SFLuoo4e6smfh+4YqaGTRJKxQtOyGVEDrNo7g5/hOvFw
IBEwQ7LEgkR7iDqMTJvNs9siEnKp9CTaaaUu/xeKy6iLdPsxyuygtMkzPKm0EsvCthyKzprAPLIP
MzNzskLK/iSLypfQ0KClpw6CYZtsXrhrL7346sKOXMo4YxvRPMwTOQ8b23NGh4QiyE1H17yIGCNl
Mi07DxdV8as0GcMQJ1hpXHSpnmrt49Avw+w11h6fHOtO7YIa1rTQsix0KxGQfMiGk2x8SAOQbLhy
3DptamNDFwmC5SAR4uTwoRaNc+lbHO+N9C2E2nhqURNhSahOc7tDSA3J0iNGjebY5QrPtbZbWI3h
CGpjXuPUXdExd/uAF87sLl5uPXsfdhgo4CZWsV+iDiaK4o3HgzPa4zTYBo02ythnwQQ/tcObF//8
MYawKSnuw+L+jsi4RZgjavlChQ8yrQ14ERJBgUW9BVczISv2V6Mfzwi4JoaIUbo+gviBU4or1RDT
aKpNZirfGWNcFNZzHdOgyYbmnahsP8kj5o6Qcxz7E3HsICHKNuq6aEt/pFCXITXaOMMfg0mIvFdj
sunijDsVV3c7YrKRgoSTjEHDiDNootyfbExrOxslUk66cYKI2cYGF0ovSJxsXGgDpG2k6CIHs9og
wbQ+VIkc1SOMySGX0hc6IhvW51WDhGxgz4h72hlCQwojpDiVIQ3O+Pyi3/eRYqIXNH+Ic89Bv7mP
0Us/vaDUV2+9jddj973a/U9/90Of+giyqeD/DW982dhGArOxuvqJzkMKyIH+1GCINpBvGxFoQjbq
kDMH8eVBLnhBGV5whybYQXw2OWCVCMI+970EfuqSX+c+ZxMS5EABzzOGFKYnHOthjyDGaIMdcrCR
I2wDcYpLlz8KmLsz8I4mv1tgAot3vMu0oQ47kYIUWJCNjBHkBTmow8WE54+LGBGJIpEd+ArCuAKq
gXira0zlLpcREpzBBrGzwRm6CBwwijEiL0DDC1CnOtYVxHXd0wxYIAWW2P2oD1f6UYoicpHlQZKS
O+EMrz7JFkweQVecpOQj55Wih6Aqk6wUZShNeZJRghJwodTkK6ciS1ti8pM4meVLeMmZW0Zk/zu9
VEMezqAAu7hgH/swAjP3UQYSGGKWnswkLbH5Smdl5H7CfF7TwHJNbWaylMAUZyQfyZlJ7sdg6Txl
OM15TUvC8pTBvKY1tWlPcdLTnePsJT39ZUuXqVOY+sTlP995T1iyk5/wbGhChQnQflLSlfysXkNz
KVF6siEP2zgDCV6QD0FIog4kEB4fNunQfT5UpSrVp0HpmdJssvSc2xynPckmUH/Ck6E6ndxCJ6pT
cVY0oC0dKESFGk6YrtSUSA1qPC3Kq4y6FKjdZKpSr4pQhWr1qV2tZ1Y/SYyO2ix9ppJCBF5aVaIi
9Jc0rSo6p1rUt2b1m1VNalTbijujYnSnXv9N0VI/WU5uYjWiNXVnWiMJV5uy9a59hShgCYrKoUY0
r3eFLFtkOlXNTEWsE4qATDXqVKgS1qqDPepOe+pW1HaSpbYq7FftCtaGCtamrnWsvzS7z6fEFbaO
vWQ/cfpL4aIzqgLNLWt/q9Xd9ja1PP0nYp372uWStrl7fS1Sj+tc3BI3tgUFrnK5ysl5bpWxlA2v
c5fHzmIa9rS6fe5BLWta6y6UlBFdZz4x+6Pxnq+ivBrvKzPLlmLe9507GeV+w5nSy/opwNfNKE61
qWDVSnWgvE0uQeB2XZb5FquuDTCBeytfqm5zwRfjDD++G+LFAlfCql1Ig/25H9m1wVJxvN3//dRQ
B/WdxBAAoCT8HNm2j6INej52VtLOQLtuCm9lpGScI5fYhU1uwwh1NUYXgEmMzI1RezZQgAaIET4f
66oNNuhX9vK3SqNFbipowLLBuEfjizTBCCh+CT90XCUeG5mGUgjy9UhAZGMYmcxJxsk2+Oxk7lly
xjW2XRRzvOOC9PjHfg7gkPuwpUFzRnWU2TTmbsZoJRSIzDdWWJ4NTGmwvOAMNA4zjfgcEiP8NI5J
VjOTT0I57ulqG1L+kRxtFWk9VyTWGti0LP3xUV1B7nT4M92hE61rKPc6vcD2E6L3o+o+/xnTmiZ0
ugxtE0T/SNqWlNlsYBipQ9GkCciMDymD/zMxg4jGEHnYCsVewzajjKwg7Y5aAvPQkedtI+A8EZdw
oCW0O0HlIKI5C0rIou+Q5EGI8YoKwAVuE6f8qd0agrekZERve1MSWtuAgZD4bXF0ay0nqeq3u6u1
MJDPuw/1lowahBYXKVB8WARhQw74oRFz14flynL5ETqeo6F84h1LwXkEfoLviBsLR2Pzt7Pm9pJ1
93sPD++DMWDglooM3SBso8lNGmZylGfo5f82WaSMgUycxN3jMudbyGs+ctxQRO2Fc4lC0lYRrfTq
XuTZl8yMcqy9owpWR4hN22aC4jO8WkMui86+3kQWskFmIIyfVPgsGTXFN4pFLdOaTxRFev+LJ/4o
w/H8sxgpEcqzKPBoh3jWMI96abW+MwjJ41q8WLL3aL4gKcG94ZEPJ9ItZip5fL3jqU4Wyc+e92Gq
b+Ehs5STQGY9qkEMjcwNfDNRv+rRKkp9ZfVIzqd+9K6XFOzrO/nh2EgoPdmImU5Ss8dcCCrhURHD
N2MhRIJINC6gGm9Kuqnw/k4t7K7+7mMzwow3DiL0nMPggGkjRONj9C/14uUn/O9FusJgloMA6Q8A
Q6JXNPCBOBBOPLAqjoxFcKJLfI9fCiI8VMEBTxD/CmIDfSQjiMVR0g9Hzm4ANSbdTLBYHA5T4Ek4
3mIBBTA5RFA+irA2cIT3KkkFm5BiPpD/LULQB6WwOraCJsziSPAEQzLiKmbjPxCG5BqlQ+KlJ4RE
iZQuP9ZkKODDSVqkC8nDDSsvCOvmNM6PP6rwa2SjEGFvXf5DOvLQD8VwNWiD+AYRDQ1RRV6EQ8BJ
HCwpUl7jJXLAYxwxEM0vLAiREkWJN8LCKPhwEcfEMgTvEdGOIsTlNN4D31jxNFZCFU+QFV/xUszD
YCTx4g5xRRLxFoMEFmkCM04EOKZi4aAFOqZCZmrwKCbiLIhFMjLGNIghOoaDUXTwDuFlBGfiIkSB
8VjkNLxiKGSObKKjJzCDPKSO4Z4xlzJvJ86xGo2xFQFQGRvlHZ2R/yDpHBsGZSjCJdIR/xmrJRQX
7g4/RPWsRxq/QyBVhpsMMgD/MNCmI0CqZSCSBE+oBjuIg29i5RrN70WQJQj5MRz9MRph8CPtUSCu
xVsOzibuZVx4ImB8Z16CY3KughiuxqqkQDTGJUnmxfgIEoaS5JG6o5zCY2HYpmAy5lxwR2Zszyvg
RGJA0jGILkNeEiGSUibPR2Rs8gjEASeJbxR5Uq+ehJRsAG5kxmnapk62so8qaT1mEixtYiz54yxG
kR86Am4eIhETKHaKEi4TAibn0isPcybCskOg8n40EixEgvFeDFYajyi956dm5Axisvi+MiKw8Dt0
ZW3G4m6oskygsS0Hs1cyczNPYiDGS/8KwhIv10Qvd7InJVMt2VKTUrNtLggs9mhqUOVgWs1DfscO
jKhdKqeAjmCPTid80MAObMD/6oAuCq0OiGI6s2E7DAENAMAGzgINcqALvsg0GsAGyEfs2uAOOOFi
TCo9GKKO6CJdsuFydKUOpOCMwM06CcIQssEOWGdyskE9GSM8xzMj+EhyxLI/j7MPYCE5cYI5dwIN
njM6rzM+K8kQiuc/CQI7NSkbevMlflMEgjN9ELQ4F7RBP+pBUzREqOwMcsA0iEc8YWgbSMAFvugi
ONR7PpQhQnREh3MhTDRjGrRydqKOTIWUjOEMKuB1IgI7q7NCs3PSuNM7L6JHDfRHl+j/DIyABBqA
3myAflBQjHYix3LAhmzCPvVHAzDUczADO7VzSjHDSvtgG7YheESCLoxTSB1Uh1aURiZUOi1UTTO0
TemClS7qqx4ssLyLLf5rv56Ctg6VxNqLuDyJ1l4CtP6rv2iNl3IJnx5pP3gpszCpUTPJoCLVQxQr
USOrVDnjv5ALkiAFn04VVF8VnK5pk3jJUS/VoSI1veIpoOTKVhOMm3wJLVvLmnwVt1gm11b1whCC
VJ21lzx1q9DvndSMV+EJwWCrsjQMqoJVmEArZcZJYYwqRfprs9JpKq71U7N1pVJrurIKt1qsVwyV
vRAMsrj1V+d1XXECtISVsPLVXW1i/19Daa3sKugOylTPyV9tA1s1Q1tJi5Ng6lz1qlMnrJ7QKb22
i5gwCsIeKlZfS2NBiWKnFZQs9mJdhlJ3aWULdrMWjL26tZbCCpbWa6ZCi1M3DHCKtWEbqmY9FWdj
i7tYlWeLS7b4CpuyS2Yfy62C619ViWn7CmeBtqWEy68A9rway1lxNb/gK8Y4DGuVdmtRll2NNmY9
9mlp6q/Kdmyp1rjCS2ivqmnbCaICbGrRJl1bq7yqq66ACm7ZlqbO1V8pA7S+9WP11qi+CcKq6Wvj
9WrHNqfYAsXUtlsL96741m1Fy6v+NrIUV7Y8tlwdV8CayrzAa3QhF79+FZ78tWZvSv/EVDWWDEtZ
NUNsuymYpmpeiwpyFSt1Z3efWNe9Fut1R2tb5ytnZXduJ7fCCqx42Wt1J+p28YuhLHVzh+l4Byt5
aZW80lZ1fXeiSik7Yi3KbolyuGgnNEDHTgdGfezVKEcKygAskMHIMrF0aMxD6mB21MA0iqcPqoEg
NMAGRAGRPOQTAGB826B8zwdN0W/c2Fd43vcl4td/NS5yriTM7tdi9BfL+reSAFiAF4KADRiBK0mB
1fd+JseB4Vd+J7h+LViM8pcsNNh/O1iWQJibyDeQRjhFS7iBTYdeAc3EzmB9u2l7mrMg4KcTMpE7
iYmIgWmI+mhexs1PMgc/F2WPHpj/ISK4klb4Shbifmkng/lXhgNYlphYltyMkvaoex6COWOHOX1Y
2apCiEWDiA0MyJI41rSsLoDphs03jR9ijeG4is/givsgi+eXgk3Yi2vHjgniE2BAHBiUIBrgEnqS
7Rbl8bovIWBAZLi4Qzro94DDUgxCKJEiAeoxMcLnEiDDMWRuYU7vDDaZJzr5IT6ZknJAlCnzWsjC
lPVDYGhElTOJIKPm4coilmdiluc0AkA5KnCZlO2Qlx/Sl9GAkoM5Ix4vLdYEljk5+jRz7Bp5FYzB
J3TZMbKxkR85kocCfTwiYDRAibZhD3CFT2bGk5WZktZGRpz5NaBZHzvQf60iAcQE/+2cJkrlOS0g
TyJw0pI+AZzFmUVcopz7wJEh2SZdQp0JQgbV4JonRym2Iy0ejp6X+ZbxGSQr46FnZGXkg9aE6A6k
pGKqwpN+z+McRTh+Yxe5DznI0FmE6Dd6QnIE5iJi+t1mWgCrBzMasvXkMBD1t3p4mgZRGaiBkG6c
kU9kBCdu2hJzeqkXgqXr0KfjJPWghyHuAFWi7qg/pJvF7qTjkSI/wTQq+SPHaAFjRarDkaptunCU
SGZmRCDgZiXAZH9Y0SuMQazJ+pISUitp5GEuAqVVjhOrh6szOawHMqo1Y6prWgpQLK1/BCSK6T/Q
JQhPBMNSok9OpmEwTBxKZinoxP+X30JpwuKzyYMdq2a0LbG0i+MIGiC1EWK1Lc7wXBtZemPf1EIE
aHtXbJs6chtHVPulSc+1Pbs3eEQtjmC1oY8/9JAljOYoxkj7QOIoXXpHPiMoKPA6js60Owa1lXu3
mbu1q9CrgbG2pYMJXWLrpOP/znGMQGK7N1siESLQKCa6g1C+L7q8bzu5mSLzsjv3LhIsDsMl1JCV
3DDB4wYmLmYaWeIwVIQJ0YOSxG4TEwLCl+cGWZvCY+IJawXDccUcOZwV4RBuIlzEe9vtxMLE1wPF
eaJkhCJEWPHBS2R5KplhErt2K++o1UQysg/HLbxvdC+xlwiVg6LC+8MrbBwlmUL/jaowGk+PKawC
SI/C/nKKPTSu6sCxKXAcM87iP46xRLh8xGV8tHflxMXcBSEpSiAxv/EQ+dRkzKM5wTO5mw47x+m8
sSX8HK+6Dg0vCV3aODjbHWGktp0cGOMaLApdzxGdzy9Dr/68MwLdzBP9I38vKtgvJWmElZZiNsxC
zu/nKkZPDWSQNhhCBNREJPr8Lfg5Y/pcNDLdJa7i3ub0GRtlWkIi1Ed81EnP+yqjLWKizjud9Wq7
MSjd/Gz90tnEMeEJMuKlIeWZJi+9b8A6FEGynbNSIHyd/5xmX+KFL/2jM5+8Fc3a22HFlQNR3Gsx
Xsod+c7dKdxC2zcDJ7evl2fi/4/PIt3c81k2Wgp176jPQt9J3PaoUckNvvRcQhTCz0ALI2Vc4yLu
bQRT72MSkjLePS0Eftx92Wk0kyEKJjOcnB+Cg2qYHe0a70W4r3ryDSvOseT74OSr0ilY+n5ycveK
z9/fD94Ffuoq44eM5yxsBgA6AZLB7WgIggRsoIA8yg6yQYlEQAlSlCCaYHy+qGo44dkyonJQ2kjX
Q8dQWhy4c+l/zcyWxz6dXhzOoAvQwCu+vg1scu7JB1mS02DE/iLIPuwBCSHQXumZfkPL9Cnc3jTg
Xu7pPnLuXku7HtwsclH6Hov6B/D18+vOwD+jTnFIYDuWM+r9fvOrnpEqR8nu5//0iYJ4/HM9MieK
KqeLikgKAEB8LsKQlOBRAe0lxGF8FqnWUF8NsN7pxYd82hJCAX/sfb+7Y58ocP8pYjTyj+B1Mv8I
OOGjUEXLbA13VN/vpaD1T0J4Pv9MP2dejD4HMOP5X6JsWm15lOA+fwTQsh/5+2Dr8/7XMI3yWw0n
8oxhOWxyAeJIHzV9Cho8KLCPwCMJERZcaDAhwYMKKT60iNHgxIoYExLrmNHhQJAUG3IMudGkyI8W
VZLcKJLhxYQQSQqEeTFiSZknc6r8qdMkT405Q5YcWZAYTo41OS492RSpQpMfh84s2nOqyYkEhbo8
+tWhULEtM4btabUsWKgFJ7L/NAoXKFypOoNmzTq24VmQUY+qNUrT71WscyGeDduXLNK3dRtHBJqY
LtrCfOE+dXz3L2aLXX16JonQ5dvAmUWutbl5blnDhAXHNcoyMuKDHy+rBlyx79emifeava1Gb27X
dgebvs02JD/VsfHWlDvRd1LNmJ+rFm5w9HTbx1vf5Y5VJmnkpZP/7k58uEvfY8mHXO9wuVzP0t3b
71wW/O3xfvlbznyTfaj19FZz1E2W3W3y4dZWXbMdaNaDw1GWXH0SOfXZdIX5hx5T+9UV3UULNnjd
eR7yNmGK2EFkYHrw9YQTa8YVtxRNu+WU0oTj7ZhiZRf2dyOGV5G24lHgoUgf/1EQ9sHYQRtp5917
AfoWInovFplaRfodUaWSrmHXHZjwPUhTl/yRliOSIVWFnEevtWdbWmFmKVhk5plWX4cATlXUXmDi
6Z50G1VZU5N/yblTY3ku9GOX5EnYkp+/8dQVhx4S+thrdWmgp2E/JgoUfuLFRGcfnILYxhl1HPGR
CKnWEVxSqbax0ScAmFTHGdmcqgYJUpAg0EckZENCSnXkQMJyChkCAEUkqBpdHTbQWpCr0HrURjbU
FlTHr8qqwYkUdUTUxK0PHfGsEiYZY25bs771LKwGbdOsQdbC2hC9CHVLAkvEdDvuQ+XamO667Q70
rkHxbqTvQezi1HBC9OKqK/+vvrbBqUDMIkSMr8DOW+9DSqhKU8Mgl8RsYOxe1OsZxbb1LAkcmdxW
uC8vG3JBC598EM0FsWtSAwf3gUbO6J5BrcZGi+BxZ7NGR7Mar7JakM9HjHxzHx7PbHTMwWpNrMEN
SY10bDTb0JYUBZ1BjEBqr/1QNlV/I7dBaBd0991HvC3FQn2vvdAZVcMgd0JndCV4H3er8Tbbbht0
xkKF5+B3QX8rXnUeaHAU+UCCC7RNHm8DrlDih5eeeeJrt93H6KG/LZANle+d0N2hb274TZ/38fpB
nR9hOuKpH5TDHqMXhAbhB6Gxhz8H3Y159H3ULcUeqiuEhkAi2K684cLznsf/9cUfT7TyBjHvvN3q
S0+99Qhl38f2gxe+9vehi288RcnXXZA4mjdkjPD5Lm6Wc19EKKeQOwgkG4FTSACvt7i3jY8ivyvc
2xj3MwFC7iF8ayDoROc7Dz7wIJdLXA4Mwr/ICeSEHOQI/I6wuT4osCB1S6FBYDc6GL5FdYkrYUFY
OL0NWq4gbUAhDR+CO9Td0HBMOd7oGidEuBkEiPz7IUdGV0Mk5uZ6PqSJE28oxT5c73pExMjuWpiQ
F8ZwhkcQB1LUxpPOtS4iaNhhFMVokSJa5IwKgSPyFrLGhbhxInDM3RCRaMcw4pEieqQgVMi3yEMS
7Y18EmNC0gfEMW7EhwZp/6TlEvK2IgokcaMkoRGDCDcvmlKSYtwkKGn4SikCL4QPUV32RODGT85x
iAu84xf7qMtdMlCS8Fvk6D53zIsoICEaIKUcJTlLKeLweQ0Z5i7vyENJkrIPyyxIM2tpkhxmc5d7
oyZFIEkMSKoumkQ7Ai47GZEL6qyFYKxnOe2mEnSqMyK2dGcu+9DIe05EZsCs5yHvibd8WiSdFumb
Xrgok4DKU2toJOUvg3nRP0oxhgCN50FEIZO/HTOc/PTlQfinx9EpoSJqI4jgWEK/PuRABKXEI0Og
KMttyGeMSGlkFst4zZXWNHrj5CRDgIg5gnD0cQmRG0FCecqnrrIPQq3INv+LysSpIBVtStWJH4Mo
1Y4ecSSQLKZB+LFNhcR0pjX93D1HyaWHNOBUPJ2ITxtUVpWg1Sdrpeki3Qo7S0ZnrooUnF2jes3z
6TWtiRVIJ05KT7gO9lRve2xhOYLS5ZlEdXfbndpgepD03dOWXsUsWQcYSxh67pVwVWTdhmq6hxjD
bR5sHROD9baPFJNvWlSDHP3oUBFk754iOOERZktbMMayozzhHzuloNTl7tKlrD1lTdVgXOTaVrmS
FGVTS2q56LJyogy9CKekwDqDiDaSsT3id59Xy4qUV7fSJW8OTdW69BZkveNUXUyrGL1Z4nY6u12l
W+57Xv1SFClHMG4qg/j/3vXZtsEMKSchV6naj5S3Igpk1R36ODsrZvW4yWVuhJ9LSciJgHSJ8+35
guPi+CFUAy/sIEPqdjoBN7gtaNhIMaMZzTOs2JKLjHH0sDsQBO51eodNCEE1qoZtPGZ0asAdBoHc
4nJm1ci95KBAlpyNJs9TsQOR8rmobGU4OrMtWqZjH2BBEQBfk8aV226VN5mTyIngzmRWYjSD81Xs
vTnODTUInQv6Nz4fFHB77nGfsczmQKsWzpA9J36xSRBFk5PRjHvqRFo8Scp+miabo/SRT8i4mzhX
k0zCcVfMPBU0KwSDI9ncqTRgAym8gFHDktlC1JCNXxmkCWcwAhr0qIGm/8FM2JnOhss4ooFstQGQ
xT7D347wAimE2Zu53vVUep0bqbVhVQJJtq5qo7U2tIF1aJCCC6QARzXkatoV2cYZ7JAN/r3gDIdb
SLa3zbuiSSGG6CJWbrYhhS7kuivPyga6SaBudrsb3rOeN0TsjW998ztW2Nb2RLYh8Bja2wjZgLU4
pGCENsARDcU+tjeVPRBla8AYZwCAFPSmNWRR2wjW9rfHqxbyqhW75AY5ecpX3nJkw7xXvyLIzGt+
84uQQOfYq/a1//3xoPNu6CZHucqrjm8WGoMEXdiG3DQAPGI5neY2x/nUX8YQiNMKdFCPIa51vZCR
E91d45aJBrpF770l3GPspkq7zJrtsovfO98G2Xe/t27zJEomMF9JU57UYiknnYtEDsKLZHCjm5Oc
ijiOsk6PBCSj4lya9OEpD+gvb/o8ld7176lkiYgEnNZfnk7MXE2G8CMlzpcoRyQZve+9CZqSBAQA
Ow==